@@ -1,6 +1,7 @@
 #!/bin/bash
 
 set -e   # Make sure any error makes the script to return an error code
+set -x   # echo
 
 MRPT_DIR=`pwd`
 BUILD_DIR=build
@@ -11,8 +12,10 @@ CMAKE_CXX_FLAGS="-Wall -Wextra -Wabi -O2"
 function build ()
 {
   #env
+  git clean -fd || true
+  rm -fr $BUILD_DIR || true
   mkdir $BUILD_DIR && cd $BUILD_DIR
-
+  
   # gcc is too slow and we have a time limit in Travis CI: exclude examples when building with gcc
   if [ "$CC" == "gcc" ]; then
     BUILD_EXAMPLES=FALSE
@@ -23,7 +26,7 @@ function build ()
   cmake $MRPT_DIR -DBUILD_EXAMPLES=$BUILD_EXAMPLES -DBUILD_APPLICATIONS=TRUE -DBUILD_TESTING=FALSE
   make -j2
 
-	cd $MRPT_DIR
+  cd $MRPT_DIR
 }
 
 command_exists () {
@@ -37,14 +40,17 @@ function test ()
 	return
   fi
 
+  git clean -fd || true
+  rm -fr $BUILD_DIR || true
   mkdir $BUILD_DIR && cd $BUILD_DIR
+
   cmake $MRPT_DIR -DBUILD_APPLICATIONS=FALSE -DCMAKE_BUILD_TYPE=${BUILD_TYPE}
   # Remove gdb use for coverage test reports.
   # Use `test_gdb` to show stack traces of failing unit tests.
 #  if command_exists gdb ; then
 #    make test_gdb
 #  else
-    make test
+    make test -j2
 #  fi
 
   cd $MRPT_DIR
