@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -656,7 +656,7 @@ void xRawLogViewerFrame::OnGenGPSTxt(wxCommandEvent& event)
 				refCoords.lon, refCoords.lat, refCoords.height,
 				_local_ENU,
 				true);
-			local_ENU = _local_ENU;
+			local_ENU = CPose3D(_local_ENU);
 		}
 
 		// All gps data:
@@ -713,7 +713,7 @@ void xRawLogViewerFrame::OnGenGPSTxt(wxCommandEvent& event)
 										refCoords,
 										_local_ENU,
 										true);
-									local_ENU = _local_ENU;
+									local_ENU = CPose3D(_local_ENU);
 								}
 
 								// Local XYZ coordinates transform:
@@ -833,7 +833,7 @@ void xRawLogViewerFrame::OnGenGPSTxt(wxCommandEvent& event)
 										refCoords.lon, refCoords.lat, refCoords.height,
 										_local_ENU,
 										true);
-									local_ENU = _local_ENU;
+									local_ENU = CPose3D(_local_ENU);
 								}
 
 								// Local XYZ coordinates transform:
