@@ -82,8 +82,13 @@ void thread_grabbing(TThreadParam &p)
 			cout << "Loading calibration from: "<< cfgFile << endl;
 			kinect.loadConfig( mrpt::utils::CConfigFile(cfgFile), "KINECT" );
 		}
-		else cerr << "Warning: Calibration file ["<< cfgFile <<"] not found -> Using default params. "
-			"This may cause innacurate 3D point clouds.\n Checkout the kinect-stereo-calib application:\n http://www.google.com/search?q=kinect-stereo-calib%20mrpt&btnI \n";
+		else
+			cerr << "Warning: Calibration file [" << cfgFile
+				 << "] not found -> Using default params. "
+					"This may cause inaccurate 3D point clouds.\n Checkout the "
+					"kinect-stereo-calib application:\n "
+					"http://www.google.com/"
+					"search?q=kinect-stereo-calib%20mrpt&btnI \n";
 
 		// Open:
 		cout << "Calling CKinect::initialize()...";
