@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -10,6 +10,7 @@
 
 #include <mrpt/random.h>
 #include <mrpt/utils/round.h>
+#include <mrpt/utils/bits.h>
 
 #include "common.h"
 
@@ -39,6 +40,23 @@ double math_test_round(int a1, int a2)
 	return T;
 }
 
+template <typename T, typename FUNC>
+double math_test_FUNC(int a1, int a2, FUNC func)
+{
+	const long N = 100000000;
+	CTicTac	 tictac;
+
+	T x = 1.0, y = 2.0, r = .0;
+	tictac.Tic();
+	for (long i = 0; i<N; i++)
+	{
+		r = func(x, y);
+	}
+	double t = tictac.Tac() / N;
+	dummy_do_nothing_with_string(mrpt::format("%f", r));
+	return t;
+}
+
 // ------------------------------------------------------
 // register_tests_math
 // ------------------------------------------------------
@@ -48,4 +66,8 @@ void register_tests_math()
 
 	lstTests.push_back( TestData("math: round",math_test_round ) );
 
+	using namespace std::placeholders;
+	lstTests.push_back(TestData("math: std::hypot(float)", std::bind(math_test_FUNC<float, decltype(std::hypotf)>, _1, _2, std::hypotf)));
+	lstTests.push_back(TestData("math: mrpt::math::hypot_fast(float)", std::bind(math_test_FUNC<float, decltype(mrpt::math::hypot_fast<float>)>, _1, _2, mrpt::math::hypot_fast<float>)));
+	lstTests.push_back(TestData("math: mrpt::math::hypot_fast(double)", std::bind(math_test_FUNC<double, decltype(mrpt::math::hypot_fast<double>)>, _1, _2, mrpt::math::hypot_fast<double>)));
 }
