@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -14,9 +14,10 @@
 //(*Headers(navlog_viewer_GUI_designDialog)
 #include <wx/sizer.h>
 #include <wx/stattext.h>
+#include <wx/radiobox.h>
 #include <wx/menu.h>
 #include <wx/textctrl.h>
-#include <wx/checkbox.h>
+#include <wx/checklst.h>
 #include <wx/things/toggle.h>
 #include <wx/slider.h>
 #include <wx/panel.h>
@@ -59,17 +60,30 @@ class navlog_viewer_GUI_designDialog: public wxFrame //wxDialog
 		void OntimAutoloadTrigger(wxTimerEvent& event);
 		void OnbtnMoreOpsClick(wxCommandEvent& event);
 		void OnmnuMatlabPlotsSelected(wxCommandEvent& event);
+		void OnmnuSeePTGParamsSelected(wxCommandEvent& event);
+		void OncbGlobalFrameClick(wxCommandEvent& event);
+		void OnmnuSaveScoreMatrixSelected(wxCommandEvent& event);
+		void OnrbPerPTGPlotsSelect(wxCommandEvent& event);
 		//*)
+		void OntimMouseXY(wxTimerEvent& event);
+		void OnmnuMatlabExportPaths(wxCommandEvent& event);
 
 		//(*Identifiers(navlog_viewer_GUI_designDialog)
 		static const long ID_BUTTON1;
-		static const long ID_STATICTEXT1;
-		static const long ID_TEXTCTRL1;
 		static const long ID_BUTTON2;
 		static const long ID_BUTTON3;
+		static const long ID_STATICTEXT1;
+		static const long ID_TEXTCTRL1;
+		static const long ID_RADIOBOX1;
+		static const long ID_CHECKLISTBOX1;
 		static const long ID_SLIDER1;
+		static const long ID_BUTTON6;
 		static const long ID_BUTTON4;
 		static const long ID_BUTTON5;
+		static const long ID_STATICTEXT9;
+		static const long ID_TEXTCTRL3;
+		static const long ID_STATICTEXT8;
+		static const long ID_TEXTCTRL2;
 		static const long ID_PANEL2;
 		static const long ID_STATICTEXT2;
 		static const long ID_STATICTEXT3;
@@ -77,26 +91,28 @@ class navlog_viewer_GUI_designDialog: public wxFrame //wxDialog
 		static const long ID_STATICTEXT5;
 		static const long ID_STATICTEXT6;
 		static const long ID_STATICTEXT7;
-		static const long ID_CHECKBOX1;
-		static const long ID_STATICTEXT8;
-		static const long ID_TEXTCTRL2;
 		static const long ID_PANEL3;
-		static const long ID_BUTTON6;
 		static const long ID_PANEL1;
 		static const long ID_TIMER1;
 		static const long ID_TIMER2;
+		static const long ID_MENUITEM2;
 		static const long ID_MENUITEM1;
+		static const long ID_MENUITEM3;
 		//*)
+		static const long ID_TIMER3;
 
 		//(*Declarations(navlog_viewer_GUI_designDialog)
 		wxButton* btnStop;
 		wxTextCtrl* edShapeMinDist;
 		wxButton* btnMoreOps;
+		wxMenuItem* mnuSeePTGParams;
 		wxPanel* Panel_AUX;
 		wxStaticText* txtLogDuration;
 		wxStaticText* StaticText2;
-		wxCheckBox* cbDrawShapePath;
+		wxRadioBox* rbPerPTGPlots;
+		wxStaticText* StaticText6;
 		wxTimer timAutoload;
+		wxCheckListBox* cbList;
 		wxFlexGridSizer* FlexGridSizer9;
 		wxCustomButton* btnQuit;
 		wxPanel* Panel1;
@@ -107,9 +123,9 @@ class navlog_viewer_GUI_designDialog: public wxFrame //wxDialog
 		wxSlider* slidLog;
 		wxTimer timPlay;
 		wxStaticText* StaticText5;
+		wxTextCtrl* edAnimDelayMS;
 		wxStaticText* txtLogEntries;
 		wxMenuItem* mnuMatlabPlots;
-		wxFlexGridSizer* flexGridRightHand;
 		wxCustomButton* btnHelp;
 		wxTextCtrl* edLogFile;
 		wxCustomButton* btnLoad;
@@ -117,6 +133,9 @@ class navlog_viewer_GUI_designDialog: public wxFrame //wxDialog
 		wxStaticText* txtSelectedPTG;
 		wxButton* btnPlay;
 		//*)
+		wxTimer timMouseXY;
+
+		int m_cbIdx_DrawShape, m_cbIdx_ShowAllDebugFields, m_cbIdx_GlobalFrame, m_cbIdx_ShowDelays, m_cbIdx_ClearanceOverPath, m_cbIdx_ShowCursor;
 
 		DECLARE_EVENT_TABLE()
 
@@ -151,7 +170,5 @@ class navlog_viewer_GUI_designDialog: public wxFrame //wxDialog
     }
 
 
-#define NAVLOGVIEWER_VERSION  "1.0"
-
 
 #endif // NAVLOG_VIEWER_GUI_DESIGNMAIN_H
