@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -166,8 +166,8 @@ void do_pf_localization(const std::string &ini_fil, const std::string &cmdline_r
 	//  Only used for observations-only rawlogs:
 	CActionRobotMovement2D::TMotionModelOptions dummy_odom_params;
 	dummy_odom_params.modelSelection = CActionRobotMovement2D::mmGaussian;
-	dummy_odom_params.gausianModel.minStdXY  = cfg.read_double("DummyOdometryParams","minStdXY",0.04);
-	dummy_odom_params.gausianModel.minStdPHI = DEG2RAD(cfg.read_double("DummyOdometryParams","minStdPHI", 2.0));
+	dummy_odom_params.gaussianModel.minStdXY  = cfg.read_double("DummyOdometryParams","minStdXY",0.04);
+	dummy_odom_params.gaussianModel.minStdPHI = DEG2RAD(cfg.read_double("DummyOdometryParams","minStdPHI", 2.0));
 
 
 	// PF-algorithm Options:
@@ -248,7 +248,7 @@ void do_pf_localization(const std::string &ini_fil, const std::string &cmdline_r
 		}
 		else
 		{
-			THROW_EXCEPTION_CUSTOM_MSG1("Map file has unknown extension: '%s'",mapExt.c_str());
+			THROW_EXCEPTION_FMT("Map file has unknown extension: '%s'",mapExt.c_str());
 		}
 
 	}
@@ -546,7 +546,7 @@ void do_pf_localization(const std::string &ini_fil, const std::string &cmdline_r
 									GTpt->setName( "GT" );
 									GTpt->setColor(0,0,0, 0.9);
 
-									getAs<CDisk>(GTpt)->setDiskRadius(0.04);
+									getAs<CDisk>(GTpt)->setDiskRadius(0.04f);
 									ptrScene->insert( GTpt );
 								}
 
@@ -598,16 +598,14 @@ void do_pf_localization(const std::string &ini_fil, const std::string &cmdline_r
 								}
 
 								CSimplePointsMap	map;
-								static CSimplePointsMap	last_map;
 
 								CPose3D				robotPose3D( meanPose );
 
 								map.clear();
 								observations->insertObservationsInto( &map );
 
-								getAs<CPointCloud>(scanPts)->loadFromPointsMap( &last_map );
+								getAs<CPointCloud>(scanPts)->loadFromPointsMap( &map );
 								getAs<CPointCloud>(scanPts)->setPose( robotPose3D );
-								last_map = map;
 							}
 
 							// The camera:
@@ -748,8 +746,14 @@ void do_pf_localization(const std::string &ini_fil, const std::string &cmdline_r
 							{
 								static mrpt::gui::CDisplayWindowPlots win;
 
-								win.plot(ssu_out.scanWithUncert.rangeScan.scan, "3k-", "mean");
-								win.plot(obs_scan->scan, "r-", "obs");
+								std::vector<float> ranges_mean, ranges_obs;
+								for (size_t i=0;i<ssu_out.scanWithUncert.rangeScan.scan.size(); i++)
+									ranges_mean.push_back(ssu_out.scanWithUncert.rangeScan.scan[i]);
+								for (size_t i=0;i<obs_scan->scan.size(); i++)
+									ranges_obs.push_back(obs_scan->scan[i]);
+
+								win.plot(ranges_mean, "3k-", "mean");
+								win.plot(ranges_obs, "r-", "obs");
 
 								Eigen::VectorXd ci1 = ssu_out.scanWithUncert.rangesMean + 3*ssu_out.scanWithUncert.rangesCovar.diagonal().array().sqrt().matrix();
 								Eigen::VectorXd ci2 = ssu_out.scanWithUncert.rangesMean - 3*ssu_out.scanWithUncert.rangesCovar.diagonal().array().sqrt().matrix();
@@ -797,7 +801,7 @@ void do_pf_localization(const std::string &ini_fil, const std::string &cmdline_r
 								GTpt->setName( "GT" );
 								GTpt->setColor(0,0,0, 0.9);
 
-								getAs<CDisk>(GTpt)->setDiskRadius(0.04);
+								getAs<CDisk>(GTpt)->setDiskRadius(0.04f);
 								scene.insert( GTpt );
 							}
 
@@ -848,16 +852,14 @@ void do_pf_localization(const std::string &ini_fil, const std::string &cmdline_r
 							}
 
 							CSimplePointsMap	map;
-							static CSimplePointsMap	last_map;
 
 							CPose3D				robotPose3D( meanPose );
 
 							map.clear();
 							observations->insertObservationsInto( &map );
 
-							getAs<CPointCloud>(scanPts)->loadFromPointsMap( &last_map );
+							getAs<CPointCloud>(scanPts)->loadFromPointsMap( &map );
 							getAs<CPointCloud>(scanPts)->setPose( robotPose3D );
-							last_map = map;
 						}
 
 						// The camera:
@@ -899,12 +901,6 @@ void do_pf_localization(const std::string &ini_fil, const std::string &cmdline_r
 						// Generate text files for matlab:
 						// ------------------------------------
 						pdf.saveToTextFile(format("%s/particles_%05u.txt",sOUT_DIR_PARTS.c_str(),(unsigned)step));
-
-						if (IS_CLASS(*observations->begin(),CObservation2DRangeScan))
-						{
-							CObservation2DRangeScanPtr o = CObservation2DRangeScanPtr( *observations->begin() );
-							vectorToTextFile(o->scan , format("%s/observation_scan_%05u.txt",sOUT_DIR_PARTS.c_str(),(unsigned)step) );
-						}
 					}
 
 				} // end if rawlog_offset
