@@ -12,6 +12,49 @@
 
 <p> <b>Note:</b> <i>If you are displaying a local version of this page and you have not built the whole HTML documentation, the links above will be broken. Either build the documentation invoking <code>make documentation_html</code> or [browse it on-line](http://www.mrpt.org/).</i></p>
 
+<a name="1.5.5">
+<h2>Version 1.5.5: Released 2/DEC/2017 </h2></a>
+- <b>Detailed list of changes:</b>
+	- \ref mrpt_base_grp
+		- Added methods mrpt::utils::CFileStream::clearError() and mrpt::utils::CFileInputStream::clearError()
+	- \ref mrpt_nav_grp
+		- mrpt::nav::CHolonomicFullEval now uses an internal sin/cos LUT cache for improved performance.
+	- Build system:
+		- octomap is no longer exposed in public headers, avoiding the dependency propagation.
+	- BUG FIXES:
+		- Fix likelihood computation in mrpt::maps::CReflectivityGridMap2D (which led to crash)
+		- Fixed regression in particle resampling affecting RBPF-SLAM methods. Introduced in Dec. 2016 with [this commit](https://github.com/MRPT/mrpt/commit/691973813bdc53d3faa7088b092eb041aa80d0ce).
+		- Wrong argument type: CStream::Seek() must allow signed offsets.
+
+<hr>
+<a name="1.5.4">
+<h2>Version 1.5.4: Released 31/OCT/2017 </h2></a>
+- <b>Detailed list of changes:</b>
+	- \ref mrpt_base_grp
+		- Fix potential uninitialized value in CRobot2DPoseEstimator::getLatestRobotPose()
+		- MRPT_getCompilationDate() returns time as well
+	- \ref mrpt_gui_grp
+		- mrpt::gui::mrptEventMouseMove:  Added new mrpt::gui windows event type.
+	- Smart pointers:
+		- All mrpt::utils::CObject derived classes:
+		- In MRPT <=1.5.3, there was a typedef `Foo::SmartPtr` => `FooPtr`.
+		- In MRPT >=1.5.4 is has been replaced by `Foo::Ptr` => `FooPtr` for compatibility with MRPT >=2.0.
+		- stlplus smart pointers in MRPT 1.5.4 now have C++11 shared_ptr-compatible methods, to ease the transition towards MRPT 2.0 in user code (in particular, for MRPT ROS packages). Also, a new template `mrpt::prt_cast<TARGET_PTR>::from(ptr)` is provided to write user code compatible with both MRPT >=1.5.4 & >=2.0.0.
+	- Build system:
+		- Fix MRPTConfig.cmake for system octomap libraries.
+		- Fix package-contains-vcs-control-file (.gitingore) Lintian error.
+		- Fix compiling without liboctomap-dev in Ubuntu PPA.
+	- BUG FIXES:
+		- Fix waypoint reactive navigator edge case in which "end event" won't be issued.
+		- Fix waypoint reactive navigator error while doing final aligning (missing and dupplicated nav-end events).
+		- Fix aborting reading from LMS111 scanner on first error.
+		- Fix corrupted pointers in CNetworkOfPoses after copy or move operations.
+		- Fix invalid TP-targets generated during reactive navigation.
+		- Fix memory leak in reactivenav engine.
+		- Fix potential out-of-range access in CObservation3DRangeScan::convertTo2DScan()
+		- Fix potential SIGBUS in armhf (patch by Steve Langasek) inside mrpt::utils::CTicTac
+
+<hr>
 <a name="1.5.3">
 <h2>Version 1.5.3: Released 13/AUG/2017  </h2></a>
 - <b>Detailed list of changes:</b>
