@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -12,6 +12,7 @@
 
 #include <mrpt/math/CMatrixTemplateNumeric.h>
 #include <mrpt/math/CArrayNumeric.h>
+#include <mrpt/utils/bits.h>
 
 namespace mrpt
 {
@@ -65,7 +66,7 @@ namespace mrpt
 			(*this)[1] = x;
 			(*this)[2] = y;
 			(*this)[3] = z;
-			ASSERTMSG_(std::abs(normSqr()-1.0)<1e-5, mrpt::format("Initialization data for quaternion is not normalized: %f %f %f %f -> sqrNorm=%f",r,x,y,z,normSqr()) );
+			ASSERTMSG_(std::abs(normSqr()-1.0)<1e-3, mrpt::format("Initialization data for quaternion is not normalized: %f %f %f %f -> sqrNorm=%f",r,x,y,z,normSqr()) );
 		}
 
 		/* @}
@@ -134,7 +135,7 @@ namespace mrpt
 			if (out_ln.size()!=3) out_ln.resize(3);
 			this->ln_noresize(out_ln);
 		}
-		/** \overload that returns by value */
+		/** overload that returns by value */
 		template <class ARRAYLIKE3>
 		inline ARRAYLIKE3 ln() const
 		{
@@ -146,7 +147,7 @@ namespace mrpt
 		template <class ARRAYLIKE3>
 		void ln_noresize(ARRAYLIKE3 &out_ln) const
 		{
-			using mrpt::utils::square;
+			using mrpt::math::square;
 			const T xyz_norm = std::sqrt(square(x())+square(y())+square(z()));
 			const T K = (xyz_norm<1e-7) ?  2 : 2*::acos(r())/xyz_norm;
 			out_ln[0] = K*x();
@@ -211,7 +212,7 @@ namespace mrpt
 
 		/** Return the squared norm of the quaternion */
 		inline double normSqr() const {
-			using mrpt::utils::square;
+			using mrpt::math::square;
 			return square(r()) + square(x()) + square(y()) + square(z());
 		}
 
@@ -327,7 +328,7 @@ namespace mrpt
 		template <class MATRIXLIKE>
 		void rpy_and_jacobian(T &roll, T &pitch, T &yaw, MATRIXLIKE *out_dr_dq = NULL, bool resize_out_dr_dq_to3x4 = true ) const
 		{
-			using mrpt::utils::square;
+			using mrpt::math::square;
 			using std::sqrt;
 
 			if (out_dr_dq && resize_out_dr_dq_to3x4)
