@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -82,7 +82,6 @@ namespace mrpt
 				ASSERT_( COV1.isSquare() && COV2.isSquare() );
 				ASSERT_( size(COV1,1)==size(COV2,1));
 			#endif
-			const size_t N = size(COV1,1);
 			MAT1 COV = COV1;
 			COV+=COV2;
 			COV.substract_An(CROSS_COV12,2);
@@ -113,7 +112,7 @@ namespace mrpt
 		mahalanobisDistance2(const VECTORLIKE &delta_mu,const MATRIXLIKE &cov)
 		{
 			ASSERTDEB_(cov.isSquare())
-			ASSERTDEB_(cov.getColCount()==delta_mu.size())
+			ASSERTDEB_(size_t(cov.getColCount())==size_t(delta_mu.size()))
 			return multiply_HCHt_scalar(delta_mu,cov.inverse());
 		}
 
