@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -18,9 +18,9 @@ namespace poses
 {
 	DEFINE_SERIALIZABLE_PRE( CPose2D )
 
-	/** A class used to store a 2D pose.
-	 *    A class used to store a 2D pose, including the 2D coordinate
-	 *      point and a heading (phi) angle.
+	/** A class used to store a 2D pose, including the 2D coordinate point and a heading (phi) angle.
+	 *  Use this class instead of lightweight mrpt::math::TPose2D when pose/point composition is to be called
+	 *  multiple times with the same pose, since this class caches calls to expensive trigronometric functions.
 	 *
 	 *  For a complete description of Points/Poses, see mrpt::poses::CPoseOrPoint, or refer
 	 *    to the <a href="http://www.mrpt.org/2D_3D_Geometry" >2D/3D Geometry tutorial</a> in the wiki.
@@ -66,13 +66,13 @@ namespace poses
 		 CPose2D(const double x,const double y,const double phi);
 
 		 /** Constructor from a CPoint2D object. */
-		 CPose2D(const CPoint2D &);
+		 explicit CPose2D(const CPoint2D &);
 
 		 /** Aproximation!! Avoid its use, since information is lost. */
 		 explicit CPose2D(const CPose3D &);
 
 		 /** Constructor from lightweight object. */
-		 CPose2D(const mrpt::math::TPose2D &);
+		 explicit CPose2D(const mrpt::math::TPose2D &);
 
 		 /** Constructor from CPoint3D with information loss. */
 		 explicit CPose2D(const CPoint3D &);
@@ -130,14 +130,21 @@ namespace poses
 		 /** An alternative, slightly more efficient way of doing \f$ G = P \oplus L \f$ with G and L being 2D points and P this 2D pose.  */
 		 void composePoint(double lx,double ly,double &gx, double &gy) const;
 
-		 /** \overload \f$ G = P \oplus L \f$ with G and L being 2D points and P this 2D pose */
+		 /** overload \f$ G = P \oplus L \f$ with G and L being 2D points and P this 2D pose */
 		 void composePoint(const mrpt::math::TPoint2D &l, mrpt::math::TPoint2D &g) const;
 
-		 /** \overload \f$ G = P \oplus L \f$ with G and L being 3D points and P this 2D pose (the "z" coordinate remains unmodified) */
+		 /** overload \f$ G = P \oplus L \f$ with G and L being 3D points and P this 2D pose (the "z" coordinate remains unmodified) */
 		 void composePoint(const mrpt::math::TPoint3D &l, mrpt::math::TPoint3D &g) const;
-		 /** \overload (the "z" coordinate remains unmodified) */
+		 /** overload (the "z" coordinate remains unmodified) */
 		 void composePoint(double lx,double ly,double lz, double &gx, double &gy, double &gz) const;
 
+		/**  Computes the 2D point L such as \f$ L = G \ominus this \f$. \sa composePoint, composeFrom */
+		void inverseComposePoint(const double gx,const double gy, double &lx,double &ly) const;
+		/** \overload */
+		inline void inverseComposePoint(const mrpt::math::TPoint2D &g, mrpt::math::TPoint2D &l) const {
+			inverseComposePoint(g.x,g.y, l.x,l.y);
+		}
+
 		 /** The operator \f$ u' = this \oplus u \f$ is the pose/point compounding operator. */
 		 CPoint3D operator + (const CPoint3D& u) const ;
 
@@ -150,7 +157,7 @@ namespace poses
 		/** Convert this pose into its inverse, saving the result in itself. \sa operator- */
 		void inverse();
 
-		/** Compute \f$ RET = this \oplus b \f$  */
+		/** Compute \f$ RET = this \ominus b \f$  */
 		inline CPose2D  operator - (const CPose2D& b) const
 		{
 			CPose2D ret(UNINITIALIZED_POSE);
@@ -165,7 +172,7 @@ namespace poses
 		 /** Scalar sum of components: This is diferent from poses
 		  *    composition, which is implemented as "+" operators in "CPose" derived classes.
 		  */
-		 void AddComponents(CPose2D &p);
+		 void AddComponents(const CPose2D &p);
 
 		 /** Scalar multiplication.
 		  */
