@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -89,13 +89,13 @@ namespace poses
 		/** Returns an estimate of the pose covariance matrix (6x6 cov matrix) and the mean, both at once.
 		  * \sa getMean
 		  */
-		void getCovarianceAndMean(mrpt::math::CMatrixDouble66 &cov,CPose3D &mean_point) const  MRPT_OVERRIDE{
-			cov = this->cov;
+		void getCovarianceAndMean(mrpt::math::CMatrixDouble66 &out_cov,CPose3D &mean_point) const  MRPT_OVERRIDE{
+			out_cov = this->cov;
 			mean_point = this->mean;
 		}
 
-        void asString(std::string &s) const;
-        inline std::string asString() const { std::string s; asString(s); return s; }
+		void asString(std::string &s) const;
+		inline std::string asString() const { std::string s; asString(s); return s; }
 
 		/** Copy operator, translating if necesary (for example, between particles and gaussian representations)
 		  */
