@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -26,10 +26,13 @@ namespace mrpt
 		/** Returns the name of a proposed temporary file name */
 		std::string BASE_IMPEXP getTempFileName();
 
-		/** Returns the current working directory.
-		  */
+		/** Returns the current working directory  */
 		std::string BASE_IMPEXP getcwd();
 
+		/** Attempts to find the directory `[PREFIX/]share/mrpt/` and returns its absolute path, or empty string if not found. 
+		  * Example return paths: Linux after installing = `/usr/share/mrpt/`; manually-built system = `[CMAKE_SOURCE_DIR]/share/mrpt/`, etc.  */
+		std::string BASE_IMPEXP getShareMRPTDir();
+
 		/** Creates a directory
 		  * \return Returns false on any error, true on directory created or already existed.
 		  */
@@ -87,10 +90,10 @@ namespace mrpt
 		  */
 		bool BASE_IMPEXP directoryExists(const std::string& fileName);
 
-		/** Replace invalid filename chars by underscores ('_').
-		  *  Invalid chars are identified by those not being alphanumeric or: ".-#%$&()+[]{}"
+		/** Replace invalid filename chars by underscores ('_') or any other user-given char.
+		  *  Invalid chars are: '<','>',':','"','/','\\','|','?','*'
 		  */
-		std::string BASE_IMPEXP fileNameStripInvalidChars( const std::string &filename);
+		std::string BASE_IMPEXP fileNameStripInvalidChars( const std::string &filename, const char replacement_to_invalid_chars = '_');
 
 		/** Replace the filename extension by another one.
 		  *  Example:
