@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -112,16 +112,16 @@ namespace mrpt
 	#define MRPT_MAKE_ALIGNED_OPERATOR_NEW \
 		void *operator new(size_t size)  { return mrpt::system::os::aligned_malloc(size,16); } \
 		void *operator new[](size_t size){ return mrpt::system::os::aligned_malloc(size,16); } \
-		void operator delete(void * ptr) throw() { mrpt::system::os::aligned_free(ptr); } \
-		void operator delete[](void * ptr) throw() { mrpt::system::os::aligned_free(ptr); } \
+		void operator delete(void * ptr) MRPT_NO_THROWS { mrpt::system::os::aligned_free(ptr); } \
+		void operator delete[](void * ptr) MRPT_NO_THROWS { mrpt::system::os::aligned_free(ptr); } \
 		/* in-place new and delete. since (at least afaik) there is no actual   */ \
 		/* memory allocated we can safely let the default implementation handle */ \
 		/* this particular case. */ \
 		static void *operator new(size_t size, void *ptr) { return ::operator new(size,ptr); } \
-		void operator delete(void * memory, void *ptr) throw() { return ::operator delete(memory,ptr); } \
+		void operator delete(void * memory, void *ptr) MRPT_NO_THROWS { return ::operator delete(memory,ptr); } \
 		/* nothrow-new (returns zero instead of std::bad_alloc) */ \
-		void* operator new(size_t size, const std::nothrow_t&) throw() { try { return mrpt::system::os::aligned_malloc(size,16); } catch (...) { return 0; } return 0; } \
-		void operator delete(void *ptr, const std::nothrow_t&) throw() { mrpt::system::os::aligned_free(ptr); }
+		void* operator new(size_t size, const std::nothrow_t&) MRPT_NO_THROWS { try { return mrpt::system::os::aligned_malloc(size,16); } catch (...) { return 0; } } \
+		void operator delete(void *ptr, const std::nothrow_t&) MRPT_NO_THROWS { mrpt::system::os::aligned_free(ptr); }
 
 	} // End of namespace
 } // End of namespace
