@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -66,11 +66,6 @@ namespace mrpt
 			  */
 			int BASE_IMPEXP fprintf(FILE *fil, const char *format, ...)  MRPT_NO_THROWS MRPT_printf_format_check(2,3);
 
-			/** An OS-independent version of fscanf
-			  * \return The number of fields correctly assigned
-			  */
-			//int BASE_IMPEXP fscanf(FILE *fil, const char *format, ...)  MRPT_NO_THROWS MRPT_scanf_format_check(2,3);
-
 			/** An OS-independent version of fclose.
 			  * \exception std::exception On trying to close a NULL file descriptor.
 			  */
@@ -120,10 +115,10 @@ namespace mrpt
 			/** An OS and compiler independent version of "memcpy"
 			  */
 			void BASE_IMPEXP memcpy(
-				void		*dest,
-				size_t		destSize,
+				void *dest,
+				size_t destSize,
 				const void	*src,
-				size_t		copyCount ) MRPT_NO_THROWS;
+				size_t copyCount) MRPT_NO_THROWS;
 
 			/** An OS-independent version of getch, which waits until a key is pushed.
 			  * \return The pushed key code
@@ -142,7 +137,7 @@ namespace mrpt
 		  * @{ */
 
 		/** Shows the message "Press any key to continue" (or other custom message) to the current standard output and returns when a key is pressed */
-		void BASE_IMPEXP pause(const std::string &msg = std::string("Press any key to continue...") ) MRPT_NO_THROWS;
+		void BASE_IMPEXP pause(const std::string &msg = std::string("Press any key to continue...")) MRPT_NO_THROWS;
 
 		/** Clears the console window */
 		void BASE_IMPEXP clearConsole();
@@ -156,10 +151,8 @@ namespace mrpt
 		/** Returns a const ref to a text with the same text that appears at the beginning of each MRPT file (useful for displaying the License text in GUIs) */
 		const std::string BASE_IMPEXP & getMRPTLicense();
 
-		/** Since MRPT 1.3.0 this function does nothing */
-		MRPT_DECLARE_DEPRECATED_FUNCTION("Deprecated: This function does nothing now. Do not call it.",
-		void BASE_IMPEXP registerFatalExceptionHandlers()
-		);
+		/** Finds the "[MRPT]/share/mrpt/" directory, if available in the system. This searches in (1) source code tree, (2) install target paths. */
+		std::string BASE_IMPEXP find_mrpt_shared_dir();
 
 		/** For use in  setConsoleColor */
 		enum TConsoleColor
@@ -175,7 +168,23 @@ namespace mrpt
 		  *
 		  * By default the color of "cout" is changed, unless changeStdErr=true, in which case "cerr" is changed.
 		  */
-		void BASE_IMPEXP setConsoleColor( TConsoleColor color, bool changeStdErr=false );
+		void BASE_IMPEXP setConsoleColor(TConsoleColor color, bool changeStdErr=false);
+
+		/** @brief Execute Generic Shell Command
+ 		 *
+ 		 * @param[in]   command Command to execute
+ 		 * @param[out]  output  Pointer to string containing the shell output
+ 		 * @param[in]   mode read/write access
+ 		 *
+ 		 * @return 0 for success, -1 otherwise.
+ 		 *
+ 		 * \note Original code snippet found in http://stackoverflow.com/a/30357710
+ 		 */
+		int BASE_IMPEXP executeCommand(
+				const std::string&  command,
+    		std::string* output=NULL,
+    		const std::string&  mode="r");
+
 
 		/** @} */
 
