@@ -59,7 +59,7 @@ namespace mrpt
 			uint64_t getPosition()  MRPT_OVERRIDE; //!< Method for getting the current cursor position, where 0 is the first byte and TotalBytesCount-1 the last one.
 
 			/** This method is not implemented in this class */
-			uint64_t Seek(uint64_t Offset, CStream::TSeekOrigin Origin = sFromBeginning)  MRPT_OVERRIDE
+			uint64_t Seek(int64_t Offset, CStream::TSeekOrigin Origin = sFromBeginning)  MRPT_OVERRIDE
 			{
 				MRPT_UNUSED_PARAM(Offset); MRPT_UNUSED_PARAM(Origin);
 				THROW_EXCEPTION("Seek is not implemented in this class");
