@@ -54,7 +54,7 @@ namespace utils
 		void changeSize( uint64_t newSize ); //!< Change size. This would be rarely used. Use ">>" operators for writing to stream \sa Stream
 
 		// See docs in base class
-		uint64_t Seek(uint64_t Offset, CStream::TSeekOrigin Origin = sFromBeginning) MRPT_OVERRIDE;
+		uint64_t Seek(int64_t Offset, CStream::TSeekOrigin Origin = sFromBeginning) MRPT_OVERRIDE;
 		/** Returns the total size of the internal buffer  */
 		uint64_t getTotalBytesCount() MRPT_OVERRIDE;
 		/** Method for getting the current cursor position, where 0 is the first byte and TotalBytesCount-1 the last one */
