@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -43,7 +43,7 @@ namespace mrpt
 					m_in.clear();
 					m_in.open(fil.c_str());
 					if (!m_in.is_open())
-						THROW_EXCEPTION_CUSTOM_MSG1("Error opening file '%s' for reading",fil.c_str());
+						THROW_EXCEPTION_FMT("Error opening file '%s' for reading",fil.c_str());
 				}
 
 				/** Close the file (no need to call it normally, the file is closed upon destruction) */
