@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -13,6 +13,7 @@
 #include <vector>
 #include <mrpt/base/link_pragmas.h>
 #include <mrpt/poses/poses_frwds.h>
+#include <ostream>
 
 namespace mrpt
 {
@@ -45,6 +46,16 @@ namespace mrpt
 			{
 			}
 
+			friend std::ostream& operator<<(
+					std::ostream& o,
+					const mrpt::utils::TMatchingPair& pair) {
+				o << "[" << pair.this_idx << "->" << pair.other_idx << "]"  << ": "
+					<< "(" << pair.this_x << "," << pair.this_y << "," << pair.this_z << ")" << " -> "
+					<< "(" << pair.other_x << "," << pair.other_y << "," << pair.other_z << ")";
+
+				return o;
+			}
+
 			unsigned int	this_idx;
 			unsigned int	other_idx;
 			float			this_x,this_y,this_z;
@@ -59,6 +70,7 @@ namespace mrpt
 
 
 		typedef TMatchingPair*  TMatchingPairPtr;
+		typedef TMatchingPair const *  TMatchingPairConstPtr;
 
 		/** A list of TMatchingPair
 		 * \ingroup mrpt_base_grp
@@ -111,6 +123,11 @@ namespace mrpt
 
 			/** Test whether the given pair "p" is within the pairings */
 			bool contains (const TMatchingPair &p) const;
+
+			/** Creates a filtered list of pairings with those ones which have a single correspondence which coincides 
+			  * in both directions, i.e. the best pairing of element `i` in map `this` is the best match for element `j` in map `other`, 
+			  * and viceversa*/
+			void filterUniqueRobustPairs(const size_t num_elements_this_map, TMatchingPairList &out_filtered_list) const;
 		};
 
 		/** A comparison operator, for sorting lists of TMatchingPair's, first order by this_idx, if equals, by other_idx   */
