@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -10,11 +10,12 @@
 #pragma once
 
 #include <mrpt/config.h>
-#include <mrpt/version.h>
 #if MRPT_ENABLE_PRECOMPILED_HDRS
 
 #include <mrpt/utils/utils_defs.h>
+#include <mrpt/utils/types_math.h>  // Include Eigen large headers here!
 #include <mrpt/utils/CObject.h>
+#include <mrpt/utils/CSerializable.h>
 #include <mrpt/math/ops_containers.h>
 #include <mrpt/math/ops_matrices.h>
 #include <mrpt/math/ops_vectors.h>
