@@ -2,18 +2,26 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "base-precomp.h"  // Precompiled headers
 
-#include <mrpt/bayes/CParticleFilter.h>
-#include <mrpt/bayes/CParticleFilterCapable.h>
-#include <mrpt/bayes/CParticleFilterData.h>
-#include <mrpt/utils/CStream.h>
-#include <mrpt/utils/CConfigFileBase.h>  // For MRPT_LOAD_*
+#include <cmath>                                // for exp
+#include <mrpt/bayes/CParticleFilter.h>         // for CParticleFilter::TPar...
+#include <mrpt/bayes/CParticleFilterCapable.h>  // for CParticleFilterCapable
+#include <mrpt/utils/CConfigFileBase.h>         // for CConfigFileBase, MRPT...
+#include <mrpt/utils/CStream.h>                 // for CStream
+#include <stddef.h>                             // for size_t
+#include <exception>                            // for exception
+#include <string>                               // for string, allocator
+#include <mrpt/utils/COutputLogger.h>           // for COutputLogger, MRPT_L...
+#include <mrpt/utils/bits.h>                    // for format, square
+#include <mrpt/utils/mrpt_macros.h>             // for MRPT_END, MRPT_START, e
+namespace mrpt { namespace obs { class CActionCollection; } }
+namespace mrpt { namespace obs { class CSensoryFrame; } }
 
 using namespace mrpt::bayes;
 using namespace mrpt::utils;
@@ -21,11 +29,12 @@ using namespace mrpt::utils;
 /*---------------------------------------------------------------
 						Default Constructor
   ---------------------------------------------------------------*/
-CParticleFilter::CParticleFilter() : m_options()
+CParticleFilter::CParticleFilter() :
+	mrpt::utils::COutputLogger("CParticleFilter"),
+	m_options()
 {
 }
 
-
 /*---------------------------------------------------------------
 					executeOn
 Executes a prediction-update stage of particle filtering. This includes:
@@ -82,8 +91,7 @@ void  CParticleFilter::executeOn(
 	{
 		if (obj.ESS() < m_options.BETA)
 		{
-			if (m_options.verbose)
-				printf_debug("[PF] Resampling particles (ESS was %.02f)\n", obj.ESS());
+			MRPT_LOG_DEBUG(mrpt::format("Resampling particles (ESS was %.02f)\n", obj.ESS()));
 			obj.performResampling( m_options );	// Resample
 		}
 	}
@@ -105,7 +113,6 @@ CParticleFilter::TParticleFilterOptions::TParticleFilterOptions() :
 	resamplingMethod		( prMultinomial ),
 	max_loglikelihood_dyn_range ( 15 ),
 	pfAuxFilterStandard_FirstStageWeightsMonteCarlo ( false ),
-	verbose	(false),
 	pfAuxFilterOptimal_MLE(false)
 {
 }
@@ -166,7 +173,6 @@ void  CParticleFilter::TParticleFilterOptions::loadFromConfigFile(
 	MRPT_LOAD_CONFIG_VAR(powFactor,double,						iniFile,section.c_str());
 	MRPT_LOAD_CONFIG_VAR(max_loglikelihood_dyn_range,double,	iniFile,section.c_str());
 	ASSERT_(max_loglikelihood_dyn_range>=0)
-	MRPT_LOAD_CONFIG_VAR(verbose,bool,	iniFile,section.c_str());
 
 
 	MRPT_LOAD_CONFIG_VAR_CAST_NO_DEFAULT(PF_algorithm,int,TParticleFilterAlgorithm,			iniFile,section.c_str());
