@@ -2,14 +2,16 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 
 #include <mrpt/math/geometry.h>
+#include <mrpt/math/CPolygon.h>
 #include <gtest/gtest.h>
+#include <algorithm>
 
 using namespace mrpt;
 using namespace mrpt::utils;
@@ -65,6 +67,7 @@ TEST(Geometry, Segment2DIntersect)
 		EXPECT_FALSE(do_inter);
 	}
 
+#if 0
 	{
 		// Two parallel segments that do NOT intersect: result is a "segment in the middle".
 		const TSegment2D s1(TPoint2D(-0.05,0.05), TPoint2D(-0.05,-0.05));
@@ -75,40 +78,68 @@ TEST(Geometry, Segment2DIntersect)
 
 		EXPECT_TRUE(do_inter && inter.getType()==GEOMETRIC_TYPE_SEGMENT);
 	}
+#endif
 }
 
-void myTestPolygonContainsPoint(std::vector<TPoint2D> &vs)
+void myTestPolygonContainsPoint(std::vector<TPoint2D> &vs, bool convex)
 {
 	const mrpt::math::TPolygon2D poly(vs);
 
+	EXPECT_EQ(poly.isConvex(),convex);
+
 	EXPECT_TRUE( poly.contains( TPoint2D(0.0, 0.0) ) );
 	EXPECT_TRUE( poly.contains( TPoint2D(0.0, 0.9) ) );
 	EXPECT_TRUE( poly.contains( TPoint2D(-0.9, -0.9) ) );
 	EXPECT_TRUE( poly.contains( TPoint2D(0.9, -0.9) ) );
 
-	EXPECT_FALSE( poly.contains( TPoint2D(-1.1, -1.1) ) );
-	EXPECT_FALSE( poly.contains( TPoint2D( 1.1, -1.1) ) );
-	EXPECT_FALSE( poly.contains( TPoint2D( 0, 1.1) ) );
+	EXPECT_FALSE( poly.contains( TPoint2D(-4.0, -5.1) ) );
+	EXPECT_FALSE( poly.contains( TPoint2D(-5.0, -0.1) ) );
+	EXPECT_FALSE( poly.contains( TPoint2D( 1.1, -6.1) ) );
+	EXPECT_FALSE( poly.contains( TPoint2D( 0, 5.1) ) );
 	EXPECT_FALSE( poly.contains( TPoint2D( 0, -1.1) ) );
 }
 
-TEST(Geometry, PolygonContainsPoint)
+TEST(Geometry, PolygonConvexContainsPoint)
 {
 	// Test with a polygon in one winding order:
-	{
-		std::vector<TPoint2D> vs;
-		vs.push_back(TPoint2D(-1.0, -1.0));
-		vs.push_back(TPoint2D( 0.0,  1.0));
-		vs.push_back(TPoint2D( 1.0, -1.0));
-		myTestPolygonContainsPoint(vs);
-	}
+	std::vector<TPoint2D> vs;
+	vs.push_back(TPoint2D(-1.0, -1.0));
+	vs.push_back(TPoint2D( 0.0,  1.0));
+	vs.push_back(TPoint2D( 1.0, -1.0));
+	myTestPolygonContainsPoint(vs, true);
+
 	// and the other:
+	std::reverse(vs.begin(),vs.end());
+	myTestPolygonContainsPoint(vs, true);
+
 	{
-		std::vector<TPoint2D> vs;
-		vs.push_back(TPoint2D( 1.0, -1.0));
-		vs.push_back(TPoint2D( 0.0,  1.0));
-		vs.push_back(TPoint2D(-1.0, -1.0));
-		myTestPolygonContainsPoint(vs);
+		mrpt::math::CPolygon p;
+		p.AddVertex(0, -0.322);
+		p.AddVertex(-0.644, -0.322);
+		p.AddVertex(-0.210377, -0.324673);
+		p.AddVertex(0.433623, -0.324673);
+
+		EXPECT_FALSE (p.contains(TPoint2D(0.73175, -0.325796)));
 	}
 }
 
+TEST(Geometry, PolygonConcaveContainsPoint)
+{
+	// Test with a polygon in one winding order:
+	std::vector<TPoint2D> vs;
+	vs.push_back(TPoint2D(-2.0,  3.0));
+	vs.push_back(TPoint2D( 2.0,  2.0));
+	vs.push_back(TPoint2D( 3.0, -4.0));
+	vs.push_back(TPoint2D( 0.1, -3.0));
+	vs.push_back(TPoint2D( 0.1, -0.1));
+	vs.push_back(TPoint2D(-0.1, -0.1));
+	vs.push_back(TPoint2D(-0.1, -3.0));
+	vs.push_back(TPoint2D(-2.0, -2.0));
+
+	myTestPolygonContainsPoint(vs,false);
+
+	// and the other:
+	std::reverse(vs.begin(),vs.end());
+	myTestPolygonContainsPoint(vs,false);
+}
+
