@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -14,6 +14,7 @@
 #include <mrpt/poses/CPoint3D.h>
 #include <mrpt/poses/CPose2D.h>
 #include <mrpt/poses/CPose3DQuat.h>
+#include <mrpt/math/CQuaternion.h>
 #include <mrpt/math/geometry.h>
 #include <mrpt/math/ops_containers.h>
 #include <mrpt/utils/CStream.h>
@@ -63,7 +64,6 @@ TPose2D::TPose2D(const mrpt::poses::CPose2D &p):x(p.x()),y(p.y()),phi(p.phi())	{
 void TPose2D::asString(std::string &s) const {
 	s = mrpt::format("[%f %f %f]",x,y,mrpt::utils::RAD2DEG(phi));
 }
-
 void TPose2D::fromString(const std::string &s)
 {
 	CMatrixDouble  m;
@@ -73,6 +73,94 @@ void TPose2D::fromString(const std::string &s)
 	y = m.get_unsafe(0,1);
 	phi = DEG2RAD(m.get_unsafe(0,2));
 }
+mrpt::math::TPose2D mrpt::math::TPose2D::operator+(const mrpt::math::TPose2D & b) const
+{
+	const double A_cosphi = cos(this->phi), A_sinphi = sin(this->phi);
+	// Use temporary variables for the cases (A==this) or (B==this)
+	const double new_x = this->x + b.x * A_cosphi - b.y * A_sinphi;
+	const double new_y = this->y + b.x * A_cosphi + b.y * A_sinphi;
+	const double new_phi = mrpt::math::wrapToPi(this->phi + b.phi);
+
+	return mrpt::math::TPose2D(new_x, new_y, new_phi);
+}
+
+mrpt::math::TPose2D mrpt::math::TPose2D::operator-(const mrpt::math::TPose2D & b) const
+{
+	const double B_cosphi = cos(b.phi), B_sinphi = sin(b.phi);
+
+	const double new_x = (this->x - b.x) * B_cosphi + (this->y - b.y) * B_sinphi;
+	const double new_y = -(this->x - b.x) * B_sinphi + (this->y - b.y) * B_cosphi;
+	const double new_phi = mrpt::math::wrapToPi(this->phi - b.phi);
+
+	return mrpt::math::TPose2D(new_x, new_y, new_phi);
+}
+
+// ----
+void TTwist2D::asString(std::string &s) const {
+	s = mrpt::format("[%f %f %f]",vx,vy,mrpt::utils::RAD2DEG(omega));
+}
+void TTwist2D::fromString(const std::string &s)
+{
+	CMatrixDouble  m;
+	if (!m.fromMatlabStringFormat(s)) THROW_EXCEPTION("Malformed expression in ::fromString");
+	ASSERTMSG_(mrpt::math::size(m,1)==1 && mrpt::math::size(m,2)==3, "Wrong size of vector in ::fromString");
+	vx = m.get_unsafe(0,0);
+	vy = m.get_unsafe(0,1);
+	omega = DEG2RAD(m.get_unsafe(0,2));
+}
+// Transform the (vx,vy) components for a counterclockwise rotation of `ang` radians
+void TTwist2D::rotate(const double ang)
+{
+	const double nvx = vx * cos(ang) - vy * sin(ang);
+	const double nvy = vx * sin(ang) + vy * cos(ang);
+	vx = nvx;
+	vy = nvy;
+}
+bool TTwist2D::operator ==(const TTwist2D&o) const
+{
+	return vx == o.vx && vy == o.vy && omega == o.omega;
+}
+bool TTwist2D::operator !=(const TTwist2D&o) const {
+	return !(*this==o);
+}
+mrpt::math::TPose2D TTwist2D::operator*(const double dt) const
+{
+	return mrpt::math::TPose2D(vx*dt,vy*dt,omega*dt);
+}
+
+// ----
+void TTwist3D::asString(std::string &s) const {
+	s = mrpt::format("[%f %f %f  %f %f %f]",vx,vy,vz, mrpt::utils::RAD2DEG(wx),mrpt::utils::RAD2DEG(wy),mrpt::utils::RAD2DEG(wz));
+}
+void TTwist3D::fromString(const std::string &s)
+{
+	CMatrixDouble  m;
+	if (!m.fromMatlabStringFormat(s)) THROW_EXCEPTION("Malformed expression in ::fromString");
+	ASSERTMSG_(mrpt::math::size(m,1)==1 && mrpt::math::size(m,2)==6, "Wrong size of vector in ::fromString");
+	for (int i=0;i<3;i++) (*this)[i] = m.get_unsafe(0,i);
+	for (int i=0;i<3;i++) (*this)[3+i] = DEG2RAD(m.get_unsafe(0,3+i));
+}
+// Transform all 6 components for a change of reference frame from "A" to
+// another frame "B" whose rotation with respect to "A" is given by `rot`. The translational part of the pose is ignored
+void TTwist3D::rotate(const mrpt::poses::CPose3D & rot)
+{
+	const TTwist3D t = *this;
+	const mrpt::math::CMatrixDouble33 & R = rot.getRotationMatrix();
+	vx=R(0,0)*t.vx+R(0,1)*t.vy+R(0,2)*t.vz;
+	vy=R(1,0)*t.vx+R(1,1)*t.vy+R(1,2)*t.vz;
+	vz=R(2,0)*t.vx+R(2,1)*t.vy+R(2,2)*t.vz;
+
+	wx=R(0,0)*t.wx+R(0,1)*t.wy+R(0,2)*t.wz;
+	wy=R(1,0)*t.wx+R(1,1)*t.wy+R(1,2)*t.wz;
+	wz=R(2,0)*t.wx+R(2,1)*t.wy+R(2,2)*t.wz;
+}
+bool TTwist3D::operator ==(const TTwist3D&o) const
+{
+	return vx == o.vx && vy == o.vy && vz == o.vz && wx == o.wx && wy == o.wy && wz == o.wz;
+}
+bool TTwist3D::operator !=(const TTwist3D&o) const {
+	return !(*this == o);
+}
 
 TPoint3D::TPoint3D(const TPoint2D &p):x(p.x),y(p.y),z(0.0)	{}
 TPoint3D::TPoint3D(const TPose2D &p):x(p.x),y(p.y),z(0.0)	{}
@@ -103,6 +191,41 @@ TPose3D::TPose3D(const mrpt::poses::CPose3D &p):x(p.x()),y(p.y()),z(p.z()),yaw(p
 void TPose3D::asString(std::string &s) const {
 	s = mrpt::format("[%f %f %f %f %f %f]",x,y,z,RAD2DEG(yaw),RAD2DEG(pitch),RAD2DEG(roll));
 }
+void TPose3D::getAsQuaternion(mrpt::math::CQuaternion<double> & q, mrpt::math::CMatrixFixedNumeric<double, 4, 3>* out_dq_dr) const
+{
+	// See: http://en.wikipedia.org/wiki/Conversion_between_quaternions_and_Euler_angles
+	const double cy = cos(yaw*0.5),  sy = sin(yaw*0.5);
+	const double cp = cos(pitch*0.5),sp = sin(pitch*0.5);
+	const double cr = cos(roll*0.5), sr = sin(roll*0.5);
+
+	const double ccc = cr*cp*cy;
+	const double ccs = cr*cp*sy;
+	const double css = cr*sp*sy;
+	const double sss = sr*sp*sy;
+	const double scc = sr*cp*cy;
+	const double ssc = sr*sp*cy;
+	const double csc = cr*sp*cy;
+	const double scs = sr*cp*sy;
+
+	q[0] = ccc + sss;
+	q[1] = scc - css;
+	q[2] = csc + scs;
+	q[3] = ccs - ssc;
+
+	// Compute 4x3 Jacobian: for details, see technical report:
+	//   Parameterizations of SE(3) transformations: equivalences, compositions and uncertainty, J.L. Blanco (2010).
+	//   http://www.mrpt.org/6D_poses:equivalences_compositions_and_uncertainty
+	if (out_dq_dr)
+	{
+		MRPT_ALIGN16 const double nums[4 * 3] = {
+			-0.5*q[3], 0.5*(-csc + scs), -0.5*q[1],
+			-0.5*q[2],  0.5*(-ssc - ccs), 0.5* q[0],
+			0.5*q[1], 0.5*(ccc - sss),  0.5*q[3],
+			0.5* q[0], 0.5*(-css - scc), -0.5*q[2]
+		};
+		out_dq_dr->loadFromArray(nums);
+	}
+}
 void TPose3D::fromString(const std::string &s)
 {
 	CMatrixDouble  m;
@@ -157,13 +280,15 @@ double TSegment2D::distance(const TPoint2D &point) const {
 double TSegment2D::signedDistance(const TPoint2D &point) const	{
 	//It is reckoned whether the perpendicular line to the TSegment2D which passes through point crosses or not the referred segment,
 	//or what is the same, whether point makes an obtuse triangle with the segment or not (being the longest segment one between the point and either end of TSegment2D).
-	double d1, d2, d3, ds1, ds2, ds3;
-	d1 = math::distance(point,point1);
-	d2 = math::distance(point,point2);
-	d3 = length();
-	ds1 = square(d1);
-	ds2 = square(d2);
-	ds3 = square(d3);
+	const double d1 = math::distance(point,point1);
+	if (point1 == point2)
+		return d1;
+
+	const double d2 = math::distance(point,point2);
+	const double d3 = length();
+	const double ds1 = square(d1);
+	const double ds2 = square(d2);
+	const double ds3 = square(d3);
 	if ( ds1 > (ds2 + ds3) || ds2 > (ds1 + ds3) )
 		 // Fix sign:
 		 return min(d1,d2) * ( TLine2D(*this).signedDistance(point)<0 ? -1:1);
@@ -321,7 +446,7 @@ void TLine2D::getAsPose2DForcingOrigin(const TPoint2D &origin,mrpt::poses::CPose
 	//Line's director vector is (-coefs[1],coefs[0]).
 	outPose.phi( atan2(coefs[0],-coefs[1]) );
 }
-TLine2D::TLine2D(const TPoint2D &p1,const TPoint2D &p2) throw(std::logic_error)	{
+TLine2D::TLine2D(const TPoint2D &p1,const TPoint2D &p2)	{
 	if (p1==p2) throw logic_error("Both points are the same");
 	coefs[0]=p2.y-p1.y;
 	coefs[1]=p1.x-p2.x;
@@ -364,11 +489,10 @@ double TLine3D::distance(const TPoint3D &point) const	{
 	return sqrt(d2-(dv*dv)/v2);
 }
 void TLine3D::unitarize()	{
-	//double s=sqrt(director[0]*director[0]+director[1]*director[1]+director[2]*director[2]);
 	double s=sqrt(squareNorm<3,double>(director));
 	for (size_t i=0;i<3;i++) director[i]/=s;
 }
-TLine3D::TLine3D(const TPoint3D &p1,const TPoint3D &p2) throw(std::logic_error)	{
+TLine3D::TLine3D(const TPoint3D &p1,const TPoint3D &p2){
 	if (abs(math::distance(p1,p2))<geometryEpsilon) throw logic_error("Both points are the same");
 	pBase=p1;
 	director[0]=p2.x-p1.x;
@@ -397,7 +521,6 @@ TLine3D::TLine3D(const TLine2D &l)	{
 }
 
 double TPlane::evaluatePoint(const TPoint3D &point) const	{
-	//return coefs[0]*point.x+coefs[1]*point.y+coefs[2]*point.z+coefs[3];
 	return dotProduct<3,double>(coefs,point)+coefs[3];
 }
 bool TPlane::contains(const TPoint3D &point) const	{
@@ -408,7 +531,6 @@ bool TPlane::contains(const TLine3D &line) const	{
 	return abs(getAngle(*this,line))<geometryEpsilon;	//Plane's normal must be normal to director vector
 }
 double TPlane::distance(const TPoint3D &point) const	{
-	//return abs(evaluatePoint(point))/sqrt(coefs[0]*coefs[0]+coefs[1]*coefs[1]+coefs[2]*coefs[2]);
 	return abs(evaluatePoint(point))/sqrt(squareNorm<3,double>(coefs));
 }
 double TPlane::distance(const TLine3D &line) const	{
@@ -421,7 +543,6 @@ void TPlane::getNormalVector(double (&vector)[3]) const	{
 	vector[2]=coefs[2];
 }
 void TPlane::unitarize()	{
-//	double s=sqrt(coefs[0]*coefs[0]+coefs[1]*coefs[1]+coefs[2]*coefs[2]);
 	double s=sqrt(squareNorm<3,double>(coefs));
 	for (size_t i=0;i<4;i++) coefs[i]/=s;
 }
@@ -432,7 +553,6 @@ void TPlane::getAsPose3D(mrpt::poses::CPose3D &outPose)	{
 	getUnitaryNormalVector(normal);
 	CMatrixDouble AXIS;
 	generateAxisBaseFromDirectionAndAxis(normal,2,AXIS);
-	AXIS.set_unsafe(3,3,1);
 	for (size_t i=0;i<3;i++) if (abs(coefs[i])>=geometryEpsilon)	{
 		AXIS.set_unsafe(i,3,-coefs[3]/coefs[i]);
 		break;
@@ -445,11 +565,10 @@ void TPlane::getAsPose3DForcingOrigin(const TPoint3D &newOrigin,mrpt::poses::CPo
 	getUnitaryNormalVector(normal);
 	CMatrixDouble AXIS;
 	generateAxisBaseFromDirectionAndAxis(normal,2,AXIS);
-	AXIS.set_unsafe(3,3,1);
 	for (size_t i=0;i<3;i++) AXIS.set_unsafe(i,3,newOrigin[i]);
 	pose=mrpt::poses::CPose3D(AXIS);
 }
-TPlane::TPlane(const TPoint3D &p1,const TPoint3D &p2,const TPoint3D &p3)  throw(std::logic_error) {
+TPlane::TPlane(const TPoint3D &p1,const TPoint3D &p2,const TPoint3D &p3) {
 	double dx1=p2.x-p1.x;
 	double dy1=p2.y-p1.y;
 	double dz1=p2.z-p1.z;
@@ -462,7 +581,7 @@ TPlane::TPlane(const TPoint3D &p1,const TPoint3D &p2,const TPoint3D &p3)  throw(
 	if (abs(coefs[0])<geometryEpsilon&&abs(coefs[1])<geometryEpsilon&&abs(coefs[2])<geometryEpsilon) throw logic_error("Points are linearly dependent");
 	coefs[3]=-coefs[0]*p1.x-coefs[1]*p1.y-coefs[2]*p1.z;
 }
-TPlane::TPlane(const TPoint3D &p1,const TLine3D &r2) throw(std::logic_error)	{
+TPlane::TPlane(const TPoint3D &p1,const TLine3D &r2) {
 	double dx1=p1.x-r2.pBase.x;
 	double dy1=p1.y-r2.pBase.y;
 	double dz1=p1.z-r2.pBase.z;
@@ -472,7 +591,7 @@ TPlane::TPlane(const TPoint3D &p1,const TLine3D &r2) throw(std::logic_error)	{
 	if (abs(coefs[0])<geometryEpsilon&&abs(coefs[1])<geometryEpsilon&&abs(coefs[2])<geometryEpsilon) throw logic_error("Point is contained in the line");
 	coefs[3]=-coefs[0]*p1.x-coefs[1]*p1.y-coefs[2]*p1.z;
 }
-TPlane::TPlane(const TLine3D &r1,const TLine3D &r2) throw(std::logic_error)	{
+TPlane::TPlane(const TLine3D &r1,const TLine3D &r2) {
 	crossProduct3D(r1.director,r2.director,coefs);
 	coefs[3]=-coefs[0]*r1.pBase.x-coefs[1]*r1.pBase.y-coefs[2]*r1.pBase.z;
 	if (abs(coefs[0])<geometryEpsilon&&abs(coefs[1])<geometryEpsilon&&abs(coefs[2])<geometryEpsilon)	{
@@ -538,19 +657,57 @@ double TPolygon2D::distance(const TPoint2D &point) const	{
 	return distance;
 }
 
-bool TPolygon2D::contains(const TPoint2D &point) const	{
-	//Inefficient, but exact, method
-	std::vector<TSegment2D> sgs;
-	getAsSegmentList(sgs);
-	TPoint2D cntr;
-	getCenter(cntr);
-	for (vector<TSegment2D>::const_iterator it=sgs.begin();it!=sgs.end();++it)	{
-		TLine2D l=TLine2D(*it);
-		double val=l.evaluatePoint(point);
-		if (abs(val)<geometryEpsilon) continue;
-		else if (sign(val)!=sign(l.evaluatePoint(cntr))) return false;
+void TPolygon2D::getBoundingBox(TPoint2D &min_coords, TPoint2D&max_coords) const
+{
+	ASSERTMSG_(!this->empty(),"getBoundingBox() called on an empty polygon!");
+	min_coords.x = min_coords.y =  std::numeric_limits<double>::max();
+	max_coords.x = max_coords.y = -std::numeric_limits<double>::max();
+	for (size_t i=0;i<size();i++)
+	{
+		mrpt::utils::keep_min( min_coords.x, (*this)[i].x);
+		mrpt::utils::keep_min( min_coords.y, (*this)[i].y);
+		mrpt::utils::keep_max( max_coords.x, (*this)[i].x);
+		mrpt::utils::keep_max( max_coords.y, (*this)[i].y);
 	}
-	return true;
+}
+
+// isLeft(): tests if a point is Left|On|Right of an infinite line.
+//    Input:  three points P0, P1, and P2
+//    Return: >0 for P2 left of the line through P0 and P1
+//            =0 for P2  on the line
+//            <0 for P2  right of the line
+//    See: Algorithm 1 "Area of Triangles and Polygons"
+inline double isLeft( const mrpt::math::TPoint2D &P0, const mrpt::math::TPoint2D &P1, const mrpt::math::TPoint2D &P2 )
+{
+	return ( (P1.x - P0.x) * (P2.y - P0.y) - (P2.x -  P0.x) * (P1.y - P0.y) );
+}
+
+bool TPolygon2D::contains(const TPoint2D &P) const
+{
+	int wn = 0;    // the  winding number counter
+
+	// loop through all edges of the polygon
+	const size_t n = this->size();
+	for (size_t i=0; i<n; i++) // edge from V[i] to  V[i+1]
+	{
+		if ((*this)[i].y <= P.y)
+		{
+			// start y <= P.y
+			if ((*this)[(i+1) % n].y  > P.y)      // an upward crossing
+				if (isLeft( (*this)[i], (*this)[(i+1)%n], P) > 0)  // P left of  edge
+					++wn;            // have  a valid up intersect
+	}
+	else
+	{
+		// start y > P.y (no test needed)
+		if ((*this)[(i+1)%n].y  <= P.y)     // a downward crossing
+			if (isLeft( (*this)[i], (*this)[(i+1)%n], P) < 0)  // P right of  edge
+				--wn;            // have  a valid down intersect
+		}
+	}
+
+	return wn!=0;
+
 }
 void TPolygon2D::getAsSegmentList(vector<TSegment2D> &v) const	{
 	size_t N=size();
@@ -709,90 +866,6 @@ inline void TPolygon3D::createRegularPolygon(size_t numEdges,double radius,TPoly
 	for (size_t i=0;i<numEdges;i++) pose.composePoint(poly[i][0],poly[i][1],poly[i][2],poly[i][0],poly[i][1],poly[i][2]);
 }
 
-#ifdef TOBJECTS_USE_UNIONS
-void TObject2D::generate3DObject(TObject3D &obj) const	{
-	switch (type)	{
-		case GEOMETRIC_TYPE_POINT:
-			obj=TPoint3D(*(data.point));
-			break;
-		case GEOMETRIC_TYPE_SEGMENT:
-			obj=TSegment3D(*(data.segment));
-			break;
-		case GEOMETRIC_TYPE_LINE:
-			obj=TLine3D(*(data.line));
-			break;
-		case GEOMETRIC_TYPE_POLYGON:
-			obj=TPolygon3D(*(data.polygon));
-			break;
-		default:
-			obj=TObject3D();
-			break;
-	}
-}
-void TObject2D::getPoints(const std::vector<TObject2D> &objs,std::vector<TPoint2D> &pnts)	{
-	for (vector<TObject2D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPoint()) pnts.push_back(*(it->data.point));
-}
-void TObject2D::getSegments(const std::vector<TObject2D> &objs,std::vector<TSegment2D> &sgms)	{
-	for (vector<TObject2D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isSegment()) sgms.push_back(*(it->data.segment));
-}
-void TObject2D::getLines(const std::vector<TObject2D> &objs,std::vector<TLine2D> &lins)	{
-	for (vector<TObject2D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isLine()) lins.push_back(*(it->data.line));
-}
-void TObject2D::getPolygons(const std::vector<TObject2D> &objs,std::vector<TPolygon2D> &polys)	{
-	for (vector<TObject2D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPolygon()) polys.push_back(*(it->data.polygon));
-}
-void TObject2D::getPoints(const std::vector<TObject2D> &objs,std::vector<TPoint2D> &pnts,std::vector<TObject2D> &remainder)	{
-	for (vector<TObject2D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPoint()) pnts.push_back(*(it->data.point));
-	else remainder.push_back(*it);
-}
-void TObject2D::getSegments(const std::vector<TObject2D> &objs,std::vector<TSegment2D> &sgms,std::vector<TObject2D> &remainder)	{
-	for (vector<TObject2D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isSegment()) sgms.push_back(*(it->data.segment));
-	else remainder.push_back(*it);
-}
-void TObject2D::getLines(const std::vector<TObject2D> &objs,std::vector<TLine2D> &lins,std::vector<TObject2D> &remainder)	{
-	for (vector<TObject2D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isLine()) lins.push_back(*(it->data.line));
-	else remainder.push_back(*it);
-}
-void TObject2D::getPolygons(const std::vector<TObject2D> &objs,std::vector<TPolygon2D> &polys,vector<TObject2D> &remainder)	{
-	for (vector<TObject2D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPolygon()) polys.push_back(*(it->data.polygon));
-	else remainder.push_back(*it);
-}
-void TObject3D::getPoints(const std::vector<TObject3D> &objs,std::vector<TPoint3D> &pnts)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPoint()) pnts.push_back(*(it->data.point));
-}
-void TObject3D::getSegments(const std::vector<TObject3D> &objs,std::vector<TSegment3D> &sgms)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isSegment()) sgms.push_back(*(it->data.segment));
-}
-void TObject3D::getLines(const std::vector<TObject3D> &objs,std::vector<TLine3D> &lins)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isLine()) lins.push_back(*(it->data.line));
-}
-void TObject3D::getPlanes(const std::vector<TObject3D> &objs,std::vector<TPlane> &plns)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPlane()) plns.push_back(*(it->data.plane));
-}
-void TObject3D::getPolygons(const std::vector<TObject3D> &objs,std::vector<TPolygon3D> &polys)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPolygon()) polys.push_back(*(it->data.polygon));
-}
-void TObject3D::getPoints(const std::vector<TObject3D> &objs,std::vector<TPoint3D> &pnts,std::vector<TObject3D> &remainder)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPoint()) pnts.push_back(*(it->data.point));
-	else remainder.push_back(*it);
-}
-void TObject3D::getSegments(const std::vector<TObject3D> &objs,std::vector<TSegment3D> &sgms,std::vector<TObject3D> &remainder)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isSegment()) sgms.push_back(*(it->data.segment));
-	else remainder.push_back(*it);
-}
-void TObject3D::getLines(const std::vector<TObject3D> &objs,std::vector<TLine3D> &lins,std::vector<TObject3D> &remainder)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isLine()) lins.push_back(*(it->data.line));
-	else remainder.push_back(*it);
-}
-void TObject3D::getPlanes(const std::vector<TObject3D> &objs,std::vector<TPlane> &plns,std::vector<TObject3D> &remainder)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPlane()) plns.push_back(*(it->data.plane));
-	else remainder.push_back(*it);
-}
-void TObject3D::getPolygons(const std::vector<TObject3D> &objs,std::vector<TPolygon3D> &polys,vector<TObject3D> &remainder)	{
-	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPolygon()) polys.push_back(*(it->data.polygon));
-	else remainder.push_back(*it);
-}
-#else
 void TObject2D::generate3DObject(TObject3D &obj) const	{
 	switch (type)	{
 		case GEOMETRIC_TYPE_POINT:
@@ -875,7 +948,6 @@ void TObject3D::getPolygons(const std::vector<TObject3D> &objs,std::vector<TPoly
 	for (vector<TObject3D>::const_iterator it=objs.begin();it!=objs.end();++it) if (it->isPolygon()) polys.push_back(*(it->data.polygon));
 	else remainder.push_back(*it);
 }
-#endif
 
 mrpt::utils::CStream& operator>>(mrpt::utils::CStream& in,mrpt::math::TPoint2D &o)
 {
@@ -910,6 +982,35 @@ mrpt::utils::CStream& operator<<(mrpt::utils::CStream& out,const mrpt::math::TPo
 	return out;
 }
 
+mrpt::utils::CStream& operator>>(mrpt::utils::CStream& in,mrpt::math::TTwist2D &o)
+{
+    for (unsigned int i=0;i<o.size();i++) in >> o[i];
+	return in;
+}
+mrpt::utils::CStream& operator<<(mrpt::utils::CStream& out,const mrpt::math::TTwist2D &o)
+{
+    for (unsigned int i=0;i<o.size();i++) out << o[i];
+	return out;
+}
+
+mrpt::utils::CStream& operator>>(mrpt::utils::CStream& in,mrpt::math::TTwist3D &o)
+{
+    for (unsigned int i=0;i<o.size();i++) in >> o[i];
+	return in;
+}
+mrpt::utils::CStream& operator<<(mrpt::utils::CStream& out,const mrpt::math::TTwist3D &o)
+{
+    for (unsigned int i=0;i<o.size();i++) out << o[i];
+	return out;
+}
+
+	BASE_IMPEXP mrpt::utils::CStream& operator>>(mrpt::utils::CStream& in,mrpt::math::TTwist2D &o);
+	BASE_IMPEXP mrpt::utils::CStream& operator<<(mrpt::utils::CStream& out,const mrpt::math::TTwist2D &o);
+
+	BASE_IMPEXP mrpt::utils::CStream& operator>>(mrpt::utils::CStream& in,mrpt::math::TTwist3D &o);
+	BASE_IMPEXP mrpt::utils::CStream& operator<<(mrpt::utils::CStream& out,const mrpt::math::TTwist3D &o);
+
+
 mrpt::utils::CStream& operator>>(mrpt::utils::CStream& in,mrpt::math::TPose3D &o)
 {
 	in >> o.x >> o.y >> o.z >> o.yaw >> o.pitch >> o.roll;
