@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -10,6 +10,7 @@
 
 #include <mrpt/math/slerp.h>
 #include <mrpt/poses/CPose3D.h>
+#include <mrpt/math/lightweight_geom_data.h>
 #include <gtest/gtest.h>
 
 using namespace mrpt;
@@ -60,6 +61,14 @@ TEST(SLERP_tests, correctShortestPath)
 		const CPose3D expected(0,0,0,DEG2RAD(-180),0,0);
 		EXPECT_NEAR(0, (pose_interp.getHomogeneousMatrixVal()-expected.getHomogeneousMatrixVal()).array().abs().sum(), 1e-4 ) << "pose_a: " << pose_a << "\npose_b: " << pose_b << "\ninterp: " << pose_interp << endl;
 	}
+	{	// Poses at yaw=-+179deg
+		const TPose3D  pose_a(0,0,0, DEG2RAD(-179),DEG2RAD(0),DEG2RAD(0));
+		const TPose3D  pose_b(0,0,0, DEG2RAD(179),DEG2RAD(0),DEG2RAD(0));
+		TPose3D pose_interp;
+		mrpt::math::slerp_ypr(pose_a,pose_b,0.5,pose_interp);
+		const TPose3D expected(0,0,0,DEG2RAD(-180),0,0);
+		EXPECT_NEAR(.0,(CPose3D(expected).getHomogeneousMatrixVal() - CPose3D(pose_interp).getHomogeneousMatrixVal()).array().abs().sum() , 1e-4 ) << "pose_a: " << pose_a.asString() << "\npose_b: " << pose_b.asString() << "\ninterp: " << pose_interp.asString() << endl;
+	}
 
 	{	// Poses at yaw=+-40
 		const CPose3D  pose_a(0,0,0, DEG2RAD(40),DEG2RAD(0),DEG2RAD(0));
