@@ -2,33 +2,44 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "base-precomp.h"  // Precompiled headers
 
-#include <mrpt/poses/CPose2D.h>
-#include <mrpt/poses/CPoint2D.h>
-#include <mrpt/poses/CPose3D.h>
-#include <mrpt/poses/CPoint3D.h>
-#include <mrpt/poses/CPose3DQuat.h>
-#include <mrpt/poses/CPose3DRotVec.h>
-#include <mrpt/math/CMatrix.h>
-#include <mrpt/math/geometry.h>
-#include <mrpt/math/wrap2pi.h>
-#include <mrpt/math/matrix_serialization.h>
-#include <mrpt/math/ops_matrices.h>
-#include <mrpt/utils/CStream.h>
+#include <mrpt/config.h>                                     // for HAVE_SINCOS
+#include <mrpt/utils/types_math.h>                           // for CVectorD...
+#include <mrpt/math/CMatrix.h>                               // for CMatrix
+#include <mrpt/math/geometry.h>                              // for skew_sym...
+#include <mrpt/math/matrix_serialization.h>                  // for operator>>
+#include <mrpt/math/wrap2pi.h>                               // for wrapToPi
+#include <mrpt/poses/CPoint2D.h>                             // for CPoint2D
+#include <mrpt/poses/CPoint3D.h>                             // for CPoint3D
+#include <mrpt/poses/CPose2D.h>                              // for CPose2D
+#include <mrpt/poses/CPose3D.h>                              // for CPose3D
+#include <mrpt/poses/CPose3DQuat.h>                          // for CPose3DQuat
+#include <mrpt/poses/CPose3DRotVec.h>                        // for CPose3DR...
+#include <mrpt/utils/CStream.h>                              // for CStream
+#include <algorithm>                                         // for move
+#include <cmath>                                             // for fabs
+#include <iomanip>                                           // for operator<<
+#include <limits>                                            // for numeric_...
+#include <ostream>                                           // for operator<<
+#include <string>                                            // for allocator
+#include <mrpt/math/CArrayNumeric.h>                         // for CArrayDo...
+#include <mrpt/math/CMatrixFixedNumeric.h>                   // for CMatrixF...
+#include <mrpt/math/CMatrixTemplateNumeric.h>                // for CMatrixD...
+#include <mrpt/math/CQuaternion.h>                           // for CQuatern...
+#include <mrpt/math/homog_matrices.h>                        // for homogene...
+#include <mrpt/math/lightweight_geom_data.h>                 // for TPoint3D
+#include <mrpt/math/ops_containers.h>                        // for dotProduct
+#include <mrpt/utils/CSerializable.h>                        // for CSeriali...
+#include <mrpt/utils/bits.h>                                 // for square
 #include <mrpt/math/utils_matlab.h>
-#include <iomanip>
-#include <limits>
-
-
-#ifndef M_SQRT1_2
-#define M_SQRT1_2 0.70710678118654752440
-#endif
+#include <mrpt/otherlibs/sophus/so3.hpp>
+#include <mrpt/otherlibs/sophus/se3.hpp>
 
 using namespace mrpt;
 using namespace mrpt::math;
@@ -320,7 +331,7 @@ void  CPose3D::getYawPitchRoll( double &yaw, double &pitch, double &roll ) const
 	if ( (fabs(m_ROT(2,1))+fabs(m_ROT(2,2)))<10*std::numeric_limits<double>::epsilon() )
 	{
 		//Gimbal lock between yaw and roll. This one is arbitrarily forced to be zero.
-		//Check http://reference.mrpt.org/svn/classmrpt_1_1poses_1_1_c_pose3_d.html. If cos(pitch)==0, the homogeneous matrix is:
+		//Check http://reference.mrpt.org/devel/classmrpt_1_1poses_1_1_c_pose3_d.html. If cos(pitch)==0, the homogeneous matrix is:
 		//When sin(pitch)==1:
 		//  /0  cysr-sycr cycr+sysr x\   /0  sin(r-y) cos(r-y)  x\.
 		//  |0  sysr+cycr sycr-cysr y| = |0  cos(r-y) -sin(r-y) y|
@@ -539,50 +550,12 @@ CPose3D mrpt::poses::operator -(const CPose3D &b)
 	return CPose3D(B_INV);
 }
 
-/*---------------------------------------------------------------
-		getAsQuaternion
----------------------------------------------------------------*/
 void CPose3D::getAsQuaternion(mrpt::math::CQuaternionDouble &q, mrpt::math::CMatrixFixedNumeric<double,4,3>   *out_dq_dr ) const
 {
 	updateYawPitchRoll();
-	// See: http://en.wikipedia.org/wiki/Conversion_between_quaternions_and_Euler_angles
-	const double	cy = cos(m_yaw*0.5);
-	const double	sy = sin(m_yaw*0.5);
-	const double	cp = cos(m_pitch*0.5);
-	const double	sp = sin(m_pitch*0.5);
-	const double	cr = cos(m_roll*0.5);
-	const double	sr = sin(m_roll*0.5);
-
-	const double ccc = cr*cp*cy;
-	const double ccs = cr*cp*sy;
-	const double css = cr*sp*sy;
-	const double sss = sr*sp*sy;
-	const double scc = sr*cp*cy;
-	const double ssc = sr*sp*cy;
-	const double csc = cr*sp*cy;
-	const double scs = sr*cp*sy;
-
-	q[0] = ccc+sss;
-	q[1] = scc-css;
-	q[2] = csc+scs;
-	q[3] = ccs-ssc;
-
-	// Compute 4x3 Jacobian: for details, see technical report:
-	//   Parameterizations of SE(3) transformations: equivalences, compositions and uncertainty, J.L. Blanco (2010).
-	//   http://www.mrpt.org/6D_poses:equivalences_compositions_and_uncertainty
-	if (out_dq_dr)
-	{
-		MRPT_ALIGN16 const double nums[4*3] = {
-			-0.5*q[3], 0.5*( -csc+scs ), -0.5*q[1],
-			-0.5*q[2],  0.5*( -ssc-ccs ), 0.5* q[0],
-			0.5*q[1], 0.5*( ccc-sss  ),  0.5*q[3],
-			0.5* q[0], 0.5*( -css-scc ), -0.5*q[2]
-		};
-		out_dq_dr->loadFromArray(nums);
-	}
+	mrpt::math::TPose3D(0, 0, 0, m_yaw, m_pitch, m_roll).getAsQuaternion(q, out_dq_dr);
 }
 
-
 bool mrpt::poses::operator==(const CPose3D &p1,const CPose3D &p2)
 {
 	return (p1.m_coords==p2.m_coords)&&(p1.getRotationMatrix()==p2.getRotationMatrix());
@@ -781,9 +754,6 @@ void CPose3D::inverseComposePoint(const double gx,const double gy,const double g
 	}
 }
 
-/** Exponentiate a Vector in the SE3 Lie Algebra to generate a new CPose3D.
-  * \note Method from TooN (C) Tom Drummond (GNU GPL)
-  */
 CPose3D CPose3D::exp(const mrpt::math::CArrayNumeric<double,6> & mu,bool pseudo_exponential )
 {
 	CPose3D P(UNINITIALIZED_POSE);
@@ -793,205 +763,40 @@ CPose3D CPose3D::exp(const mrpt::math::CArrayNumeric<double,6> & mu,bool pseudo_
 
 void CPose3D::exp(const mrpt::math::CArrayNumeric<double,6> & mu, CPose3D &out_pose, bool pseudo_exponential)
 {
-	static const double one_6th = 1.0/6.0;
-	static const double one_20th = 1.0/20.0;
-
-	CArrayDouble<3> mu_xyz;
-	for (int i=0;i<3;i++) mu_xyz[i] = mu[i];
-
-	CArrayDouble<3> w;
-	for (int i=0;i<3;i++) w[i] = mu[3+i];
-
-	const double theta_sq = w.squareNorm(); // w*w;
-	const double theta = std::sqrt(theta_sq);
-	double A, B;
-
-	CArrayDouble<3> cross;
-	mrpt::math::crossProduct3D(w, mu_xyz, cross );
-
-	if (theta_sq < 1e-8)
+	if (pseudo_exponential)
 	{
-		A = 1.0 - one_6th * theta_sq;
-		B = 0.5;
-
-		if (!pseudo_exponential)
-		{
-			out_pose.m_coords[0] = mu_xyz[0] + 0.5 * cross[0];
-			out_pose.m_coords[1] = mu_xyz[1] + 0.5 * cross[1];
-			out_pose.m_coords[2] = mu_xyz[2] + 0.5 * cross[2];
-		}
+		auto R = Sophus::SO3<double>::exp( mu.block<3,1>(3,0) );
+		out_pose.setRotationMatrix(R.matrix());
+		out_pose.x(mu[0]);
+		out_pose.y(mu[1]);
+		out_pose.z(mu[2]);
 	}
 	else
 	{
-		double C;
-		if (theta_sq < 1e-6)
-		{
-			C = one_6th*(1.0 - one_20th * theta_sq);
-			A = 1.0 - theta_sq * C;
-			B = 0.5 - 0.25 * one_6th * theta_sq;
-		}
-		else
-		{
-			const double inv_theta = 1.0/theta;
-			A = sin(theta) * inv_theta;
-			B = (1 - cos(theta)) * (inv_theta * inv_theta);
-			C = (1 - A) * (inv_theta * inv_theta);
-		}
-
-		CArrayDouble<3> w_cross;	// = w^cross
-		mrpt::math::crossProduct3D(w, cross, w_cross );
-
-		if (!pseudo_exponential)
-		{
-			//result.get_translation() = mu_xyz + B * cross + C * (w ^ cross);
-			out_pose.m_coords[0] = mu_xyz[0] + B * cross[0] + C * w_cross[0];
-			out_pose.m_coords[1] = mu_xyz[1] + B * cross[1] + C * w_cross[1];
-			out_pose.m_coords[2] = mu_xyz[2] + B * cross[2] + C * w_cross[2];
-		}
+		auto R = Sophus::SE3<double>::exp(mu);
+		out_pose = CPose3D( CMatrixDouble44(R.matrix()));
 	}
-
-	// 3x3 rotation part:
-	mrpt::math::rodrigues_so3_exp(w, A, B, out_pose.m_ROT);
-
-	if (pseudo_exponential) out_pose.m_coords = mu_xyz;
-	// else: has been already filled in above.
 }
 
-
-
-/** Take the logarithm of the 3x3 rotation matrix, generating the corresponding vector in the Lie Algebra.
-  * \note Method from TooN (C) Tom Drummond (GNU GPL)
-  */
 CArrayDouble<3> CPose3D::ln_rotation() const
 {
-	CArrayDouble<3> result;
-
-	const double cos_angle = (m_ROT.trace() - 1.0) * 0.5;
-	result[0] = (m_ROT(2,1)-m_ROT(1,2))*0.5;
-	result[1] = (m_ROT(0,2)-m_ROT(2,0))*0.5;
-	result[2] = (m_ROT(1,0)-m_ROT(0,1))*0.5;
-
-	double sin_angle_abs = result.norm(); //sqrt(result*result);
-	if (cos_angle > M_SQRT1_2)
-	{            // [0 - Pi/4[ use asin
-		if(sin_angle_abs > 0){
-			result *= asin(sin_angle_abs) / sin_angle_abs;
-		}
-	}
-	else if( cos_angle > -M_SQRT1_2)
-	{    // [Pi/4 - 3Pi/4[ use acos, but antisymmetric part
-		double angle = acos(cos_angle);
-		result *= angle / sin_angle_abs;
-	}
-	else
-	{  // rest use symmetric part
-		// antisymmetric part vanishes, but still large rotation, need information from symmetric part
-		const double angle = M_PI - asin(sin_angle_abs);
-		const double
-			d0 = m_ROT(0,0) - cos_angle,
-			d1 = m_ROT(1,1) - cos_angle,
-			d2 = m_ROT(2,2) - cos_angle;
-		CArrayDouble<3> r2;
-		if(fabs(d0) > fabs(d1) && fabs(d0) > fabs(d2))
-		{ // first is largest, fill with first column
-			r2[0] = d0;
-			r2[1] = (m_ROT(1,0)+m_ROT(0,1))*0.5;
-			r2[2] = (m_ROT(0,2)+m_ROT(2,0))*0.5;
-		}
-		else if(fabs(d1) > fabs(d2))
-		{ 			    // second is largest, fill with second column
-			r2[0] = (m_ROT(1,0)+m_ROT(0,1))*0.5;
-			r2[1] = d1;
-			r2[2] = (m_ROT(2,1)+m_ROT(1,2))*0.5;
-		}
-		else
-		{							    // third is largest, fill with third column
-			r2[0] = (m_ROT(0,2)+m_ROT(2,0))*0.5;
-			r2[1] = (m_ROT(2,1)+m_ROT(1,2))*0.5;
-			r2[2] = d2;
-		}
-		// flip, if we point in the wrong direction!
-		if( mrpt::math::dotProduct<CArrayDouble<3>,CArrayDouble<3> >(r2,result) < 0)
-			r2 *= -1;
-		result = r2;
-		result *= (angle/r2.norm());
-	}
-	return result;
+	Sophus::SO3<double> R(this->m_ROT);
+	return R.log();
 }
 
-/** Exponentiate a vector in the Lie algebra to generate a new SO3 (a 3x3 rotation matrix).
-  * \note Method from TooN (C) Tom Drummond (GNU GPL) */
 CMatrixDouble33 CPose3D::exp_rotation(const mrpt::math::CArrayNumeric<double,3> & w)
 {
-	using std::sqrt;
-	using std::sin;
-	using std::cos;
-
-	static const double one_6th = 1.0/6.0;
-	static const double one_20th = 1.0/20.0;
-
-	const double theta_sq = w.squareNorm(); //w*w;
-	const double theta = sqrt(theta_sq);
-	double A, B;
-	//Use a Taylor series expansion near zero. This is required for
-	//accuracy, since sin t / t and (1-cos t)/t^2 are both 0/0.
-	if (theta_sq < 1e-8) {
-		A = 1.0 - one_6th * theta_sq;
-		B = 0.5;
-	} else {
-		if (theta_sq < 1e-6) {
-			B = 0.5 - 0.25 * one_6th * theta_sq;
-			A = 1.0 - theta_sq * one_6th*(1.0 - one_20th * theta_sq);
-		} else {
-			const double inv_theta = 1.0/theta;
-			A = sin(theta) * inv_theta;
-			B = (1 - cos(theta)) * (inv_theta * inv_theta);
-		}
-	}
-
-	CMatrixDouble33 result(UNINITIALIZED_MATRIX);
-	mrpt::math::rodrigues_so3_exp(w, A, B, result);
-	return result;
+	auto R = Sophus::SO3<double>::exp(w);
+	return R.matrix();
 }
 
-/** Take the logarithm of the 3x4 matrix defined by this pose, generating the corresponding vector in the SE3 Lie Algebra.
-  * \note Method from TooN (C) Tom Drummond (GNU GPL)
-  */
 void CPose3D::ln(CArrayDouble<6> &result) const
 {
-	CArrayDouble<3> rot = this->ln_rotation();
-	const double theta =  rot.norm(); //sqrt(rot*rot);
-
-	double shtot = 0.5;
-	if(theta > 0.00001)
-		shtot = sin(theta*0.5)/theta;
-
-	// now do the rotation
-	CArrayDouble<3> rot_half = rot;
-	rot_half*=-0.5;
-	const CMatrixDouble33 halfrotator = CPose3D::exp_rotation(rot_half);
-
-	CArrayDouble<3> rottrans; // = halfrotator * xyz;
-	halfrotator.multiply_Ab(m_coords, rottrans);
-
-	if(theta > 0.001)
-	{
-		rottrans -= rot * ( m_coords.dot(rot) * (1-2*shtot) / rot.squareNorm() ); //(rot*rot));
-	}
-	else
-	{
-		rottrans -= rot * ( m_coords.dot(rot)/24);
-	}
-
-	rottrans *= 1.0/(2 * shtot);
-
-	for (int i=0;i<3;i++) result[i] = rottrans[i];
-	for (int i=0;i<3;i++) result[3+i] = rot[i];
+	const Sophus::SE3<double> RT(m_ROT, m_coords);
+	result = RT.log();
 }
 
-
-/* The following code fragments are from TooN and RobotVision packages.
-*/
+/* The following code fragments are based on formulas originally reported in the TooN and RobotVision packages */
 namespace mrpt
 {
 	namespace poses
@@ -1088,8 +893,6 @@ namespace mrpt
 			}
 			M3x9(a,B,J);
 		}
-
-
 	}
 }
 
