@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -15,6 +15,7 @@
 #include <mrpt/math/wrap2pi.h>
 #include <mrpt/utils/CStream.h>
 #include <mrpt/poses/SO_SE_average.h>
+#include <mrpt/system/os.h>
 
 using namespace mrpt;
 using namespace mrpt::poses;
@@ -30,19 +31,16 @@ CPose3DPDFParticles::CPose3DPDFParticles( size_t M )
 {
 	m_particles.resize(M);
 
-	for (CPose3DPDFParticles::CParticleList::iterator it=m_particles.begin();it!=m_particles.end();++it)
+	for (auto &it : m_particles)
 	{
-		it->log_w	= 0;
-		it->d		= new CPose3D();
+		it.log_w = .0;
+		it.d.reset(new CPose3D());
 	}
 
-	static CPose3D	nullPose(0,0,0);
+	CPose3D	nullPose(0,0,0);
 	resetDeterministic( nullPose );
 }
 
-/*---------------------------------------------------------------
-						operator =
-  ---------------------------------------------------------------*/
 void  CPose3DPDFParticles::copyFrom(const CPose3DPDF &o)
 {
 	MRPT_START
@@ -54,34 +52,10 @@ void  CPose3DPDFParticles::copyFrom(const CPose3DPDF &o)
 
 	if (o.GetRuntimeClass()==CLASS_ID(CPose3DPDFParticles))
 	{
-		const CPose3DPDFParticles	*pdf = static_cast<const CPose3DPDFParticles*>( &o );
+		const CPose3DPDFParticles	*pdf = dynamic_cast<const CPose3DPDFParticles*>( &o );
+		ASSERT_(pdf);
 
-		// Both are m_particles:
-		if (m_particles.size()==pdf->m_particles.size())
-		{
-			for ( itSrc=pdf->m_particles.begin(), itDest = m_particles.begin();
-				   itSrc!=pdf->m_particles.end();
-			      itSrc++, itDest++ )
-			{
-				(*itDest->d) = (*itSrc->d);
-				itDest->log_w = itSrc->log_w;
-			}
-		}
-		else
-		{
-			for ( itDest = m_particles.begin();itDest!=m_particles.end();++itDest )
-				delete itDest->d;
-
-			m_particles.resize( pdf->m_particles.size() );
-
-			for ( itSrc=pdf->m_particles.begin(), itDest = m_particles.begin();
-				   itSrc!=pdf->m_particles.end();
-			      ++itSrc, ++itDest )
-			{
-				itDest->d = new CPose3D( *itSrc->d );
-				itDest->log_w = itSrc->log_w;
-			}
-		}
+		m_particles = pdf->m_particles;
 	}
 	else
 	if (o.GetRuntimeClass()==CLASS_ID(CPose3DPDFGaussian))
@@ -92,14 +66,6 @@ void  CPose3DPDFParticles::copyFrom(const CPose3DPDF &o)
 	MRPT_END
 }
 
-/*---------------------------------------------------------------
-	Destructor
-  ---------------------------------------------------------------*/
-CPose3DPDFParticles::~CPose3DPDFParticles( )
-{
-	clearParticles();
-}
-
 /*---------------------------------------------------------------
 						getMean
   Returns an estimate of the pose, (the mean, or mathematical expectation of the PDF), computed
@@ -111,7 +77,7 @@ void CPose3DPDFParticles::getMean(CPose3D &p) const
 
 	// Default to (0,..,0)
 	p = CPose3D();
-	if (m_particles.empty()) 
+	if (m_particles.empty())
 		return;
 
 	// Calc average on SE(3)
@@ -277,8 +243,24 @@ void  CPose3DPDFParticles::readFromStream(mrpt::utils::CStream &in, int version)
  ---------------------------------------------------------------*/
 void  CPose3DPDFParticles::saveToTextFile(const std::string &file) const
 {
-	MRPT_UNUSED_PARAM(file);
-	THROW_EXCEPTION("TO DO!");
+	using namespace mrpt::system;
+
+	FILE	*f=os::fopen(file.c_str(),"wt");
+	if (!f) return;
+
+	os::fprintf(f,"%% x  y  z  yaw[rad] pitch[rad] roll[rad] log_weight\n");
+
+	for (const auto &p : m_particles)
+		os::fprintf(f,"%f %f %f %f %f %f %e\n",
+				p.d->x(),
+				p.d->y(),
+				p.d->z(),
+				p.d->yaw(),
+				p.d->pitch(),
+				p.d->roll(),
+				p.log_w );
+
+	os::fclose(f);
 }
 
 
@@ -401,8 +383,8 @@ void  CPose3DPDFParticles::resetDeterministic( const CPose3D &location,
 	{
 		clearParticles();
 		m_particles.resize(particlesCount);
-		for (it=m_particles.begin();it!=m_particles.end();++it)
-			it->d = new CPose3D();
+		for (it = m_particles.begin(); it != m_particles.end(); ++it)
+			it->d.reset(new CPose3D());
 	}
 
 	for (it=m_particles.begin();it!=m_particles.end();++it)
