@@ -2,18 +2,14 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "base-precomp.h"  // Precompiled headers
-#include <mrpt/poses/CPose2D.h>
-#include <mrpt/poses/CPoint2D.h>
 #include <mrpt/poses/CPose3D.h>
-#include <mrpt/poses/CPoint3D.h>
 #include <mrpt/poses/CPose3DQuat.h>
-#include <mrpt/math/CMatrix.h>
 #include <mrpt/utils/CStream.h>
 #include <iomanip>
 #include <limits>
@@ -454,3 +450,28 @@ void CPose3DQuat::setToNaN()
 	for (int i=0;i<4;i++)
 		quat()[i] = std::numeric_limits<double>::quiet_NaN();
 }
+
+bool mrpt::poses::operator==(const CPose3DQuat &p1,const CPose3DQuat &p2)
+{
+	return p1.quat()==p2.quat() && p1.x()==p2.x() && p1.y()==p2.y() && p1.z()==p2.z();
+}
+
+bool mrpt::poses::operator!=(const CPose3DQuat &p1,const CPose3DQuat &p2)
+{
+	return !(p1==p2);
+}
+
+CPoint3D mrpt::poses::operator -(const CPoint3D &G,const CPose3DQuat &p)
+{ 
+	CPoint3D L; 
+	p.inverseComposePoint(G[0], G[1], G[2], L[0], L[1], L[2]); 
+	return L; 
+}
+
+mrpt::math::TPoint3D mrpt::poses::operator -(const mrpt::math::TPoint3D &G, const CPose3DQuat &p)
+{
+	mrpt::math::TPoint3D L; 
+	p.inverseComposePoint(G[0], G[1], G[2], L[0], L[1], L[2]); 
+	return L; 
+}
+
