@@ -2,14 +2,13 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "base-precomp.h"  // Precompiled headers
 
-#include <mrpt/utils/CTicTac.h>
 #include <mrpt/poses/CPosePDFGaussian.h>
 #include <mrpt/poses/CPosePDFParticles.h>
 #include <mrpt/system/os.h>
@@ -37,16 +36,16 @@ CPosePDFParticles::CPosePDFParticles( size_t M )
 {
 	m_particles.resize(M);
 
-	for (CParticleList::iterator it=m_particles.begin();it!=m_particles.end();++it)
-		it->d = new CPose2D();
+	for (auto & p : m_particles)
+	{
+		p.log_w = .0;
+		p.d.reset(new CPose2D());
+	}
 
-	static CPose2D	nullPose(0,0,0);
+	CPose2D nullPose(0,0,0);
 	resetDeterministic( nullPose );
 }
 
-/*---------------------------------------------------------------
-						operator =
-  ---------------------------------------------------------------*/
 void  CPosePDFParticles::copyFrom(const CPosePDF &o)
 {
 	MRPT_START
@@ -58,34 +57,11 @@ void  CPosePDFParticles::copyFrom(const CPosePDF &o)
 
 	if (o.GetRuntimeClass()==CLASS_ID(CPosePDFParticles))
 	{
-		const CPosePDFParticles	*pdf = static_cast<const CPosePDFParticles*>( &o );
+		const CPosePDFParticles	*pdf = dynamic_cast<const CPosePDFParticles*>( &o );
+		ASSERT_(pdf);
 
 		// Both are m_particles:
-		if (m_particles.size()==pdf->m_particles.size())
-		{
-			for ( itSrc=pdf->m_particles.begin(), itDest = m_particles.begin();
-				   itSrc!=pdf->m_particles.end();
-			      ++itSrc, ++itDest )
-			{
-				(*itDest->d) = (*itSrc->d);
-				itDest->log_w = itSrc->log_w;
-			}
-		}
-		else
-		{
-			for ( itDest = m_particles.begin();itDest!=m_particles.end();++itDest )
-				delete itDest->d;
-
-			m_particles.resize( pdf->m_particles.size() );
-
-			for ( itSrc=pdf->m_particles.begin(), itDest = m_particles.begin();
-				   itSrc!=pdf->m_particles.end();
-			      ++itSrc, ++itDest )
-			{
-				itDest->d = new CPose2D( *itSrc->d );
-				itDest->log_w = itSrc->log_w;
-			}
-		}
+		m_particles = pdf->m_particles;
 	}
 	else
 	if (o.GetRuntimeClass()==CLASS_ID(CPosePDFGaussian))
@@ -103,9 +79,11 @@ void  CPosePDFParticles::copyFrom(const CPosePDF &o)
 		for ( itDest = m_particles.begin(),partsIt=parts.begin();itDest!=m_particles.end();++itDest,++partsIt )
 		{
 			itDest->log_w = 0;
-            itDest->d = new CPose2D( ( pdf->mean.x() + (*partsIt)[0] ),
-									 ( pdf->mean.y() + (*partsIt)[1] ),
-                                     ( pdf->mean.phi() + (*partsIt)[2] ) );
+			itDest->d.reset(new CPose2D(
+				(pdf->mean.x() + (*partsIt)[0]),
+				(pdf->mean.y() + (*partsIt)[1]),
+				(pdf->mean.phi() + (*partsIt)[2]))
+			);
 			itDest->d->normalizePhi();
 		}
 
@@ -114,17 +92,6 @@ void  CPosePDFParticles::copyFrom(const CPosePDF &o)
 	MRPT_END
 }
 
-/*---------------------------------------------------------------
-	Destructor
-  ---------------------------------------------------------------*/
-CPosePDFParticles::~CPosePDFParticles( )
-{
-	clear();
-}
-
-/*---------------------------------------------------------------
-			clear
-  ---------------------------------------------------------------*/
 void  CPosePDFParticles::clear( )
 {
 	clearParticles();
@@ -249,20 +216,18 @@ void  CPosePDFParticles::readFromStream(mrpt::utils::CStream &in, int version)
 void  CPosePDFParticles::resetDeterministic( const CPose2D &location,
 										size_t	particlesCount)
 {
-	CParticleList::iterator		it;
-
 	if (particlesCount>0)
 	{
 		clear();
 		m_particles.resize(particlesCount);
-		for (it=m_particles.begin();it!=m_particles.end();++it)
-			it->d = new CPose2D();
+		for (auto &p: m_particles)
+			p.d.resetDefaultCtor();
 	}
 
-	for (it=m_particles.begin();it!=m_particles.end();++it)
+	for (auto &p: m_particles)
 	{
-		*it->d	= location;
-		it->log_w	= 0;
+		*p.d = location;
+		p.log_w = .0;
 	}
 }
 
@@ -284,8 +249,8 @@ void  CPosePDFParticles::resetUniform(
 	{
 		clear();
 		m_particles.resize(particlesCount);
-		for (int i=0;i<particlesCount;i++)
-			m_particles[i].d = new CPose2D();
+		for (int i = 0; i < particlesCount; i++)
+			m_particles[i].d.reset(new CPose2D());
 	}
 
 	size_t		i,M = m_particles.size();
@@ -300,6 +265,40 @@ void  CPosePDFParticles::resetUniform(
 	MRPT_END
 }
 
+void  CPosePDFParticles::resetAroundSetOfPoses(
+	const std::vector<mrpt::math::TPose2D> & list_poses,
+	const size_t num_particles_per_pose,
+	const double spread_x,
+	const double spread_y,
+	const double spread_phi_rad)
+{
+	MRPT_START
+	ASSERT_(!list_poses.empty());
+	ASSERT_(num_particles_per_pose>=1);
+
+	const size_t N = list_poses.size() * num_particles_per_pose;
+
+	clear();
+	m_particles.resize(N);
+	size_t i,nSpot;
+	for (i=0,nSpot=0;nSpot<list_poses.size();nSpot++)
+	{
+		const mrpt::math::TPose2D & p = list_poses[nSpot];
+		for (size_t k=0;k<num_particles_per_pose;k++,i++)
+		{
+			m_particles[i].d.reset(new CPose2D());
+			m_particles[i].d->x( randomGenerator.drawUniform( p.x - spread_x*0.5, p.x + spread_x*0.5 ) );
+			m_particles[i].d->y( randomGenerator.drawUniform( p.y - spread_y*0.5, p.y + spread_y*0.5 ) );
+			m_particles[i].d->phi( randomGenerator.drawUniform( p.phi - spread_phi_rad*0.5, p.phi + spread_phi_rad*0.5 ) );
+			m_particles[i].log_w=0;
+		}
+	}
+
+	ASSERT_EQUAL_(i,N);
+
+	MRPT_END
+}
+
 /*---------------------------------------------------------------
 						saveToTextFile
    Save PDF's m_particles to a text file. In each line it
@@ -309,6 +308,7 @@ void  CPosePDFParticles::saveToTextFile(const std::string &file) const
 {
 	FILE	*f=os::fopen(file.c_str(),"wt");
 	if (!f) return;
+	os::fprintf(f,"%% x  y  yaw[rad] log_weight\n");
 
 	for (unsigned int i=0;i<m_particles.size();i++)
 		os::fprintf(f,"%f %f %f %e\n",
@@ -378,7 +378,7 @@ void  CPosePDFParticles::append( CPosePDFParticles &o )
 	for (unsigned int i=0;i<o.m_particles.size();i++)
 	{
 		CParticleData		part;
-		part.d = new CPose2D( *o.m_particles[i].d );
+		part.d.reset(new CPose2D(*o.m_particles[i].d));
 		part.log_w = o.m_particles[i].log_w;
 		m_particles.push_back( part );
 	}
