@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -227,7 +227,7 @@ void  CRandomGenerator::drawGaussianMultivariate(
 		for (size_t d=0;d<dim;d++) out_result[d]+= (*mean)[d];
 
 	MRPT_END_WITH_CLEAN_UP( \
-		printf("\nEXCEPTION: Dumping variables for debuging:\n"); \
+		printf("\nEXCEPTION: Dumping variables for debugging:\n"); \
 		std::cout << "Z:\n" << Z << "D:\n" << D << "Cov:\n" << cov; \
 		try \
 		{ \
