@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -10,7 +10,7 @@
 #include "base-precomp.h"  // Precompiled headers 
 
 
-#include <mrpt/synch.h>
+#include <mrpt/synch/CCriticalSection.h>
 #include <mrpt/utils/CStream.h>
 
 #include <iostream>
@@ -24,7 +24,7 @@ using namespace std;
 /*---------------------------------------------------------------
 				CCriticalSectionLocker
 ---------------------------------------------------------------*/
-CCriticalSectionLocker::CCriticalSectionLocker( const CCriticalSection * cs)
+CCriticalSectionLocker::CCriticalSectionLocker( const CAbstractMutex * cs)
 	: m_cs(cs)
 {
 	if (m_cs)
