@@ -2,19 +2,22 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "base-precomp.h"  // Precompiled headers
 
-#include <mrpt/system/datetime.h>
-#include <mrpt/system/filesystem.h>
-#include <mrpt/system/os.h>
 #include <mrpt/system/CDirectoryExplorer.h>
+#include <mrpt/system/filesystem.h>
+#include <mrpt/system/os.h>                  // for sprintf
+#include "mrpt/utils/bits.h"                 // for format
+#include "mrpt/utils/mrpt_macros.h"          // for MRPT_END, MRPT_START, e
 
 #include <cstring>
+#include <string>
+#include <vector>
 #include <stdio.h>
 
 #ifdef MRPT_OS_WINDOWS
@@ -26,10 +29,9 @@
 	#include <io.h>
 	#include <direct.h>
 #else
-    #include <termios.h>
-    #include <unistd.h>
-    #include <sys/time.h>
-    #include <time.h>
+	#include <termios.h>
+	#include <sys/time.h>
+	#include <time.h>
 	#include <unistd.h>
 	#include <utime.h>
 	#include <errno.h>
@@ -310,23 +312,21 @@ bool mrpt::system::renameFile( const string &oldFileName, const string &newFileN
 /*---------------------------------------------------------------
 			fileNameStripInvalidChars
 ---------------------------------------------------------------*/
-std::string mrpt::system::fileNameStripInvalidChars( const std::string &filename)
+std::string mrpt::system::fileNameStripInvalidChars(const std::string &filename, const char replacement_to_invalid_chars)
 {
-	string	ret(filename);
+	const char forbid[] = {'<','>',':','"','/','\\','|','?','*'};
+	const unsigned int nForbid = sizeof(forbid) / sizeof(forbid[0]);
+
+	string	ret(filename	);
 	for (string::iterator c=ret.begin();c!=ret.end();++c)
 	{
-		if (!isalnum(*c) &&
-			*c !='.' &&
-			*c !='-' &&
-			*c !='#' &&
-			*c !='%' &&
-			*c !='$' &&
-			*c !='&' &&
-			*c !='+' &&
-			*c !='(' && *c !=')' &&
-			*c !='[' && *c !=']' &&
-			*c !='{' && *c !='}' )
-				*c = '_';
+		bool invalid = (*c < 32);
+
+		for (unsigned int i = 0; !invalid && i < nForbid; i++)
+			if (*c == forbid[i])
+				invalid = true;
+
+		if (invalid) *c = '_';
 	}
 	return ret;
 }
@@ -386,7 +386,7 @@ bool mrpt::system::copyFile(
 	// Is source a directory?
 	if ( !fil_exs )
 	{
-		if (outErrStr) *outErrStr = string("Source does not exist or permision denied!: ")+org;
+		if (outErrStr) *outErrStr = string("Source does not exist or permission denied!: ")+org;
 		return false;
 	}
 	if (dir_exs)
@@ -427,7 +427,7 @@ bool mrpt::system::copyFile(
 			// It exists, but cannot overwrite it:
 
 #ifdef MRPT_OS_WINDOWS
-			// Try changing the permisions of the target file:
+			// Try changing the permissions of the target file:
 			DWORD dwProp = GetFileAttributesA( trg.c_str() );
 			if (dwProp==INVALID_FILE_ATTRIBUTES)
 			{
@@ -456,7 +456,7 @@ bool mrpt::system::copyFile(
 				return false;
 			}
 #else
-			// Try changing the permisions of the target file:
+			// Try changing the permissions of the target file:
 			if (chmod( trg.c_str(), S_IRWXU | S_IRGRP | S_IROTH ) )
 			{
 				if (outErrStr) *outErrStr = string("Cannot set file permissions for target file, trying to remove a possible read-only attribute after first attempt of copy failed, for: ")+trg;
@@ -562,3 +562,49 @@ time_t mrpt::system::getFileModificationTime(const std::string &filename)
 	else return fS.st_mtime;
 }
 
+#include <mrpt/version.h>
+// Read docs in .h
+std::string mrpt::system::getShareMRPTDir()
+{
+	using std::string;
+	using std::vector;
+
+	static vector<string> sPaths;
+	static string sDetectedPath;
+	static bool is_first = true;
+	if (is_first)
+	{
+		is_first = false;
+
+		// Source dir:
+		sPaths.push_back(string(MRPT_CMAKE_SOURCE_DIR) + string("/share/mrpt/"));
+		// Install dir:
+		sPaths.push_back(string(MRPT_CMAKE_INSTALL_PREFIX) + string("/share/mrpt/"));
+
+		// Program path & ".." & "../..":
+		char buf[2048];
+		bool sBufOk=false;
+#ifdef MRPT_OS_WINDOWS
+		sBufOk = (0 != GetModuleFileNameA(NULL, buf, sizeof(buf)));
+#endif
+#ifdef MRPT_OS_LINUX
+		sBufOk = (-1 != readlink("/proc/self/exe", buf, sizeof(buf)));
+#endif
+
+		if (sBufOk) {
+			string sBuf = string(buf);
+			std::replace(sBuf.begin(), sBuf.end(), '\\', '/');
+			sBuf = extractFileDirectory(sBuf);
+			sPaths.push_back(sBuf + string("share/mrpt/"));
+			sPaths.push_back(sBuf + string("../share/mrpt/"));
+			sPaths.push_back(sBuf + string("../../share/mrpt/"));
+		}
+
+		for (const auto &e : sPaths)
+			if (directoryExists(e)) {
+				sDetectedPath = e;
+				break;
+			}
+	}
+	return sDetectedPath;
+}
