@@ -2,18 +2,19 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "base-precomp.h"  // Precompiled headers
 
-#include <mrpt/utils/core_defs.h>
+#include <cstdio>                    // for size_t, fclose, fopen, fscanf, FILE
+#include <cstdlib>                   // for free, posix_memalign, realloc
+#include <exception>                 // for exception
+#include <mrpt/config.h>             // for HAVE_POSIX_MEMALIGN, MRPT_OS_LINUX
+#include <mrpt/utils/mrpt_macros.h>  // for MRPT_END, MRPT_START, MRPT_UNUSE...
 #include <mrpt/system/memory.h>
-#include <cstdio>
-#include <cstring>
-#include <cstdlib> // realloc(), posix_memalign()...
 
 #ifdef MRPT_OS_APPLE
 #include <mach/mach_init.h>
@@ -224,8 +225,6 @@ unsigned long  mrpt::system::getMemoryUsage()
 		MEM=info.virtual_size;
 	}
 #endif
-
 	return MEM;
 	MRPT_END
 }
-
