@@ -2,15 +2,13 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 #include "base-precomp.h"  // Precompiled headers
 
-
-
 #include <mrpt/utils/CConfigFileMemory.h>
 #include <mrpt/system/os.h>
 
@@ -21,8 +19,7 @@ using namespace mrpt::utils;
 using namespace mrpt::utils::simpleini;
 using namespace std;
 
-
-#define THE_INI  static_cast<CSimpleIniA*>(m_ini.get())
+#define THE_INI  static_cast<MRPT_CSimpleIni*>(m_ini.get())
 
 /*---------------------------------------------------------------
 					Constructor
@@ -30,7 +27,7 @@ using namespace std;
 CConfigFileMemory::CConfigFileMemory( const utils::CStringList &stringList )
 {
 	// Create the object:
-    m_ini = (void*) new CSimpleIniA();
+    m_ini = (void*) new MRPT_CSimpleIni();
 
     // Load the strings:
     std::string aux;
@@ -44,7 +41,7 @@ CConfigFileMemory::CConfigFileMemory( const utils::CStringList &stringList )
 CConfigFileMemory::CConfigFileMemory( const std::string &str )
 {
 	// Create the object:
-    m_ini = (void*) new CSimpleIniA();
+    m_ini = (void*) new MRPT_CSimpleIni();
 
     // Load the strings:
     THE_INI->Load( str.c_str(), str.size() );
@@ -56,14 +53,14 @@ CConfigFileMemory::CConfigFileMemory( const std::string &str )
 CConfigFileMemory::CConfigFileMemory()
 {
 	// Create the empty object:
-    m_ini = (void*) new CSimpleIniA();
+    m_ini = (void*) new MRPT_CSimpleIni();
 }
 
 /** Copy constructor */
 CConfigFileMemory::CConfigFileMemory(const CConfigFileMemory& o)
 {
 	// Create the empty object:
-    m_ini = (void*) new CSimpleIniA();
+    m_ini = (void*) new MRPT_CSimpleIni();
 	(*this) = o;
 }
 
@@ -71,7 +68,7 @@ CConfigFileMemory::CConfigFileMemory(const CConfigFileMemory& o)
 CConfigFileMemory& CConfigFileMemory::operator = (const CConfigFileMemory& o)
 {
 	std::string  str;
-	static_cast<const CSimpleIniA*>(o.m_ini.get())->Save(str);
+	static_cast<const MRPT_CSimpleIni*>(o.m_ini.get())->Save(str);
 	THE_INI->Load(str.c_str(),str.size());
 	return *this;
 }
@@ -101,7 +98,7 @@ void CConfigFileMemory::setContent(  const std::string &str )
  ---------------------------------------------------------------*/
 void CConfigFileMemory::getContent( std::string &str ) const
 {
-	((CSimpleIniA*)(m_ini.get()))->Save( str, false );
+	((MRPT_CSimpleIni*)(m_ini.get()))->Save( str);
 }
 
 /*---------------------------------------------------------------
@@ -138,7 +135,7 @@ std::string  CConfigFileMemory::readString(
     MRPT_START
     const char *defVal = failIfNotFound ? NULL :defaultStr.c_str();
 
-    const char *aux = static_cast<const CSimpleIniA*>(m_ini.get())->GetValue(
+    const char *aux = static_cast<const MRPT_CSimpleIni*>(m_ini.get())->GetValue(
         section.c_str(),
         name.c_str(),
         defVal,
@@ -164,10 +161,10 @@ std::string  CConfigFileMemory::readString(
  ---------------------------------------------------------------*/
 void CConfigFileMemory::getAllSections( vector_string	&sections ) const
 {
-	CSimpleIniA::TNamesDepend	names;
-	static_cast<const CSimpleIniA*>(m_ini.get())->GetAllSections(names);
+	MRPT_CSimpleIni::TNamesDepend	names;
+	static_cast<const MRPT_CSimpleIni*>(m_ini.get())->GetAllSections(names);
 
-	CSimpleIniA::TNamesDepend::iterator		n;
+	MRPT_CSimpleIni::TNamesDepend::iterator		n;
 	vector_string::iterator		s;
 	sections.resize(names.size());
 	for (n=names.begin(),s=sections.begin(); n!=names.end();++n,++s)
@@ -180,10 +177,10 @@ void CConfigFileMemory::getAllSections( vector_string	&sections ) const
  ---------------------------------------------------------------*/
 void CConfigFileMemory::getAllKeys( const string &section, vector_string	&keys ) const
 {
-	CSimpleIniA::TNamesDepend	names;
-	static_cast<const CSimpleIniA*>(m_ini.get())->GetAllKeys(section.c_str(), names);
+	MRPT_CSimpleIni::TNamesDepend	names;
+	static_cast<const MRPT_CSimpleIni*>(m_ini.get())->GetAllKeys(section.c_str(), names);
 
-	CSimpleIniA::TNamesDepend::iterator		n;
+	MRPT_CSimpleIni::TNamesDepend::iterator		n;
 	vector_string::iterator		s;
 	keys.resize(names.size());
 	for ( n = names.begin(), s = keys.begin(); n!=names.end();++n,++s)
