@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -54,7 +54,7 @@ bool CFileGZInputStream::open(const std::string &fileName )
 	// Get compressed file size:
 	m_file_size = mrpt::system::getFileSize(fileName);
 	if (m_file_size==uint64_t(-1))
-		THROW_EXCEPTION_CUSTOM_MSG1("Couldn't access the file '%s'",fileName.c_str() );
+		THROW_EXCEPTION_FMT("Couldn't access the file '%s'",fileName.c_str() );
 
 	// Open gz stream:
 	m_f = gzopen(fileName.c_str(),"rb");
