@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -153,7 +153,7 @@ void CImage::copyFromForceLoad(const CImage &o)
 	{
 		// Load from that file:
 		if (!this->loadFromFile( o.getExternalStorageFileAbsolutePath() ))
-			THROW_TYPED_EXCEPTION_CUSTOM_MSG1("Error loading externally-stored image from: %s", o.getExternalStorageFileAbsolutePath().c_str() ,CExceptionExternalImageNotFound);
+			THROW_TYPED_EXCEPTION_FMT(CExceptionExternalImageNotFound,"Error loading externally-stored image from: %s", o.getExternalStorageFileAbsolutePath().c_str());
 	}
 	else
 	{	// It's not external storage.
@@ -1810,12 +1810,12 @@ void  CImage::cross_correlation_FFT(
 			float	r1 = I1_R.get_unsafe(y,x);
 			float	r2 = I2_R.get_unsafe(y,x);
 
-			float	i1 = I1_I.get_unsafe(y,x);
-			float	i2 = I2_I.get_unsafe(y,x);
+			float	ii1 = I1_I.get_unsafe(y,x);
+			float	ii2 = I2_I.get_unsafe(y,x);
 
-			float	den = square(r1)+square(i1);
-			I2_R.set_unsafe(y,x, (r1*r2+i1*i2)/den);
-			I2_I.set_unsafe(y,x, (i2*r1-r2*i1)/den);
+			float	den = square(r1)+square(ii1);
+			I2_R.set_unsafe(y,x, (r1*r2+ii1*ii2)/den);
+			I2_I.set_unsafe(y,x, (ii2*r1-r2*ii1)/den);
 		}
 
 //	I2_R.saveToTextFile("DIV_R.txt");
@@ -1932,7 +1932,7 @@ void CImage::releaseIpl(bool thisIsExternalImgUnload) MRPT_NO_THROWS
 /*---------------------------------------------------------------
 				makeSureImageIsLoaded
  ---------------------------------------------------------------*/
-void CImage::makeSureImageIsLoaded() const throw (std::exception,utils::CExceptionExternalImageNotFound )
+void CImage::makeSureImageIsLoaded() const
 {
 	if (img!=NULL) return;  // OK, continue
 
@@ -1951,7 +1951,7 @@ void CImage::makeSureImageIsLoaded() const throw (std::exception,utils::CExcepti
 		m_externalFile = tmpFile;
 
 		if (!ret)
-			THROW_TYPED_EXCEPTION_CUSTOM_MSG1("Error loading externally-stored image from: %s", wholeFile.c_str() ,CExceptionExternalImageNotFound);
+			THROW_TYPED_EXCEPTION_FMT(CExceptionExternalImageNotFound,"Error loading externally-stored image from: %s", wholeFile.c_str());
 	}
 	else THROW_EXCEPTION("img is NULL in a non-externally stored image.");
 }
@@ -1992,6 +1992,14 @@ void CImage::flipVertical(bool also_swapRB )
 #endif
 }
 
+void CImage::flipHorizontal()
+{
+#if MRPT_HAS_OPENCV
+	IplImage *ptr=(IplImage*)img;
+	cvFlip(ptr,nullptr,1);
+#endif
+}
+
 /*---------------------------------------------------------------
 				swapRB
  ---------------------------------------------------------------*/
@@ -2325,7 +2333,7 @@ bool CImage::drawChessboardCorners(
 
 	if (cornerCoords.size()!=check_size_x*check_size_y) return false;
 
-	IplImage* img = this->getAs<IplImage>();
+	IplImage* ipl = this->getAs<IplImage>();
 
 	unsigned int x, y,i;
 	CvPoint prev_pt = cvPoint(0, 0);
@@ -2352,17 +2360,17 @@ bool CImage::drawChessboardCorners(
 			pt.x = cvRound( cornerCoords[i].x);
 			pt.y = cvRound( cornerCoords[i].y);
 
-			if( i != 0 ) cvLine( img, prev_pt, pt, color, lines_width );
+			if( i != 0 ) cvLine(ipl, prev_pt, pt, color, lines_width );
 
-			cvLine( img,
+			cvLine(ipl,
 					  cvPoint( pt.x - r, pt.y - r ),
 					  cvPoint( pt.x + r, pt.y + r ), color, lines_width );
-			cvLine( img,
+			cvLine(ipl,
 					  cvPoint( pt.x - r, pt.y + r),
 					  cvPoint( pt.x + r, pt.y - r), color, lines_width );
 
 			if (r>0)
-				cvCircle( img, pt, r+1, color );
+				cvCircle(ipl, pt, r+1, color );
 			prev_pt = pt;
 
 			// Text label with the corner index in the first and last corners:
@@ -2795,4 +2803,3 @@ bool CImage::loadTGA(const std::string& fileName, mrpt::utils::CImage &out_RGB,
 	return false;
 #endif // MRPT_HAS_OPENCV
 }
-
