@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -12,7 +12,6 @@
 
 #include <mrpt/utils/CObject.h>
 #include <mrpt/utils/CMemoryStream.h>
-#include <mrpt/utils/CStartUpClassesRegister.h>
 #include <mrpt/system/os.h>
 
 #include "internal_class_registry.h"
@@ -23,9 +22,6 @@ using namespace mrpt::system;
 
 #include <cstdio>
 
-extern CStartUpClassesRegister  mrpt_base_class_reg;
-const int dumm = mrpt_base_class_reg.do_nothing(); // Avoid compiler removing this class in static linking
-
 /*---------------------------------------------------------------
 					TRuntimeClassId::derivedFrom
  ---------------------------------------------------------------*/
