@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -20,11 +20,34 @@
 
 #include <mrpt/utils/CTicTac.h>
 #include <cstring>
-#include <cassert>
+
+// For Windows: get the common code out of CTicTac so it's only run once!
+#ifdef MRPT_OS_WINDOWS
+struct AuxWindowsTicTac
+{
+	static AuxWindowsTicTac & GetInstance()
+	{
+		static AuxWindowsTicTac obj;
+		return obj;
+	}
+
+	double dbl_period;
+
+private:
+	LARGE_INTEGER m_freq;
+
+	AuxWindowsTicTac() : dbl_period(.0)
+	{
+		QueryPerformanceFrequency(&m_freq);
+		ASSERTMSG_(m_freq.QuadPart != 0, "Error getting QueryPerformanceFrequency()");
+		dbl_period = 1.0 / static_cast<double>(m_freq.QuadPart);
+	}
+};
+
+#endif
 
 using namespace mrpt::utils;
 
-
 // Macros for easy access to memory with the correct types:
 #ifdef MRPT_OS_WINDOWS
 #	define	LARGE_INTEGER_NUMS	reinterpret_cast<LARGE_INTEGER*>(largeInts)
@@ -37,25 +60,16 @@ using namespace mrpt::utils;
  ---------------------------------------------------------------*/
 CTicTac::CTicTac()
 {
-	memset( largeInts, 0, sizeof(largeInts) );
+	::memset( largeInts, 0, sizeof(largeInts) );
 
 #ifdef MRPT_OS_WINDOWS
-	ASSERT_( sizeof( largeInts ) > 3*sizeof(LARGE_INTEGER) );
-	LARGE_INTEGER *l= LARGE_INTEGER_NUMS;
-	QueryPerformanceFrequency(&l[0]);
+	static_assert( sizeof( largeInts ) >= 2*sizeof(LARGE_INTEGER), "sizeof(LARGE_INTEGER) failed!");
 #else
-	assert( sizeof( largeInts ) > 2*sizeof(struct timeval) );
+	static_assert( sizeof( largeInts ) > 2*sizeof(struct timeval), "sizeof(struct timeval) failed!");
 #endif
 	Tic();
 }
 
-/*---------------------------------------------------------------
-						Destructor
- ---------------------------------------------------------------*/
-CTicTac::~CTicTac()
-{
-}
-
 /*---------------------------------------------------------------
 						Tic
 	Starts the stopwatch
@@ -64,10 +78,10 @@ void	CTicTac::Tic()
 {
 #ifdef MRPT_OS_WINDOWS
 	LARGE_INTEGER *l= LARGE_INTEGER_NUMS;
-	QueryPerformanceCounter(&l[1]);
+	QueryPerformanceCounter(&l[0]);
 #else
 	struct timeval* ts = TIMEVAL_NUMS;
-    gettimeofday( &ts[0], NULL);
+	gettimeofday( &ts[0], NULL);
 #endif
 }
 
@@ -79,13 +93,11 @@ double	CTicTac::Tac()
 {
 #ifdef MRPT_OS_WINDOWS
 	LARGE_INTEGER *l= LARGE_INTEGER_NUMS;
-	QueryPerformanceCounter( &l[2] );
-	return (l[2].QuadPart-l[1].QuadPart)/static_cast<double>(l[0].QuadPart);
+	QueryPerformanceCounter( &l[1] );
+	return (l[1].QuadPart-l[0].QuadPart) * AuxWindowsTicTac::GetInstance().dbl_period;
 #else
 	struct timeval* ts = TIMEVAL_NUMS;
-    gettimeofday( &ts[1], NULL);
-
-    return ( ts[1].tv_sec - ts[0].tv_sec) +
-           1e-6*(  ts[1].tv_usec - ts[0].tv_usec );
+	gettimeofday( &ts[1], NULL);
+	return ( ts[1].tv_sec - ts[0].tv_sec) + 1e-6*(  ts[1].tv_usec - ts[0].tv_usec );
 #endif
 }
