@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -16,11 +16,6 @@ namespace mrpt
 {
 	namespace utils
 	{
-		/** Register all pending classes - to be called just before de-serializing an object, for example.
-		  * After calling this method, pending_class_registers_modified is set to false until pending_class_registers() is invoked.
- 		  */
-		void BASE_IMPEXP registerAllPendingClasses();
-
 		typedef void (*TRegisterFunction)(); // A void(void) function
 
 		// Use a queue for the pending register issues, but also an atomic counter, which is much faster to check than a CS.
