@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -15,7 +15,8 @@
 #include <mrpt/utils/CTicTac.h>
 #include <mrpt/system/string_utils.h>
 #include <mrpt/system/threads.h>
-#include <mrpt/synch.h>
+#include <mrpt/synch/CSemaphore.h>
+#include <mrpt/synch/CThreadSafeVariable.h>
 #include <cstring>
 #include <stdio.h>
 
@@ -73,11 +74,10 @@ mrpt::utils::net::http_get(
 }
 
 
-/*---------------------------------------------------------------
-							http_get
-  ---------------------------------------------------------------*/
-ERRORCODE_HTTP  BASE_IMPEXP
-mrpt::utils::net::http_get(
+ERRORCODE_HTTP BASE_IMPEXP
+mrpt::utils::net::http_request(
+	const string   & http_method,
+	const string   & http_send_content,
 	const string	&url,
 	vector_byte		&out_content,
 	string			&out_errormsg,
@@ -120,7 +120,6 @@ mrpt::utils::net::http_get(
 		server_addr.resize(pos);
 	}
 
-
 	CClientTCPSocket	sock;
 
 	try {
@@ -157,13 +156,18 @@ mrpt::utils::net::http_get(
 			headers_to_send["Authorization"]=string("Basic ")+encoded_str;
 		}
 
+		if (!http_send_content.empty() && headers_to_send.find("Content-Length") == headers_to_send.end())
+		{
+			headers_to_send["Content-Length"] = mrpt::format("%u", (unsigned int)http_send_content.size());
+		}
 
 		// Prepare the request string
 		// ---------------------------------
 		string req = format(
-		  "GET %s HTTP/1.1\r\n"
-          "Host: %s\r\n",
-		  get_object.c_str(),server_addr.c_str());
+			"%s %s HTTP/1.1\r\n"
+			"Host: %s\r\n",
+			http_method.c_str(),
+			get_object.c_str(),server_addr.c_str());
 
 		// Other headers:
 		for (TParameters<string>::const_iterator i=headers_to_send.begin();i!=headers_to_send.end();++i)
@@ -177,6 +181,9 @@ mrpt::utils::net::http_get(
 		// End:
 		req+="\r\n";
 
+		// Any POST data?
+		req += http_send_content;
+
 		// Send:
 		sock.sendString(req);
 
@@ -352,7 +359,6 @@ mrpt::utils::net::http_get(
 			}
 		}
 
-
 		// Set the content output:
 		out_content.swap(buf);
 
@@ -375,6 +381,27 @@ mrpt::utils::net::http_get(
 }
 
 
+/*---------------------------------------------------------------
+	http_get
+---------------------------------------------------------------*/
+ERRORCODE_HTTP  BASE_IMPEXP
+mrpt::utils::net::http_get(
+	const string	&url,
+	vector_byte		&out_content,
+	string			&out_errormsg,
+	int				port,
+	const string	&auth_user,
+	const string	&auth_pass,
+	int				*out_http_responsecode,
+	mrpt::utils::TParameters<string>  *extra_headers,
+	mrpt::utils::TParameters<string>  *out_headers,
+	int  timeout_ms
+	)
+{
+	return http_request("GET", "", url, out_content, out_errormsg, port, auth_user, auth_pass, out_http_responsecode, extra_headers, out_headers, timeout_ms);
+}
+
+
 // ===========   net::DNS_resolve_async   ==============
 // Yeah, it's gonna got pretty complicated...
 struct TDNSThreadData
@@ -400,7 +427,6 @@ void thread_DNS_solver_async(TDNSThreadData &dat); // Frd decl.
   *
   * \return true on success, false on timeout or other error.
   */
-
 bool net::DNS_resolve_async(
 	const std::string &server_name,
 	std::string	 &out_ip,
@@ -469,7 +495,8 @@ void thread_DNS_solver_async(TDNSThreadData &param)
 	}
 	else
 	{
-		struct in_addr ADDR = *((struct in_addr *)he->h_addr);
+		struct in_addr ADDR;
+		::memcpy(&ADDR, he->h_addr, sizeof(ADDR)); // Was: *((struct in_addr *)he->h_addr);
 		// Convert address to text:
 		dns_result = string( inet_ntoa(ADDR) );
 	}
@@ -506,3 +533,41 @@ std::string mrpt::utils::net::getLastSocketErrorStr()
 #endif
 }
 
+
+MRPT_TODO("Modify ping to run on Windows + Test this");
+bool mrpt::utils::net::Ping(
+		const std::string& address,
+    const int& max_attempts,
+    std::string* output_str/*=NULL*/)
+{
+	using namespace std;
+
+  // Format a command string
+	string cmd_str = "ping";
+
+  // different "count" argument for Windows and *NIX  systems
+#if defined(MRPT_OS_LINUX) || defined(MRPT_OS_APPLE)
+	string count_arg_str = "-c " + num2str(max_attempts);
+#else
+	THROW_EXCEPTION("Ping not implemented on Windows Yet.")
+
+	string count_arg_str = "-n " + num2str(max_attempts);
+#endif
+
+	string redirection_str = "2>&1";
+
+	// Join the command subparts
+	string cmd_full_str = mrpt::format("%s %s %s %s",
+			cmd_str.c_str(),
+			count_arg_str.c_str(),
+			address.c_str(),
+			redirection_str.c_str());
+
+  // Finally exec the command
+  int code = executeCommand(cmd_full_str, output_str);
+
+  return (code == 0);
+}
+
+
+
