@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -10,11 +10,15 @@
 #ifndef _mrpt_graphs_H
 #define _mrpt_graphs_H
 
+#include <mrpt/graphs/TNodeAnnotations.h>
+#include <mrpt/graphs/TMRSlamNodeAnnotations.h>
 #include <mrpt/graphs/CAStarAlgorithm.h>
 #include <mrpt/graphs/CGraphPartitioner.h>
 #include <mrpt/graphs/CNetworkOfPoses.h>
 #include <mrpt/graphs/dijkstra.h>
 #include <mrpt/graphs/CDirectedGraph.h>
 #include <mrpt/graphs/CDirectedTree.h>
+#include <mrpt/graphs/THypothesis.h>
+#include <mrpt/graphs/CHypothesisNotFoundException.h>
 
 #endif
