@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -12,9 +12,6 @@
 #include <mrpt/utils/utils_defs.h>
 #include <list>
 
-/*---------------------------------------------------------------
-	Class
-  ---------------------------------------------------------------*/
 namespace mrpt
 {
 	namespace graphs
@@ -28,7 +25,7 @@ namespace mrpt
 		  *
 		  *  Note that nodes are *not* explicitly listed anywhere: their existence is only inferred from their ID numbers in the list
 		  *  of edges in the \a edges_to_children data structure. If you want to include information for each node, derive from this class
-		  *  and create a separte container for that data.
+		  *  and create a separate container for that data.
 		  *
 		  *  This class is less general than CDirectedGraph but more efficient to traverse (see \a visitDepthFirst and \a visitBreadthFirst).
 		  *
