@@ -2,13 +2,14 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
 
 
-#include <mrpt/graphslam.h>
+#include <mrpt/graphslam/types.h>
+#include <mrpt/graphslam/levmarq.h>
 #include <mrpt/graphs.h>
 #include <mrpt/random.h>
 #include <mrpt/utils/CMemoryStream.h>
