@@ -187,7 +187,7 @@ namespace mrpt
 		  *  IMPORTANTE NOTICE: Event handlers in your observer class will be invoked from the wxWidgets internal MRPT thread,
 		  *    so all your code in the handler must be thread safe.
 		  *
-		  * \sa mrptEventMouseDown
+		  * \sa mrptEventMouseMove
 		  */
 		class GUI_IMPEXP mrptEventMouseDown : public mrpt::utils::mrptEvent
 		{
@@ -208,6 +208,30 @@ namespace mrpt
 			bool   rightButton;
 		}; // End of class def.
 
+		   /**  An event sent by a window when the mouse is moved over it.
+		   *  IMPORTANTE NOTICE: Event handlers in your observer class will be invoked from the wxWidgets internal MRPT thread,
+		   *    so all your code in the handler must be thread safe.
+		   * \sa mrptEventMouseDown
+		   */
+		class GUI_IMPEXP mrptEventMouseMove : public mrpt::utils::mrptEvent
+		{
+		protected:
+			virtual void do_nothing() MRPT_OVERRIDE { } //!< Just to allow this class to be polymorphic
+		public:
+			inline mrptEventMouseMove(
+				CBaseGUIWindow *obj,
+				mrpt::utils::TPixelCoord  _coords,
+				bool   _leftButton,
+				bool   _rightButton
+			) : source_object(obj), coords(_coords), leftButton(_leftButton), rightButton(_rightButton)
+			{ }
+
+			CBaseGUIWindow *source_object;
+			mrpt::utils::TPixelCoord  coords;
+			bool   leftButton;
+			bool   rightButton;
+		}; // End of class def.
+
 		/**  An event sent by a window upon when it's about to be closed, either manually by the user or programatically.
 		  *   The event field member \a allow_close is default by default, but can be set to false in the event callback
 		  *   to forbid the window to be closed by the user. If the event corresponds to a programatic close, this field is ignored.
