@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -13,8 +13,6 @@
 #include <mrpt/system/os.h>
 #include <mrpt/gui/WxSubsystem.h>
 
-#include <mrpt/utils/CStartUpClassesRegister.h>
-
 using namespace mrpt;
 using namespace mrpt::gui;
 using namespace mrpt::utils;
@@ -23,9 +21,6 @@ using namespace std;
 
 IMPLEMENTS_VIRTUAL_MRPT_OBJECT(CBaseGUIWindow, CObject,mrpt::gui)
 
-extern CStartUpClassesRegister  mrpt_gui_class_reg;
-const int dumm = mrpt_gui_class_reg.do_nothing(); // Avoid compiler removing this class in static linking
-
 
 /*---------------------------------------------------------------
 					Ctor
