@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -52,8 +52,7 @@ void CHMTSLAM::generateLogFiles(unsigned int nIteration)
 	{
 		CCriticalSectionLocker  locker( &m_LMHs_cs );
 
-		printf_debug("[LOG] Number of LMHs: %u\n", (unsigned int)m_LMHs.size() );
-
+		MRPT_LOG_INFO_STREAM( "[LOG] Number of LMHs: " <<  m_LMHs.size());
 
 		// Generate 3D view of local areas:
 		{
@@ -95,7 +94,7 @@ void CHMTSLAM::generateLogFiles(unsigned int nIteration)
 
 					sceneLSLAM->enableFollowCamera(true);
 
-					printf_debug("[LOG] Saving %s\n", filLocalAreas.c_str());
+					MRPT_LOG_INFO_STREAM( "[LOG] Saving " << filLocalAreas);
 					CFileGZOutputStream(filLocalAreas) << *sceneLSLAM;
 				}
 
@@ -138,14 +137,13 @@ void CHMTSLAM::generateLogFiles(unsigned int nIteration)
 		if ((CNT++ % 20) == 0)
 		{
 			string hmtmap_file( format("%s/HMTSLAM_state/state_%05u.hmtslam", m_options.LOG_OUTPUT_DIR.c_str(), nIteration ) );
-			printf_debug("[LOG] Saving %s\n", hmtmap_file.c_str());
+			MRPT_LOG_INFO_STREAM( "[LOG] Saving: " << hmtmap_file.c_str());
 			CFileGZOutputStream(hmtmap_file) << *this;
 		}
 	}
 #endif
 
 
-
 #if 1
 	{
 		// Update the poses-graph in the HMT-map from the LMH to draw it:
@@ -161,7 +159,7 @@ void CHMTSLAM::generateLogFiles(unsigned int nIteration)
 			COpenGLScene	sceneGlobalHMTMAP;
 			{
 				CCriticalSectionLocker  locker( &m_map_cs );
-				printf_debug("[LOG] HMT-map: %u nodes/ %u arcs\n", (unsigned int)m_map.nodeCount(), (unsigned int)m_map.arcCount() );
+				MRPT_LOG_INFO_STREAM( "[LOG] HMT-map: "<< m_map.nodeCount() << " nodes/ "<< m_map.arcCount() << " arcs");
 
 				m_map.getAs3DScene(
 					sceneGlobalHMTMAP,					// Scene
@@ -172,7 +170,7 @@ void CHMTSLAM::generateLogFiles(unsigned int nIteration)
 			}
 
 			string hmtmap_file( format("%s/HMAP_3D/mostLikelyHMT_MAP_%05u.3Dscene", m_options.LOG_OUTPUT_DIR.c_str(), nIteration ) );
-			printf_debug("[LOG] Saving %s\n", hmtmap_file.c_str());
+			MRPT_LOG_INFO_STREAM( "[LOG] Saving "<< hmtmap_file);
 			CFileGZOutputStream(hmtmap_file) << sceneGlobalHMTMAP;
 		}
 	}
@@ -190,7 +188,7 @@ void CHMTSLAM::generateLogFiles(unsigned int nIteration)
 	}
 
 	double t_log = tictac.Tac();
-	printf_debug("[LOG] Time for logging: %f ms\n", 1000*t_log);
+	MRPT_LOG_INFO_STREAM( "[LOG] Time for logging: " << mrpt::system::formatTimeInterval(t_log));
 
 	MRPT_END
 }
