@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -20,7 +20,7 @@
 #include <mrpt/poses/CPose3DPDFParticles.h>
 #include <mrpt/math/ops_containers.h>
 #include <mrpt/random.h>
-#include <mrpt/graphslam.h>
+#include <mrpt/graphslam/levmarq.h>
 
 using namespace std;
 using namespace mrpt;
@@ -1172,7 +1172,7 @@ void  CHierarchicalMapMHPartition::getAs3DScene(
 	{
 		const CHMHMapNodePtr node = getNodeByID( it->first );
 		const CPose3D		&pose = it->second.mean ;
-		const CPose3D		&meanPose= it2->second ;
+		const CPose3D		meanPose= CPose3D(it2->second);
 
 		// The sphere of the node:
 		mrpt::opengl::CSpherePtr objSphere = mrpt::opengl::CSphere::Create();
@@ -1219,7 +1219,7 @@ void  CHierarchicalMapMHPartition::getAs3DScene(
 				glObj->setPose( auxPose );
 				//glObj->m_z = 0;
 
-				glObj->setDiskRadius(0.05);
+				glObj->setDiskRadius(0.05f);
 				glObj->setSlicesCount(20);
 				glObj->setLoopsCount(10);
 
