@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -11,11 +11,12 @@
 #define CNationalInstrumentsDAQ_H
 
 #include <mrpt/obs/CObservationRawDAQ.h>
-#include <mrpt/utils/CDebugOutputCapable.h>
+#include <mrpt/utils/COutputLogger.h>
 #include <mrpt/hwdrivers/CGenericSensor.h>
 #include <mrpt/synch/CPipe.h>
 #include <mrpt/system/threads.h>
 #include <list>
+#include <memory>
 
 namespace mrpt
 {
@@ -32,7 +33,7 @@ namespace mrpt
 		*  Samples will be returned inside mrpt::obs::CObservationRawDAQ in "packets" of a predefined number of samples, which can 
 		*  be changed by the user through the "samplesPerChannelToRead" parameter of each task.
 		*
-		*  For multichannels tasks, samples will be **interleaved**. For example, the readings from succesive timesteps for 4 ADC channels 
+		*  For multichannels tasks, samples will be **interleaved**. For example, the readings from successive timesteps for 4 ADC channels 
 		*  will be available in the ADC vector inside mrpt::obs::CObservationRawDAQ in this order:
 		*
 		*   - A0[0] A1[0] A2[0] A3[0]  A0[1] A1[1] A2[1] A3[1]  A0[2] A1[2] A2[2] A3[2] ...
@@ -153,7 +154,7 @@ namespace mrpt
 		*
 		* \ingroup mrpt_hwdrivers_grp
 		*/
-		class HWDRIVERS_IMPEXP CNationalInstrumentsDAQ : public utils::CDebugOutputCapable, public CGenericSensor
+		class HWDRIVERS_IMPEXP CNationalInstrumentsDAQ : public mrpt::utils::COutputLogger, public CGenericSensor
 		{
 			DEFINE_GENERIC_SENSOR(CNationalInstrumentsDAQ)
 		public:
@@ -334,8 +335,13 @@ namespace mrpt
 
 				void * taskHandle;
 				mrpt::system::TThreadHandle hThread;
+#if MRPT_HAS_CXX11
+				std::unique_ptr<mrpt::synch::CPipeReadEndPoint> read_pipe;
+				std::unique_ptr<mrpt::synch::CPipeWriteEndPoint> write_pipe;
+#else
 				std::auto_ptr<mrpt::synch::CPipeReadEndPoint> read_pipe;
 				std::auto_ptr<mrpt::synch::CPipeWriteEndPoint> write_pipe;
+#endif
 				bool must_close, is_closed;
 				mrpt::synch::CAtomicCounter  new_obs_available;
 
