@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -13,9 +13,8 @@
 #include <mrpt/hwdrivers/CInterfaceFTDI.h>
 #include <mrpt/hwdrivers/CInterfaceFTDIMessages.h>
 #include <mrpt/utils/CMessage.h>
-#include <mrpt/synch.h>
 #include <mrpt/math/CMatrixTemplate.h>
-#include <mrpt/utils/CDebugOutputCapable.h>
+#include <mrpt/utils/COutputLogger.h>
 #include <mrpt/utils/CConfigFileBase.h>
 #include <mrpt/obs/CObservationRange.h>
 
@@ -43,7 +42,7 @@ namespace mrpt
 		  *  \endcode
 		  * \ingroup mrpt_hwdrivers_grp
 		  */
-		class HWDRIVERS_IMPEXP CRoboticHeadInterface : public mrpt::utils::CDebugOutputCapable
+		class HWDRIVERS_IMPEXP CRoboticHeadInterface : public mrpt::utils::COutputLogger
 		{
 			private:
 				CInterfaceFTDIMessages	m_usbConnection;
