@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -37,6 +37,7 @@ IMPLEMENTS_GENERIC_SENSOR(CCameraSensor,mrpt::hwdrivers)
                 Constructor
    ----------------------------------------------------- */
 CCameraSensor::CCameraSensor() :
+	mrpt::utils::COutputLogger("CCameraSensor"),
 	m_sensorPose			(),
 	m_grabber_type			("opencv"),
 	m_capture_grayscale		(false),
@@ -128,7 +129,7 @@ void CCameraSensor::initialize()
 		if (idx<0)
 		{
 			m_state = CGenericSensor::ssError;
-			THROW_EXCEPTION_CUSTOM_MSG1("Invalid value of :'%s'",m_cv_camera_type.c_str())
+			THROW_EXCEPTION_FMT("Invalid value of :'%s'",m_cv_camera_type.c_str())
 		}
 
 		cout << format("[CCameraSensor::initialize] opencv camera, index: %i type: %i...\n", int(m_cv_camera_index),idx);
@@ -171,7 +172,7 @@ void CCameraSensor::initialize()
 		if (!m_cap_ffmpeg->openURL( m_ffmpeg_url, m_capture_grayscale ))
 		{
 			m_state = CGenericSensor::ssError;
-			THROW_EXCEPTION_CUSTOM_MSG1("Error opening FFmpeg stream: %s", m_ffmpeg_url.c_str())
+			THROW_EXCEPTION_FMT("Error opening FFmpeg stream: %s", m_ffmpeg_url.c_str())
 		}
 	}
 	else if (m_grabber_type=="swissranger")
@@ -258,7 +259,7 @@ void CCameraSensor::initialize()
 		if (! m_cap_rawlog->open(m_rawlog_file) )
 		{
 			m_state = CGenericSensor::ssError;
-			THROW_EXCEPTION_CUSTOM_MSG1("Error opening rawlog file: %s", m_rawlog_file.c_str())
+			THROW_EXCEPTION_FMT("Error opening rawlog file: %s", m_rawlog_file.c_str())
 		}
 		// File open OK.
 		// Localize the external images directory of this rawlog, if it exists:
@@ -286,10 +287,10 @@ void CCameraSensor::initialize()
 			m_cap_flycap_stereo_l = new CImageGrabber_FlyCapture2();
 			m_cap_flycap_stereo_r = new CImageGrabber_FlyCapture2();
 
-			cout << "[CCameraSensor::initialize] PGR FlyCapture2 stereo camera: Openning LEFT camera...\n";
+			cout << "[CCameraSensor::initialize] PGR FlyCapture2 stereo camera: Opening LEFT camera...\n";
 			m_cap_flycap_stereo_l->open(m_flycap_stereo_options[0], false /* don't start grabbing */ );
 
-			cout << "[CCameraSensor::initialize] PGR FlyCapture2 stereo camera: Openning RIGHT camera...\n";
+			cout << "[CCameraSensor::initialize] PGR FlyCapture2 stereo camera: Opening RIGHT camera...\n";
 			m_cap_flycap_stereo_r->open(m_flycap_stereo_options[1], false /* don't start grabbing */ );
 
 			// Now, start grabbing "simultaneously":
@@ -320,7 +321,7 @@ void CCameraSensor::initialize()
 		// Open it:
 		try
 		{
-			m_cap_duo3d = new CDUO3DCamera( m_duo3d_options );		
+			m_cap_duo3d = new CDUO3DCamera( m_duo3d_options );
 		} catch (std::exception &e)
 		{
 			m_state = CGenericSensor::ssError;
@@ -328,7 +329,7 @@ void CCameraSensor::initialize()
 		}
 	}
 	else
-		THROW_EXCEPTION_CUSTOM_MSG1("Unknown 'grabber_type' found: %s", m_grabber_type.c_str() )
+		THROW_EXCEPTION_FMT("Unknown 'grabber_type' found: %s", m_grabber_type.c_str() )
 
 	// Change state:
 	cout << "[CCameraSensor::initialize] Done!" << endl;
@@ -529,7 +530,7 @@ void  CCameraSensor::loadConfig_sensorSpecific(
 	double the_fps = configSource.read_double( iniSection, "dc1394_framerate", 15.0 );
 	it_fps = map_fps.find( the_fps );
 	if ( it_fps == map_fps.end() )
-		THROW_EXCEPTION_CUSTOM_MSG1("ERROR: DC1394 framerate seems to be not a valid number: %f",the_fps);
+		THROW_EXCEPTION_FMT("ERROR: DC1394 framerate seems to be not a valid number: %f",the_fps);
 
 	m_dc1394_options.framerate =  it_fps->second;
 
@@ -547,7 +548,7 @@ void  CCameraSensor::loadConfig_sensorSpecific(
 	string the_color_coding = mrpt::system::upperCase( configSource.read_string_first_word( iniSection, "dc1394_color_coding", "COLOR_CODING_YUV422" ) );
 	it_color = map_color.find(the_color_coding );
 	if (it_color == map_color.end())
-		THROW_EXCEPTION_CUSTOM_MSG1("ERROR: Color coding seems not to be valid : '%s'",the_color_coding.c_str() );
+		THROW_EXCEPTION_FMT("ERROR: Color coding seems not to be valid : '%s'",the_color_coding.c_str() );
 	m_dc1394_options.color_coding = it_color->second;
 
 
@@ -733,7 +734,7 @@ void CCameraSensor::getNextFrame( vector<CSerializablePtr> & out_obs )
 				m_state = CGenericSensor::ssError;
 				THROW_EXCEPTION("Error reading images from directory");
 			}
-			std::string auxR = format( "%s/%s", m_img_dir_url.c_str(), m_img_dir_right_format.c_str() );			
+			std::string auxR = format( "%s/%s", m_img_dir_url.c_str(), m_img_dir_right_format.c_str() );
 			if( !stObs->imageRight.loadFromFile( format(auxR.c_str(), m_img_dir_counter++)) )
 			{
 				m_state = CGenericSensor::ssError;
@@ -1110,7 +1111,7 @@ void CCameraSensor::getNextFrame( vector<CSerializablePtr> & out_obs )
 
 	if (delayed_insertion_in_obs_queue)
 	{
-		if( m_cap_duo3d && m_cap_duo3d->captureIMUIsSet() && obsIMU )	
+		if( m_cap_duo3d && m_cap_duo3d->captureIMUIsSet() && obsIMU )
 			out_obs.push_back( CObservationPtr(obsIMU) );
 	}
 	else
@@ -1118,7 +1119,7 @@ void CCameraSensor::getNextFrame( vector<CSerializablePtr> & out_obs )
 		if( stObs )		out_obs.push_back( CObservationPtr(stObs) );
 		if( obs )		out_obs.push_back( CObservationPtr(obs) );
 		if( obs3D )		out_obs.push_back( CObservationPtr(obs3D) );
-	} 
+	}
 	return;
 }
 
@@ -1158,7 +1159,7 @@ void CCameraSensor::setPathForExternalImages( const std::string &directory )
 {
 	if (!mrpt::system::createDirectory( directory ))
 	{
-		THROW_EXCEPTION_CUSTOM_MSG1("Error: Cannot create the directory for externally saved images: %s",directory.c_str() )
+		THROW_EXCEPTION_FMT("Error: Cannot create the directory for externally saved images: %s",directory.c_str() )
 	}
 	m_path_for_external_images = directory;
 }
