@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -47,6 +47,7 @@ private:
                 Constructor
    ----------------------------------------------------- */
 CGPSInterface::CGPSInterface() :
+	mrpt::utils::COutputLogger("CGPSInterface"),
 	m_data_stream(NULL),    // Typically a CSerialPort created by this class, but may be set externally.
 	m_data_stream_cs(NULL),
 	m_data_stream_is_external(false),
@@ -327,7 +328,7 @@ void  CGPSInterface::doProcess()
 	catch (std::exception &)
 	{
 		// ERROR:
-		printf_debug("[CGPSInterface::doProcess] Error reading stream of data: Closing communications\n");
+		MRPT_LOG_ERROR("[CGPSInterface::doProcess] Error reading stream of data: Closing communications\n");
 		if(stream_serial) {
 			CCriticalSectionLocker lock(m_data_stream_cs);
 			stream_serial->close();
