@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -213,14 +213,14 @@ CPoint3D CIbeoLuxETH::convertToCartesian(float vrad, float hrad, float distance)
 	return point;
 }
 
-float CIbeoLuxETH::convertTicksToHRad(int hticks, int hticksPerRotation)
+double CIbeoLuxETH::convertTicksToHRad(int hticks, int hticksPerRotation)
 {
 	return M_PI*2 * hticks / hticksPerRotation;
 }
 
-float CIbeoLuxETH::convertLayerToRad(int scanlayer)
+double CIbeoLuxETH::convertLayerToRad(int scanlayer)
 {
-	float vangle;
+	double vangle;
 
 	switch(scanlayer)
 	{
