@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -11,22 +11,13 @@
 
 #define MRPT_NO_WARN_BIG_HDR
 #include <mrpt/hwdrivers.h>
-
-#include <mrpt/utils/CStartUpClassesRegister.h>
+#include <mrpt/utils/initializer.h>
 
 using namespace mrpt::utils;
 using namespace mrpt::hwdrivers;
 
 
-void registerAllClasses_mrpt_hwdrivers();
-
-CStartUpClassesRegister  mrpt_hwdrivers_class_reg(&registerAllClasses_mrpt_hwdrivers);
-
-
-/** Register existing sensors.
-  * \sa mrpt::hwdrivers::CGenericSensor::createSensor
-  */
-void registerAllClasses_mrpt_hwdrivers()
+MRPT_INITIALIZER(registerAllClasses_mrpt_hwdrivers)
 {
 #if !defined(DISABLE_MRPT_AUTO_CLASS_REGISTRATION)
 	CSickLaserUSB::doRegister();
@@ -35,13 +26,9 @@ void registerAllClasses_mrpt_hwdrivers()
 	CRoboPeakLidar::doRegister();
 	CGPSInterface::doRegister();
 	CBoardSonars::doRegister();
-	CBoardIR::doRegister();
-	CBoardDLMS::doRegister();
 	CIMUXSens::doRegister();
 	CIMUXSens_MT4::doRegister();
 	CCameraSensor::doRegister();
-	CActivMediaRobotBase::doRegister();
-	CPtuHokuyo::doRegister();
 	CWirelessPower::doRegister();
 	CRaePID::doRegister();
 	CImpinjRFID::doRegister();
@@ -65,4 +52,3 @@ void registerAllClasses_mrpt_hwdrivers()
 	CVelodyneScanner::doRegister();
 #endif
 }
-
