@@ -1,7 +1,13 @@
 /*
- * Copyright (c) 2014, RoboPeak
- * All rights reserved.
+ *  RPLIDAR SDK
  *
+ *  Copyright (c) 2009 - 2014 RoboPeak Team
+ *  http://www.robopeak.com
+ *  Copyright (c) 2014 - 2016 Shanghai Slamtec Co., Ltd.
+ *  http://www.slamtec.com
+ *
+ */
+/*
  * Redistribution and use in source and binary forms, with or without 
  * modification, are permitted provided that the following conditions are met:
  *
@@ -25,14 +31,6 @@
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  */
-/*
- *  RoboPeak LIDAR System
- *  Serial based RPlidar Driver
- *
- *  Copyright 2009 - 2014 RoboPeak Team
- *  http://www.robopeak.com
- * 
- */
 
 #pragma once
 
@@ -46,6 +44,10 @@ public:
         MAX_SCAN_NODES = 2048,
     };
 
+    enum {
+        LEGACY_SAMPLE_DURATION = 476,
+    };
+
     RPlidarDriverSerialImpl();
     virtual ~RPlidarDriverSerialImpl();
 
@@ -58,37 +60,53 @@ public:
 
     virtual u_result getHealth(rplidar_response_device_health_t &, _u32 timeout = DEFAULT_TIMEOUT);
     virtual u_result getDeviceInfo(rplidar_response_device_info_t &, _u32 timeout = DEFAULT_TIMEOUT);
-	virtual u_result getFrequency(rplidar_response_measurement_node_t * nodebuffer, size_t count, float & frequency);
+    virtual u_result getSampleDuration_uS(rplidar_response_sample_rate_t & rateInfo, _u32 timeout = DEFAULT_TIMEOUT);
+
+    virtual u_result setMotorPWM(_u16 pwm);
+    virtual u_result startMotor();
+    virtual u_result stopMotor();
+    virtual u_result checkMotorCtrlSupport(bool & support, _u32 timeout = DEFAULT_TIMEOUT);
+	virtual u_result getFrequency(bool inExpressMode, size_t count, float & frequency, bool & is4kmode);
+
+    virtual u_result startScan(bool force = false, bool autoExpressMode = true);
+    virtual u_result startScanNormal(bool force, _u32 timeout = DEFAULT_TIMEOUT);
+    virtual u_result startScanExpress(bool fixedAngle, _u32 timeout = DEFAULT_TIMEOUT);
+    virtual u_result checkExpressScanSupported(bool & support, _u32 timeout = DEFAULT_TIMEOUT);
 
-    virtual u_result startScan(bool force, _u32 timeout = DEFAULT_TIMEOUT);
     virtual u_result stop(_u32 timeout = DEFAULT_TIMEOUT);
     virtual u_result grabScanData(rplidar_response_measurement_node_t * nodebuffer, size_t & count, _u32 timeout = DEFAULT_TIMEOUT);
     virtual u_result ascendScanData(rplidar_response_measurement_node_t * nodebuffer, size_t count);
 
-	virtual u_result stopMotor();
-	virtual u_result startMotor();
-	
-	
 protected:
-    u_result _waitNode(rplidar_response_measurement_node_t * node, _u32 timeout);
+    u_result _waitNode(rplidar_response_measurement_node_t * node, _u32 timeout = DEFAULT_TIMEOUT);
     u_result _waitScanData(rplidar_response_measurement_node_t * nodebuffer, size_t & count, _u32 timeout = DEFAULT_TIMEOUT);
 	u_result _cacheScanData();
+    void     _capsuleToNormal(const rplidar_response_capsule_measurement_nodes_t & capsule, rplidar_response_measurement_node_t *nodebuffer, size_t &nodeCount);
+    u_result _waitCapsuledNode(rplidar_response_capsule_measurement_nodes_t & node, _u32 timeout = DEFAULT_TIMEOUT);
+    u_result  _cacheCapsuledScanData();
     u_result _sendCommand(_u8 cmd, const void * payload = NULL, size_t payloadsize = 0);
-    u_result _waitResponseHeader(rplidar_ans_header_t * header, _u32 timeout);
+    u_result _waitResponseHeader(rplidar_ans_header_t * header, _u32 timeout = DEFAULT_TIMEOUT);
+    u_result _waitSampleRate(rplidar_response_sample_rate_t * res, _u32 timeout = DEFAULT_TIMEOUT);
 
     void     _disableDataGrabbing();
 
     bool     _isConnected;
     bool     _isScanning;
+    bool     _isSupportingMotorCtrl;
 
 	rp::hal::Locker         _lock;
     rp::hal::Event          _dataEvt;
     rp::hal::serial_rxtx  * _rxtx;
     rplidar_response_measurement_node_t      _cached_scan_node_buf[2048];
     size_t                                   _cached_scan_node_count;
-	rp::hal::Thread _cachethread;
 
-    
+    _u16                    _cached_sampleduration_std;
+    _u16                    _cached_sampleduration_express;
+
+    rplidar_response_capsule_measurement_nodes_t _cached_previous_capsuledata;
+    bool                                         _is_previous_capsuledataRdy;
+
+	rp::hal::Thread _cachethread;
 };
 
 
