@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -138,7 +138,7 @@ void CKinematicChain::recomputeAllPoses(mrpt::aligned_containers<mrpt::poses::CP
 	}
 }
 
-const float R = 0.01;
+const float R = 0.01f;
 
 void addBar_D(mrpt::opengl::CSetOfObjectsPtr &objs, const double d)
 {
