@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -211,7 +211,7 @@ namespace maps
 		void  resizeGrid(float new_x_min,float new_x_max,float new_y_min,float new_y_max,float new_cells_default_value = 0.5f, bool additionalMargin = true) MRPT_NO_THROWS;
 
 		/** Returns the area of the gridmap, in square meters */
-		inline double getArea() const { return size_x*size_y*mrpt::utils::square(resolution); }
+		inline double getArea() const { return size_x*size_y*mrpt::math::square(resolution); }
 
 		/** Returns the horizontal size of grid map in cells count */
 		inline unsigned int   getSizeX() const { return size_x; }
@@ -737,21 +737,15 @@ namespace maps
 		/** Load the gridmap from a image in a file (the format can be any supported by CImage::loadFromFile).
 		 * \param file The file to be loaded.
 		 * \param resolution The size of a pixel (cell), in meters. Recall cells are always squared, so just a dimension is needed.
-		 * \param xCentralPixel The "x" coordinate (0=first) for the pixel which will be taken at coordinates origin (0,0). If not supplied, it will be used the middle of the map.
-		 * \param yCentralPixel The "y" coordinate (0=first) for the pixel which will be taken at coordinates origin (0,0). If not supplied, it will be used the middle of the map.
+		 * \param xCentralPixel The `x` coordinate (0=first, increases <b>left to right</b> on the image) for the pixel which will be taken at coordinates origin (0,0). (Default: the center of the image)
+		 * \param yCentralPixel The `y` coordinate (0=first, increases <b>BOTTOM upwards</b> on the image) for the pixel which will be taken at coordinates origin (0,0). (Default: the center of the image)
 		 * \return False on any error.
 		 * \sa loadFromBitmap
 		 */
 		bool  loadFromBitmapFile(const std::string	&file, float resolution, float xCentralPixel = -1, float yCentralPixel =-1 );
 
 		/** Load the gridmap from a image in a file (the format can be any supported by CImage::loadFromFile).
-		 * \param img The image. Only a grayscale image will be used, so RGB components will be mixed if a color image is passed.
-		 * \param resolution The size of a pixel (cell), in meters. Recall cells are always squared, so just a dimension is needed.
-		 * \param xCentralPixel The "x" coordinate (0=first) for the pixel which will be taken at coordinates origin (0,0). If not supplied, it will be used the middle of the map.
-		 * \param yCentralPixel The "y" coordinate (0=first) for the pixel which will be taken at coordinates origin (0,0). If not supplied, it will be used the middle of the map.
-		 * \return False on any error.
-		 * \sa loadFromBitmapFile
-		 */
+		 *  See loadFromBitmapFile() for the meaning of parameters */
 		bool  loadFromBitmap(const mrpt::utils::CImage &img, float resolution, float xCentralPixel = -1, float yCentralPixel =-1 );
 
 		/** See the base class for more details: In this class it is implemented as correspondences of the passed points map to occupied cells.
@@ -792,7 +786,7 @@ namespace maps
 		// See docs in base class
 		double internal_computeObservationLikelihood( const mrpt::obs::CObservation *obs, const mrpt::poses::CPose3D &takenFrom ) MRPT_OVERRIDE;
 		// See docs in base class
-		bool internal_canComputeObservationLikelihood( const mrpt::obs::CObservation *obs ) MRPT_OVERRIDE;
+		bool internal_canComputeObservationLikelihood( const mrpt::obs::CObservation *obs ) const MRPT_OVERRIDE;
 
 		/** Returns a byte with the occupancy of the 8 sorrounding cells.
 		 * \param cx The cell index
