@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -90,6 +90,8 @@ CColouredPointsMap::~CColouredPointsMap()
  ---------------------------------------------------------------*/
 void CColouredPointsMap::reserve(size_t newLength)
 {
+	newLength = mrpt::utils::length2length4N(newLength);
+
 	x.reserve( newLength );
 	y.reserve( newLength );
 	z.reserve( newLength );
@@ -102,6 +104,8 @@ void CColouredPointsMap::reserve(size_t newLength)
 //  and old contents are not changed.
 void CColouredPointsMap::resize(size_t newLength)
 {
+	this->reserve(newLength); // to ensure 4N capacity
+
 	x.resize( newLength, 0 );
 	y.resize( newLength, 0 );
 	z.resize( newLength, 0 );
@@ -115,6 +119,8 @@ void CColouredPointsMap::resize(size_t newLength)
 //  and leaving all points to default values.
 void CColouredPointsMap::setSize(size_t newLength)
 {
+	this->reserve(newLength); // to ensure 4N capacity
+
 	x.assign( newLength, 0);
 	y.assign( newLength, 0);
 	z.assign( newLength, 0);
@@ -194,7 +200,7 @@ void  CColouredPointsMap::readFromStream(mrpt::utils::CStream &in, int version)
 			uint32_t n;
 			in >> n;
 
-			x.resize(n); y.resize(n); z.resize(n);
+			this->resize(n);
 
 			if (n>0)
 			{
@@ -231,10 +237,7 @@ void  CColouredPointsMap::readFromStream(mrpt::utils::CStream &in, int version)
 			uint32_t n;
 			in >> n;
 
-			x.resize(n);
-			y.resize(n);
-			z.resize(n);
-			//pointWeight.resize(n,1);	// Default value=1
+			this->resize(n);
 
 			if (n>0)
 			{
@@ -263,7 +266,7 @@ void  CColouredPointsMap::readFromStream(mrpt::utils::CStream &in, int version)
 					else
 					{
 						std::vector<uint32_t>  dummy_pointWeight(n);
-						in.ReadBufferFixEndianness((unsigned long*)(&dummy_pointWeight[0]),n);
+						in.ReadBufferFixEndianness(&dummy_pointWeight[0],n);
 					}
 				}
 			}
@@ -577,7 +580,7 @@ bool CColouredPointsMap::colourFromObservation( const CObservationImage &obs, co
 	else { chR = 0; chG = 1; chB = 2; }
 
 	unsigned int n_proj = 0;
-	const float factor = 1.0/255;	// Normalize pixels:
+	const float factor = 1.0f/255;	// Normalize pixels:
 
 	// Get the colour of the projected points
 	size_t k;
