@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -198,7 +198,7 @@ bool  CGasConcentrationGridMap2D::internal_insertObservation(
 				const CObservationGasSensors::TObservationENose *it = &o->m_readings[insertionOptions.enose_id];
 
 				// Compute the 3D sensor pose in world coordinates:
-				sensorPose = CPose2D( CPose3D(robotPose2D) + it->eNosePoseOnTheRobot );
+				sensorPose = CPose2D( CPose3D(robotPose2D) + CPose3D(it->eNosePoseOnTheRobot) );
 
 				// Compute the sensor reading value (Volts):
 				if (insertionOptions.gasSensorType==0x0000){	//compute the mean
@@ -228,7 +228,7 @@ bool  CGasConcentrationGridMap2D::internal_insertObservation(
 			{
 				const CObservationGasSensors::TObservationENose *it = &o->m_readings[0];
 				// Compute the 3D sensor pose in world coordinates:
-				sensorPose = CPose2D( CPose3D(robotPose2D) + it->eNosePoseOnTheRobot );
+				sensorPose = CPose2D( CPose3D(robotPose2D) +CPose3D(it->eNosePoseOnTheRobot) );
 				sensorReading = it->readingsVoltage[0];
 			}
 
@@ -242,20 +242,13 @@ bool  CGasConcentrationGridMap2D::internal_insertObservation(
 			m_average_normreadings_var  = (square(sensorReading - m_average_normreadings_mean) + m_average_normreadings_count*m_average_normreadings_var) /(1+m_average_normreadings_count);
 			m_average_normreadings_count++;
 
-#if 0
-			cout << "[DEBUG] m_average_normreadings_count: " << m_average_normreadings_count << " -> mean: " << m_average_normreadings_mean << " var: " <<  m_average_normreadings_var  << endl;
-#endif
-
 			// Finally, do the actual map update with that value:
 			this->insertIndividualReading(sensorReading, mrpt::math::TPoint2D(sensorPose.x(),sensorPose.y()) );
 			return true;	// Done!
-
 		} //endif correct "gasSensorLabel"
-
 	} // end if "CObservationGasSensors"
 
 	return false;
-
 	MRPT_END
 }
 
@@ -412,7 +405,7 @@ void  CGasConcentrationGridMap2D::readFromStream(mrpt::utils::CStream &in, int v
 				m_average_normreadings_count = N;
 			}
 
-			if (version>=4) 
+			if (version>=4)
 				in >> genericMapParams;
 
 			m_hasToRecoverMeanAndCov = true;
@@ -434,10 +427,10 @@ CGasConcentrationGridMap2D::TInsertionOptions::TInsertionOptions() :
 	gasSensorType				( 0x0000 ),		//By default use the mean between all e-nose sensors
 	windSensorLabel				( "windSensor" ),
 	useWindInformation			( false ),		//By default dont use wind
-	std_windNoise_phi			( 0.2 ),
-	std_windNoise_mod			( 0.2 ),
-	default_wind_direction		( 0.0 ),
-	default_wind_speed			( 1.0 )
+	std_windNoise_phi			( 0.2f ),
+	std_windNoise_mod			( 0.2f ),
+	default_wind_direction		( 0.0f ),
+	default_wind_speed			( 1.0f )
 {
 }
 
@@ -546,7 +539,7 @@ void  CGasConcentrationGridMap2D::getAs3DObject(
 void  CGasConcentrationGridMap2D::getWindAs3DObject( mrpt::opengl::CSetOfObjectsPtr &windObj) const
 {
 	//Return an arrow map of the wind state (module(color) and direction).
-	float scale = 0.2;
+	float scale = 0.2f;
 	size_t arrow_separation = 5;	//distance between arrows, expresed as times the cell resolution
 
 
@@ -859,9 +852,9 @@ bool CGasConcentrationGridMap2D::build_Gaussian_Wind_Grid()
 	std::string filename = format("Gaussian_Wind_Weights_res(%f)_stdPhi(%f)_stdR(%f).gz",LUT.resolution,LUT.std_phi,LUT.std_r);
 
 	// Fixed Params:
-	LUT.phi_inc = M_PI/8;									//Increment in the wind Angle. (rad)
+	LUT.phi_inc = M_PIf/8;									//Increment in the wind Angle. (rad)
 	LUT.phi_count = round(2*M_PI/LUT.phi_inc)+1;			//Number of angles to generate
-	LUT.r_inc = 0.1;										//Increment in the wind Module. (m)
+	LUT.r_inc = 0.1f;										//Increment in the wind Module. (m)
 	LUT.max_r = 2;											//maximum distance (m) to simulate
 	LUT.r_count = round(LUT.max_r/LUT.r_inc)+1;				//Number of wind modules to simulate
 
