@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -372,19 +372,6 @@ double	 COccupancyGridMap2D::computeObservationLikelihood_rayTracing(
 			0,
 			decimation	);
 
-		 /** /
-		 {
-			FILE	*f;
-
-			f=os::fopen("scan_sim.txt","wt");
-			for (int i=0;i<nRays;i++) os::fprintf(f,"%f ",simulatedObs.validRange[i] ? simulatedObs.scan[i]:0);
-			os::fclose(f);
-			f=os::fopen("scan_meas.txt","wt");
-			for (i=0;i<nRays;i++) os::fprintf(f,"%f ",o->validRange[i] ? o->scan[i]:0);
-			os::fclose(f);
-		 }
-		 / **/
-
 		 double		stdLaser   = likelihoodOptions.rayTracing_stdHit;
 		 double		stdSqrt2 = sqrt(2.0f) * stdLaser;
 
@@ -907,7 +894,7 @@ void  COccupancyGridMap2D::TLikelihoodOptions::dumpToTextStream(mrpt::utils::CSt
  * \param obs The observation.
  * \sa computeObservationLikelihood
  */
-bool COccupancyGridMap2D::internal_canComputeObservationLikelihood( const mrpt::obs::CObservation *obs )
+bool COccupancyGridMap2D::internal_canComputeObservationLikelihood( const mrpt::obs::CObservation *obs ) const
 {
 	// Ignore laser scans if they are not planar or they are not
 	//  at the altitude of this grid map:
@@ -929,4 +916,3 @@ bool COccupancyGridMap2D::internal_canComputeObservationLikelihood( const mrpt::
 		return false;
 	}
 }
-
