@@ -9,6 +9,11 @@
 
 #include "maps-precomp.h" // Precomp header
 
+#include <octomap/octomap.h>
+#include <octomap/OcTree.h>
+#include <mrpt/utils/pimpl.h>
+PIMPL_IMPLEMENT(octomap::OcTree);
+
 #include <mrpt/maps/COctoMap.h>
 #include <mrpt/maps/CPointsMap.h>
 #include <mrpt/obs/CObservation2DRangeScan.h>
@@ -17,6 +22,11 @@
 #include <mrpt/system/filesystem.h>
 #include <mrpt/utils/CMemoryChunk.h>
 
+#include "COctoMapBase_impl.h"
+
+// Explicit instantiation:
+template class mrpt::maps::COctoMapBase<octomap::OcTree,octomap::OcTreeNode>;
+
 using namespace std;
 using namespace mrpt;
 using namespace mrpt::maps;
@@ -62,15 +72,14 @@ mrpt::maps::CMetricMap* COctoMap::internal_CreateFromMapDefinition(const mrpt::m
 }
 //  =========== End of Map definition Block =========
 
-
 IMPLEMENTS_SERIALIZABLE(COctoMap, CMetricMap,mrpt::maps)
 
 /*---------------------------------------------------------------
 						Constructor
   ---------------------------------------------------------------*/
-COctoMap::COctoMap(const double resolution) :
-	COctoMapBase<octomap::OcTree,octomap::OcTreeNode>(resolution)
+COctoMap::COctoMap(const double resolution)
 {
+	m_octomap.ptr.reset(new octomap::OcTree(resolution));
 }
 
 /*---------------------------------------------------------------
@@ -98,7 +107,7 @@ void  COctoMap::writeToStream(mrpt::utils::CStream &out, int *version) const
 
 		CMemoryChunk chunk;
 		const string	tmpFil = mrpt::system::getTempFileName();
-		const_cast<octomap::OcTree*>(&m_octomap)->writeBinary(tmpFil);
+		const_cast<octomap::OcTree*>(&PIMPL_GET_REF(OcTree, m_octomap))->writeBinary(tmpFil);
 		chunk.loadBufferFromFile(tmpFil);
 		mrpt::system::deleteFile(tmpFil);
 
@@ -132,7 +141,7 @@ void  COctoMap::readFromStream(mrpt::utils::CStream &in, int version)
 			{
 				const string	tmpFil = mrpt::system::getTempFileName();
 				if (!chunk.saveBufferToFile( tmpFil ) ) THROW_EXCEPTION("Error saving temporary file");
-				m_octomap.readBinary(tmpFil);
+				PIMPL_GET_REF(OcTree, m_octomap).readBinary(tmpFil);
 				mrpt::system::deleteFile( tmpFil );
 			}
 
@@ -151,7 +160,7 @@ bool COctoMap::internal_insertObservation(const mrpt::obs::CObservation *obs,con
 	if (!internal_build_PointCloud_for_observation(obs,robotPose, sensorPt, scan))
 		return false; // Nothing to do.
 	// Insert rays:
-	m_octomap.insertPointCloud(scan, sensorPt, insertionOptions.maxrange, insertionOptions.pruning);
+	PIMPL_GET_REF(OcTree, m_octomap).insertPointCloud(scan, sensorPt, insertionOptions.maxrange, insertionOptions.pruning);
 	return true;
 }
 
@@ -162,7 +171,7 @@ void COctoMap::getAsOctoMapVoxels(mrpt::opengl::COctoMapVoxels &gl_obj) const
 {
 	// Go thru all voxels:
 	//OcTreeVolume voxel; // current voxel, possibly transformed
-	octomap::OcTree::tree_iterator it_end = m_octomap.end_tree();
+	octomap::OcTree::tree_iterator it_end = PIMPL_GET_REF(OcTree, m_octomap).end_tree();
 
 	const unsigned char max_depth = 0; // all
 	const TColorf general_color = gl_obj.getColor();
@@ -185,7 +194,7 @@ void COctoMap::getAsOctoMapVoxels(mrpt::opengl::COctoMapVoxels &gl_obj) const
 	this->getMetricMax(xmax, ymax, zmax);
 	inv_dz = 1/(zmax-zmin + 0.01);
 
-	for(octomap::OcTree::tree_iterator it = m_octomap.begin_tree(max_depth);it!=it_end; ++it)
+	for(octomap::OcTree::tree_iterator it = PIMPL_GET_REF(OcTree, m_octomap).begin_tree(max_depth);it!=it_end; ++it)
 	{
 		const octomap::point3d vx_center = it.getCoordinate();
 		const double           vx_length = it.getSize();
@@ -236,7 +245,7 @@ void COctoMap::getAsOctoMapVoxels(mrpt::opengl::COctoMapVoxels &gl_obj) const
 					THROW_EXCEPTION("Unknown coloring scheme!")
 				}
 
-				const size_t vx_set = (m_octomap.isNodeOccupied(*it)) ? VOXEL_SET_OCCUPIED:VOXEL_SET_FREESPACE;
+				const size_t vx_set = (PIMPL_GET_REF(OcTree, m_octomap).isNodeOccupied(*it)) ? VOXEL_SET_OCCUPIED:VOXEL_SET_FREESPACE;
 
 				gl_obj.push_back_Voxel(vx_set,COctoMapVoxels::TVoxel( TPoint3D(vx_center.x(),vx_center.y(),vx_center.z()) ,vx_length, vx_color) );
 			}
@@ -261,8 +270,50 @@ void COctoMap::getAsOctoMapVoxels(mrpt::opengl::COctoMapVoxels &gl_obj) const
 		this->getMetricMax(bbmax.x,bbmax.y,bbmax.z);
 		gl_obj.setBoundingBox(bbmin, bbmax);
 	}
-
 }
 
+void COctoMap::insertRay(const float end_x, const float end_y, const float end_z, const float sensor_x, const float sensor_y, const float sensor_z)
+{
+	PIMPL_GET_REF(OcTree, m_octomap).insertRay(octomap::point3d(sensor_x, sensor_y, sensor_z), octomap::point3d(end_x, end_y, end_z), insertionOptions.maxrange, insertionOptions.pruning);
+}
+void COctoMap::updateVoxel(const double x, const double y, const double z, bool occupied)
+{
+	PIMPL_GET_REF(OcTree, m_octomap).updateNode(x, y, z, occupied);
+}
+bool COctoMap::isPointWithinOctoMap(const float x, const float y, const float z) const
+{
+	octomap::OcTreeKey key;
+	return PIMPL_GET_CONSTREF(OcTree, m_octomap).coordToKeyChecked(octomap::point3d(x, y, z), key);
+}
 
-
+double COctoMap::getResolution() const { return PIMPL_GET_CONSTREF(OcTree, m_octomap).getResolution(); }
+unsigned int COctoMap::getTreeDepth() const { return PIMPL_GET_CONSTREF(OcTree, m_octomap).getTreeDepth(); }
+size_t COctoMap::size() const { return  PIMPL_GET_CONSTREF(OcTree, m_octomap).size(); }
+size_t COctoMap::memoryUsage() const { return  PIMPL_GET_CONSTREF(OcTree, m_octomap).memoryUsage(); }
+size_t COctoMap::memoryUsageNode() const { return  PIMPL_GET_CONSTREF(OcTree, m_octomap).memoryUsageNode(); }
+size_t COctoMap::memoryFullGrid() const { return  PIMPL_GET_CONSTREF(OcTree, m_octomap).memoryFullGrid(); }
+double COctoMap::volume() { return PIMPL_GET_REF(OcTree, m_octomap).volume(); }
+void COctoMap::getMetricSize(double& x, double& y, double& z) { return PIMPL_GET_REF(OcTree, m_octomap).getMetricSize(x, y, z); }
+void COctoMap::getMetricSize(double& x, double& y, double& z) const { return  PIMPL_GET_CONSTREF(OcTree, m_octomap).getMetricSize(x, y, z); }
+void COctoMap::getMetricMin(double& x, double& y, double& z) { return PIMPL_GET_REF(OcTree, m_octomap).getMetricMin(x, y, z); }
+void COctoMap::getMetricMin(double& x, double& y, double& z) const { return  PIMPL_GET_CONSTREF(OcTree, m_octomap).getMetricMin(x, y, z); }
+void COctoMap::getMetricMax(double& x, double& y, double& z) { return PIMPL_GET_REF(OcTree, m_octomap).getMetricMax(x, y, z); }
+void COctoMap::getMetricMax(double& x, double& y, double& z) const { return  PIMPL_GET_CONSTREF(OcTree, m_octomap).getMetricMax(x, y, z); }
+size_t COctoMap::calcNumNodes() const { return PIMPL_GET_REF(OcTree, m_octomap).calcNumNodes(); }
+size_t COctoMap::getNumLeafNodes() const { return PIMPL_GET_CONSTREF(OcTree, m_octomap).getNumLeafNodes(); }
+void COctoMap::setOccupancyThres(double prob) { PIMPL_GET_REF(OcTree, m_octomap).setOccupancyThres(prob); }
+void COctoMap::setProbHit(double prob) { PIMPL_GET_REF(OcTree, m_octomap).setProbHit(prob); }
+void COctoMap::setProbMiss(double prob) { PIMPL_GET_REF(OcTree, m_octomap).setProbMiss(prob); }
+void COctoMap::setClampingThresMin(double thresProb) { PIMPL_GET_REF(OcTree, m_octomap).setClampingThresMin(thresProb); }
+void COctoMap::setClampingThresMax(double thresProb) { PIMPL_GET_REF(OcTree, m_octomap).setClampingThresMax(thresProb); }
+double COctoMap::getOccupancyThres() const { return PIMPL_GET_REF(OcTree, m_octomap).getOccupancyThres(); }
+float COctoMap::getOccupancyThresLog() const { return PIMPL_GET_REF(OcTree, m_octomap).getOccupancyThresLog(); }
+double COctoMap::getProbHit() const { return PIMPL_GET_REF(OcTree, m_octomap).getProbHit(); }
+float COctoMap::getProbHitLog() const { return PIMPL_GET_REF(OcTree, m_octomap).getProbHitLog(); }
+double COctoMap::getProbMiss() const { return PIMPL_GET_REF(OcTree, m_octomap).getProbMiss(); }
+float COctoMap::getProbMissLog() const { return PIMPL_GET_REF(OcTree, m_octomap).getProbMissLog(); }
+double COctoMap::getClampingThresMin() const { return PIMPL_GET_REF(OcTree, m_octomap).getClampingThresMin(); }
+float COctoMap::getClampingThresMinLog() const { return PIMPL_GET_REF(OcTree, m_octomap).getClampingThresMinLog(); }
+double COctoMap::getClampingThresMax() const { return PIMPL_GET_REF(OcTree, m_octomap).getClampingThresMax(); }
+float COctoMap::getClampingThresMaxLog() const { return PIMPL_GET_REF(OcTree, m_octomap).getClampingThresMaxLog(); }
+void COctoMap::internal_clear() { PIMPL_GET_REF(OcTree, m_octomap).clear(); }
