@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -12,7 +12,6 @@
 #include <mrpt/utils/CConfigFile.h>
 #include <mrpt/utils/CTicTac.h>
 #include <mrpt/utils/CTimeLogger.h>
-#include <mrpt/utils/CStartUpClassesRegister.h>
 #include <mrpt/system/os.h>
 #include <mrpt/math/geometry.h>
 #include <mrpt/utils/CStream.h>
@@ -62,9 +61,6 @@ float CPointsMap::COLOR_3DSCENE_R = 0;
 float CPointsMap::COLOR_3DSCENE_G = 0;
 float CPointsMap::COLOR_3DSCENE_B = 1;
 
-extern CStartUpClassesRegister  mrpt_maps_class_reg;
-const int dumm = mrpt_maps_class_reg.do_nothing(); // Avoid compiler removing this class in static linking
-
 /*---------------------------------------------------------------
 						Constructor
   ---------------------------------------------------------------*/
@@ -349,8 +345,8 @@ void CPointsMap::determineMatching2D(
 	correspondences.reserve(nLocalPoints);
 	extraResults.correspondencesRatio = 0;
 
-    TMatchingPairList _correspondences;
-    _correspondences.reserve(nLocalPoints);
+	TMatchingPairList _correspondences;
+	_correspondences.reserve(nLocalPoints);
 
 	// Hay mapa global?
 	if (!nGlobalPoints) return;  // No
@@ -384,6 +380,8 @@ void CPointsMap::determineMatching2D(
 
 	// We'll assume that the real allocated memory in the source buffers at least have room for a maximum
 	//  of 3 more floats, and pad with zeroes there (yeah, fuck correct-constness....)
+	// JLBC OCT/2016: resize() methods in maps have been modified to enforce capacities to be 4*N by design,
+	// but will leave this code here just in case (for some edge cases?)
 	if ( otherMap->x.capacity()<nLocalPoints_4align ||
 		 otherMap->y.capacity()<nLocalPoints_4align )
 	{
@@ -444,8 +442,8 @@ void CPointsMap::determineMatching2D(
 
 #else
 	// Non SSE2 version:
-	const Eigen::Map<Eigen::Matrix<float,Eigen::Dynamic,1> > x_org( const_cast<float*>(&otherMap->x[0]),otherMap->x.size(),1 ); 
-	const Eigen::Map<Eigen::Matrix<float,Eigen::Dynamic,1> > y_org( const_cast<float*>(&otherMap->y[0]),otherMap->y.size(),1 ); 
+	const Eigen::Map<Eigen::Matrix<float,Eigen::Dynamic,1> > x_org( const_cast<float*>(&otherMap->x[0]),otherMap->x.size(),1 );
+	const Eigen::Map<Eigen::Matrix<float,Eigen::Dynamic,1> > y_org( const_cast<float*>(&otherMap->y[0]),otherMap->y.size(),1 );
 
 	Eigen::Array<float,Eigen::Dynamic,1>  x_locals = otherMapPose.x + cos_phi * x_org.array() - sin_phi *  y_org.array() ;
 	Eigen::Array<float,Eigen::Dynamic,1>  y_locals = otherMapPose.y + sin_phi * x_org.array() + cos_phi *  y_org.array() ;
@@ -535,39 +533,12 @@ void CPointsMap::determineMatching2D(
 	//  led to just one correspondence for each "local map" point, but
 	//  many of them may have as corresponding pair the same "global point"!!
 	// -------------------------------------------------------------------------
-	if (params.onlyUniqueRobust)
-	{
-		//if (!params.onlyKeepTheClosest)  THROW_EXCEPTION("ERROR: onlyKeepTheClosest must be also set to true when onlyUniqueRobust=true.")
-
-		vector<TMatchingPairPtr>	bestMatchForThisMap( nGlobalPoints, TMatchingPairPtr(NULL) );
-		TMatchingPairList::iterator it;
-
-		//   1) Go through all the correspondences and keep the best corresp.
-		//       for each "global map" (this) point.
-		for (it=_correspondences.begin();it!=_correspondences.end();++it)
-		{
-			if (!bestMatchForThisMap[it->this_idx])
-			{
-				bestMatchForThisMap[it->this_idx] = &(*it);
-			}
-			else
-			{
-				if ( it->errorSquareAfterTransformation < bestMatchForThisMap[it->this_idx]->errorSquareAfterTransformation )
-					bestMatchForThisMap[it->this_idx] = &(*it);
-			}
-		}
-
-		//   2) Go again through the list of correspondences and remove those
-		//       who are not the best one for their corresponding global map.
-		for (it=_correspondences.begin();it!=_correspondences.end(); ++it)
-		{
-			if ( bestMatchForThisMap[it->this_idx] != &(*it) )
-                correspondences.push_back( *it );   				// Add to the output
-		}
-	} // end of additional consistency filer for "onlyKeepTheClosest"
-	else
-	{
-	    correspondences.swap(_correspondences);
+	if (params.onlyUniqueRobust) {
+		ASSERTMSG_(params.onlyKeepTheClosest, "ERROR: onlyKeepTheClosest must be also set to true when onlyUniqueRobust=true.");
+		_correspondences.filterUniqueRobustPairs(nGlobalPoints,correspondences);
+	}
+	else {
+		correspondences.swap(_correspondences);
 	}
 
 	// If requested, copy sum of squared distances to output pointer:
@@ -682,7 +653,7 @@ void CPointsMap::TInsertionOptions::readFromStream(mrpt::utils::CStream &in)
 
 
 CPointsMap::TLikelihoodOptions::TLikelihoodOptions() :
-	sigma_dist          ( 0.05 ),
+    sigma_dist          ( 0.0025 ),
 	max_corr_distance   ( 1.0 ),
 	decimation          ( 10 )
 {
@@ -950,6 +921,8 @@ void CPointsMap::boundingBox(
 
 			// We'll assume that the real allocated memory in the source buffers at least have room for a maximum
 			//  of 3 more floats, and pad with zeroes there (yeah, fuck correct-constness....)
+			// JLBC OCT/2016: resize() methods in maps have been modified to enforce capacities to be 4*N by design,
+			// but will leave this code here just in case (for some edge cases?)
 			if ( x.capacity()<nPoints_4align ||
 				 y.capacity()<nPoints_4align ||
 				 z.capacity()<nPoints_4align )
@@ -1069,20 +1042,14 @@ void  CPointsMap::determineMatching3D(
 	correspondences.clear();
 	correspondences.reserve(nLocalPoints);
 
-    TMatchingPairList _correspondences;
+	TMatchingPairList _correspondences;
 	_correspondences.reserve(nLocalPoints);
 
-	// Hay mapa global?
-	if (!nGlobalPoints) return;  // No
+	// Empty maps?  Nothing to do
+	if (!nGlobalPoints || !nLocalPoints) return;
 
-	// Hay mapa local?
-	if (!nLocalPoints)  return;  // No
-
-	// Solo hacer matching si existe alguna posibilidad de que
-	//  los dos mapas se toquen:
-	// -----------------------------------------------------------
-
-	// Transladar y rotar ya todos los puntos locales
+	// Try to do matching only if the bounding boxes have some overlap:
+	// Transform all local points:
 	vector<float> x_locals(nLocalPoints), y_locals(nLocalPoints), z_locals(nLocalPoints);
 
 	for (unsigned int localIdx=params.offset_other_map_points;localIdx<nLocalPoints;localIdx+=params.decimation_other_map_points)
@@ -1117,8 +1084,7 @@ void  CPointsMap::determineMatching3D(
 	if (local_x_min>global_x_max ||
 		local_x_max<global_x_min ||
 		local_y_min>global_y_max ||
-		local_y_max<global_y_min) return;	// No hace falta hacer matching,
-											//   porque es de CERO.
+		local_y_max<global_y_min) return;	// No need to compute: matching is ZERO.
 
 	// Loop for each point in local map:
 	// --------------------------------------------------
@@ -1182,39 +1148,12 @@ void  CPointsMap::determineMatching3D(
 	//  led to just one correspondence for each "local map" point, but
 	//  many of them may have as corresponding pair the same "global point"!!
 	// -------------------------------------------------------------------------
-	if (params.onlyUniqueRobust)
-	{
-		if (!params.onlyKeepTheClosest)  THROW_EXCEPTION("ERROR: onlyKeepTheClosest must be also set to true when onlyUniqueRobust=true.")
-
-		vector<TMatchingPairPtr>	bestMatchForThisMap( nGlobalPoints, TMatchingPairPtr(NULL) );
-		TMatchingPairList::iterator it;
-
-		//   1) Go through all the correspondences and keep the best corresp.
-		//       for each "global map" (this) point.
-		for (it=_correspondences.begin();it!=_correspondences.end();++it)
-		{
-			if (!bestMatchForThisMap[it->this_idx])
-			{
-				bestMatchForThisMap[it->this_idx] = &(*it);
-			}
-			else
-			{
-				if ( it->errorSquareAfterTransformation < bestMatchForThisMap[it->this_idx]->errorSquareAfterTransformation )
-					bestMatchForThisMap[it->this_idx] = &(*it);
-			}
-		}
-
-		//   2) Go again through the list of correspondences and remove those
-		//       who are not the best one for their corresponding global map.
-		for (it=_correspondences.begin();it!=_correspondences.end(); ++it)
-		{
-			if ( bestMatchForThisMap[it->this_idx] != &(*it) )
-				correspondences.push_back(*it); 				// Add to the output
-		}
-	} // end of additional consistency filer for "onlyKeepTheClosest"
-	else
-	{
-	    correspondences.swap(_correspondences);
+	if (params.onlyUniqueRobust) {
+		ASSERTMSG_(params.onlyKeepTheClosest, "ERROR: onlyKeepTheClosest must be also set to true when onlyUniqueRobust=true.");
+		_correspondences.filterUniqueRobustPairs(nGlobalPoints,correspondences);
+	}
+	else {
+		correspondences.swap(_correspondences);
 	}
 
 	// If requested, copy sum of squared distances to output pointer:
@@ -1832,17 +1771,8 @@ bool  CPointsMap::internal_insertObservation(
 					*o,						// The laser range scan observation
 					&robotPose3D				// The robot pose
 					);
-
-				// Don't build this vector if is not used later!
-//				if (!insertionOptions.disableDeletion)
-//				{
-//					const size_t n = size();
-//					checkForDeletion.resize(n);
-//					for (size_t i=0;i<n;i++) checkForDeletion[i] = true;
-//				}
 			}
 
-
 			return true;
 		}
 		// A planar map and a non-horizontal scan.
@@ -2109,7 +2039,7 @@ void CPointsMap::loadFromVelodyneScan(
 
 	// global 3D pose:
 	CPose3D sensorGlobalPose;
-	if (robotPose) 
+	if (robotPose)
 	      sensorGlobalPose = *robotPose + scan.sensorPose;
 	else  sensorGlobalPose = scan.sensorPose;
 
@@ -2138,4 +2068,3 @@ void CPointsMap::loadFromVelodyneScan(
 			);
 	}
 }
-
