@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -137,7 +137,7 @@ void do_test_clipOutOfRange()
 	// Clip:
 	{
 		CPoint2D pivot(0,0);
-		const float radius = 1.1;
+		const float radius = 1.1f;
 
 		MAP  pts = pts0;
 		pts.clipOutOfRange(pivot,radius);
