@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -11,6 +11,7 @@
 
 #include <mrpt/nav/link_pragmas.h>
 #include <mrpt/utils/CSerializable.h>
+#include <mrpt/math/CMatrixD.h>
 
 namespace mrpt
 {
@@ -30,7 +31,9 @@ namespace mrpt
 	{
 		DEFINE_VIRTUAL_SERIALIZABLE( CHolonomicLogFileRecord )
 	public:
+		std::vector<std::vector<double> >  dirs_eval; //!< Final [0] and alternative [1..N] evaluation scores for each direction, in the same order of TP-Obstacles. May be not filled by all methods.
 
+		virtual const mrpt::math::CMatrixD * getDirectionScores() const { return NULL; }
 	};
 	DEFINE_SERIALIZABLE_POST_CUSTOM_BASE_LINKAGE(CHolonomicLogFileRecord, mrpt::utils::CSerializable, NAV_IMPEXP)
 
