@@ -124,7 +124,7 @@ namespace mrpt
 			   * By default (ith=0), the first one is returned.
 			   */
 			 template <typename T>
-			 typename T::SmartPtr getActionByClass( const size_t &ith = 0 ) const
+			 typename T::Ptr getActionByClass( const size_t &ith = 0 ) const
 			 {
 				MRPT_START
 				size_t  foundCount = 0;
@@ -132,8 +132,8 @@ namespace mrpt
 				for (const_iterator it = begin();it!=end();++it)
 					if ( (*it)->GetRuntimeClass()->derivedFrom( class_ID ) )
 						if (foundCount++ == ith)
-							return typename T::SmartPtr(it->get_ptr());
-				return typename T::SmartPtr();	// Not found: return empty smart pointer
+							return typename T::Ptr(it->get_ptr());
+				return typename T::Ptr();	// Not found: return empty smart pointer
 				MRPT_END
 			 }
 
