@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -21,15 +21,8 @@ namespace mrpt
 	/** This namespace contains representation of robot actions and observations */
 	namespace obs
 	{
-		/** Used for CObservationBearingRange::TMeasurement::beaconID
-		 * \ingroup mrpt_obs_grp
-		  */
-		#define INVALID_LANDMARK_ID 	(-1)
-
-		/** Used for CObservationBeaconRange
-		 * \ingroup mrpt_obs_grp
-		  */
-		#define INVALID_BEACON_ID  		(-1)
+		#define INVALID_BEACON_ID  		(-1) //!< Used for CObservationBeaconRange, CBeacon, etc. \ingroup mrpt_obs_grp
+		#define INVALID_LANDMARK_ID 	(-1) //!< Used for CObservationBearingRange::TMeasurement::beaconID and others. \ingroup mrpt_obs_grp
 
 		DEFINE_SERIALIZABLE_PRE_CUSTOM_BASE_LINKAGE( CObservation, mrpt::utils::CSerializable, OBS_IMPEXP )
 
@@ -77,6 +70,7 @@ namespace mrpt
 		* \return Returns true if the map has been updated, or false if this observations
 		*			has nothing to do with a metric map (for example, a sound observation).
 		*
+		* See: \ref maps_observations
 		* \sa CMetricMap, CMetricMap::insertObservation
 		*/
 		template <class METRICMAP>
@@ -109,8 +103,8 @@ namespace mrpt
 		*/
 		void setSensorPose( const mrpt::math::TPose3D &newSensorPose );
 
-		/** Build a detailed, multi-line textual description of the observation contents and dump it to the output stream. 
-		  * \note If overried by derived classes, call base CObservation::getDescriptionAsText() first to show common information. 
+		/** Build a detailed, multi-line textual description of the observation contents and dump it to the output stream.
+		  * \note If overried by derived classes, call base CObservation::getDescriptionAsText() first to show common information.
 		  * \note This is the text that appears in RawLogViewer when selecting an object in the dataset */
 		virtual void getDescriptionAsText(std::ostream &o) const;
 
