@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -11,8 +11,6 @@
 
 #include <mrpt/obs/CAction.h>
 #include <mrpt/utils/CStream.h>
-#include <mrpt/utils/CStartUpClassesRegister.h>
-
 
 using namespace mrpt::obs;
 using namespace mrpt::utils;
@@ -21,11 +19,6 @@ using namespace mrpt::utils;
 IMPLEMENTS_VIRTUAL_SERIALIZABLE(CAction, CSerializable, mrpt::obs)
 
 
-extern CStartUpClassesRegister  mrpt_obs_class_reg;
-
-const int dumm = mrpt_obs_class_reg.do_nothing(); // Avoid compiler removing this class in static linking
-
-
 /*---------------------------------------------------------------
 			Constructor
   ---------------------------------------------------------------*/
