@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -128,7 +128,7 @@ void  CObservationBeaconRanges::debugPrintOut()
 void CObservationBeaconRanges::getSensorPose( CPose3D &out_sensorPose ) const
 {
 	if (!sensedData.empty())
-		out_sensorPose=sensedData[0].sensorLocationOnRobot;
+		out_sensorPose=CPose3D(sensedData[0].sensorLocationOnRobot);
 	else 	out_sensorPose = CPose3D(0,0,0);
 }
 
