@@ -129,15 +129,15 @@ namespace mrpt
 			   * By default (ith=0), the first observation is returned.
 			   */
 			 template <typename T>
-			 typename T::SmartPtr getByClass( const size_t &ith = 0 ) const
+			 typename T::Ptr getByClass( const size_t &ith = 0 ) const
 			 {
 				MRPT_START
 				for (TListViewports::const_iterator it = m_viewports.begin();it!=m_viewports.end();++it)
 				{
-					typename T::SmartPtr o = (*it)->getByClass<T>(ith);
+					typename T::Ptr o = (*it)->getByClass<T>(ith);
 					if (o.present()) return o;
 				}
-				return typename T::SmartPtr();	// Not found: return empty smart pointer
+				return typename T::Ptr();	// Not found: return empty smart pointer
 				MRPT_END
 			 }
 
