@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -281,6 +281,11 @@ namespace mrpt
 				m_obj.setPoint_fast(idx,x,y,z);
 			}
 
+			/** Set XYZ coordinates of i'th point */
+			inline void setInvalidPoint(const size_t idx) {
+				THROW_EXCEPTION("mrpt::opengl::CPointCloud needs to be dense");
+			}
+
 		}; // end of PointCloudAdapter<mrpt::opengl::CPointCloud>
 	}
 
