@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)               |
    |                          http://www.mrpt.org/                             |
    |                                                                           |
-   | Copyright (c) 2005-2016, Individual contributors, see AUTHORS file        |
+   | Copyright (c) 2005-2017, Individual contributors, see AUTHORS file        |
    | See: http://www.mrpt.org/Authors - All rights reserved.                   |
    | Released under BSD License. See details in http://www.mrpt.org/License    |
    +---------------------------------------------------------------------------+ */
@@ -70,7 +70,9 @@ namespace mrpt
 			inline bool isShowNameEnabled() const { return m_show_name; }	//!< \sa enableShowName
 
 			CRenderizable& setPose( const mrpt::poses::CPose3D &o );	//!< Set the 3D pose from a mrpt::poses::CPose3D object (return a ref to this)
+			CRenderizable& setPose( const mrpt::poses::CPose2D &o );	//!< Set the 3D pose from a mrpt::poses::CPose3D object (return a ref to this)
 			CRenderizable& setPose( const mrpt::math::TPose3D &o );	//!< Set the 3D pose from a  mrpt::math::TPose3D object (return a ref to this)
+			CRenderizable& setPose( const mrpt::math::TPose2D &o );	//!< Set the 3D pose from a  mrpt::math::TPose3D object (return a ref to this)
 			CRenderizable& setPose( const mrpt::poses::CPoint3D &o );	//!< Set the 3D pose from a mrpt::poses::CPose3D object (return a ref to this)
 			CRenderizable& setPose( const mrpt::poses::CPoint2D &o );	//!< Set the 3D pose from a mrpt::poses::CPose3D object (return a ref to this)
 
@@ -134,8 +136,8 @@ namespace mrpt
 			/*** Changes the default object color \return a ref to this */
 			virtual CRenderizable& setColor_u8( const mrpt::utils::TColor &c);
 
-			/** Set the color components of this object (R,G,B,Alpha, in the range 0-1)  \return a ref to this */
-			inline CRenderizable& setColor_u8( uint8_t R, uint8_t G, uint8_t B, uint8_t A=255) { return setColor_u8(mrpt::utils::TColor(R,G,B,A)); }
+			/** Set the color components of this object (R,G,B,Alpha, in the range 0-255)  \return a ref to this */
+			CRenderizable& setColor_u8( uint8_t R, uint8_t G, uint8_t B, uint8_t A=255) { return setColor_u8(mrpt::utils::TColor(R,G,B,A)); }
 
 			/** @} */
 
